window.Gleam.initSearch([{"doc":"gleam_stdlib","title":"gleam_stdlib","content":"# stdlib\n\n&lt;a href=&quot;https://github.com/gleam-lang/stdlib/releases&quot;&gt;&lt;img src=&quot;https://img.shields.io/github/release/gleam-lang/stdlib&quot; alt=&quot;GitHub release&quot;&gt;&lt;/a&gt;\n&lt;a href=&quot;https://discord.gg/Fm8Pwmy&quot;&gt;&lt;img src=&quot;https://img.shields.io/discord/768594524158427167?color=blue&quot; alt=&quot;Discord chat&quot;&gt;&lt;/a&gt;\n![CI](https://github.com/gleam-lang/stdlib/workflows/CI/badge.svg?branch=main)\n\nGleam&#39;s standard library!\nDocumentation available on [HexDocs](https://hexdocs.pm/gleam_stdlib/).\n\n## Installation\n\nAdd `gleam_stdlib` to your Gleam project.\n\n```sh\ngleam add gleam_stdlib\n```\n\n## Usage\n\nImport the modules you want to use and write some code!\n\n```gleam\nimport gleam/string\n\npub fn greet(name: String) -&gt; String {\n  string.concat([&quot;Hello &quot;, name, &quot;!&quot;])\n}\n```\n\n## Targets\n\nGleam&#39;s standard library supports both targets: Erlang and JavaScript.\n\n### Compatibility\n\nThis library is compatible with all versions of Erlang/OTP, NodeJS, and\nmajor browsers that are currently supported by their maintainers. If you\nhave a compatibility issue with any platform open an issue and we&#39;ll see\nwhat we can do to help.\n","url":"index.html"},{"doc":"gleam/order","title":"Order","content":"pub type Order {\n  Lt\n  Eq\n  Gt\n}\n Represents the result of a single comparison to determine the precise\n ordering of two values.\n\nLt\n Less-than\n\nEq\n Equal\n\nGt\n Greater than\n\nSynonyms:\ngleam/order.Order\ngleam/order Order","url":"gleam/order.html#Order"},{"doc":"gleam/order","title":"compare","content":"pub fn compare(a: Order, with b: Order) -&gt; Order\n Compares two `Order` values to one another, producing a new `Order`.\n\n ## Examples\n\n \n &gt; compare(Eq, with: Lt)\n Gt\n \n\nSynonyms:\ngleam/order.compare\ngleam/order compare","url":"gleam/order.html#compare"},{"doc":"gleam/order","title":"max","content":"pub fn max(a: Order, b: Order) -&gt; Order\n Returns the largest of two orders given that `Gt &gt; Eq &gt; Lt`.\n\n ## Examples\n\n \n &gt; max(Eq, Lt)\n Eq\n \n\nSynonyms:\ngleam/order.max\ngleam/order max","url":"gleam/order.html#max"},{"doc":"gleam/order","title":"min","content":"pub fn min(a: Order, b: Order) -&gt; Order\n Returns the smallest of two orders given that `Gt &gt; Eq &gt; Lt`.\n\n ## Examples\n\n \n &gt; min(Eq, Lt)\n Lt\n \n\nSynonyms:\ngleam/order.min\ngleam/order min","url":"gleam/order.html#min"},{"doc":"gleam/order","title":"negate","content":"pub fn negate(order: Order) -&gt; Order\n Inverts an order, so less-than becomes greater-than and greater-than\n becomes less-than.\n\n ## Examples\n\n \n &gt; negate(Lt)\n Gt\n \n\n \n &gt; negate(Eq)\n Eq\n \n\n \n &gt; negate(Lt)\n Gt\n \n\nSynonyms:\ngleam/order.negate\ngleam/order negate","url":"gleam/order.html#negate"},{"doc":"gleam/order","title":"reverse","content":"pub fn reverse(orderer: fn(a, a) -&gt; Order) -&gt; fn(a, a) -&gt; Order\n Inverts an ordering function, so less-than becomes greater-than and greater-than\n becomes less-than.\n\n ## Examples\n\n \n &gt; list.sort([1, 5, 4], by: reverse(int.compare))\n [5, 4, 1]\n \n\nSynonyms:\ngleam/order.reverse\ngleam/order reverse","url":"gleam/order.html#reverse"},{"doc":"gleam/order","title":"to_int","content":"pub fn to_int(order: Order) -&gt; Int\n Produces a numeric representation of the order.\n\n ## Examples\n\n \n &gt; to_int(Lt)\n -1\n \n\n \n &gt; to_int(Eq)\n 0\n \n\n \n &gt; to_int(Gt)\n 1\n \n\nSynonyms:\ngleam/order.to_int\ngleam/order to_int","url":"gleam/order.html#to_int"},{"doc":"gleam/order","title":"gleam/order","content":"","url":"gleam/order.html"},{"doc":"gleam/float","title":"absolute_value","content":"pub fn absolute_value(x: Float) -&gt; Float\n Returns the absolute value of the input as a `Float`.\n\n ## Examples\n\n \n &gt; absolute_value(-12.5)\n 12.5\n \n\n \n &gt; absolute_value(10.2)\n 10.2\n \n\nSynonyms:\ngleam/float.absolute_value\ngleam/float absolute_value","url":"gleam/float.html#absolute_value"},{"doc":"gleam/float","title":"add","content":"pub fn add(a: Float, b: Float) -&gt; Float\n Adds two floats together.\n\n It&#39;s the function equivalent of the `+.` operator.\n This function is useful in higher order functions or pipes.\n\n ## Examples\n\n \n &gt; add(1.0, 2.0)\n 3.0\n \n\n \n &gt; import gleam/list\n &gt; list.fold([1.0, 2.0, 3.0], 0.0, add)\n 6.0\n \n\n \n &gt; 3.0 |&gt; add(2.0)\n 5.0\n \n\nSynonyms:\ngleam/float.add\ngleam/float add","url":"gleam/float.html#add"},{"doc":"gleam/float","title":"ceiling","content":"pub fn ceiling(x: Float) -&gt; Float\n Rounds the value to the next highest whole number as a `Float`.\n\n ## Examples\n\n \n &gt; ceiling(2.3)\n 3.0\n \n\nSynonyms:\ngleam/float.ceiling\ngleam/float ceiling","url":"gleam/float.html#ceiling"},{"doc":"gleam/float","title":"clamp","content":"pub fn clamp(\n  x: Float,\n  min min_bound: Float,\n  max max_bound: Float,\n) -&gt; Float\n Restricts a `Float` between a lower and upper bound.\n\n ## Examples\n\n \n &gt; clamp(1.2, min: 1.4, max: 1.6)\n 1.4\n \n\nSynonyms:\ngleam/float.clamp\ngleam/float clamp","url":"gleam/float.html#clamp"},{"doc":"gleam/float","title":"compare","content":"pub fn compare(a: Float, with b: Float) -&gt; Order\n Compares two `Float`s, returning an `Order`:\n `Lt` for lower than, `Eq` for equals, or `Gt` for greater than.\n\n ## Examples\n\n \n &gt; compare(2.0, 2.3)\n Lt\n \n\n To handle\n [Floating Point Imprecision](https://en.wikipedia.org/wiki/Floating-point_arithmetic#Accuracy_problems)\n you may use [`loosely_compare`](#loosely_compare) instead.\n\nSynonyms:\ngleam/float.compare\ngleam/float compare","url":"gleam/float.html#compare"},{"doc":"gleam/float","title":"divide","content":"pub fn divide(a: Float, by b: Float) -&gt; Result(Float, Nil)\n Returns division of the inputs as a `Result`.\n\n ## Examples\n\n \n &gt; divide(0.0, 1.0)\n Ok(1.0)\n \n\n \n &gt; divide(1.0, 0.0)\n Error(Nil)\n \n\nSynonyms:\ngleam/float.divide\ngleam/float divide","url":"gleam/float.html#divide"},{"doc":"gleam/float","title":"floor","content":"pub fn floor(x: Float) -&gt; Float\n Rounds the value to the next lowest whole number as a `Float`.\n\n ## Examples\n\n \n &gt; floor(2.3)\n 2.0\n \n\nSynonyms:\ngleam/float.floor\ngleam/float floor","url":"gleam/float.html#floor"},{"doc":"gleam/float","title":"loosely_compare","content":"pub fn loosely_compare(\n  a: Float,\n  with b: Float,\n  tolerating tolerance: Float,\n) -&gt; Order\n Compares two `Float`s within a tolerance, returning an `Order`:\n `Lt` for lower than, `Eq` for equals, or `Gt` for greater than.\n\n This function allows Float comparison while handling\n [Floating Point Imprecision](https://en.wikipedia.org/wiki/Floating-point_arithmetic#Accuracy_problems).\n\n Notice: For `Float`s the tolerance won&#39;t be exact:\n `5.3 - 5.0` is not exactly `0.3`.\n\n ## Examples\n\n \n &gt; loosely_compare(5.0, with: 5.3, tolerating: 0.5)\n Eq\n \n\n If you want to check only for equality you may use\n [`loosely_equals`](#loosely_equals) instead.\n\nSynonyms:\ngleam/float.loosely_compare\ngleam/float loosely_compare","url":"gleam/float.html#loosely_compare"},{"doc":"gleam/float","title":"loosely_equals","content":"pub fn loosely_equals(\n  a: Float,\n  with b: Float,\n  tolerating tolerance: Float,\n) -&gt; Bool\n Checks for equality of two `Float`s within a tolerance,\n returning an `Bool`.\n\n This function allows Float comparison while handling\n [Floating Point Imprecision](https://en.wikipedia.org/wiki/Floating-point_arithmetic#Accuracy_problems).\n\n Notice: For `Float`s the tolerance won&#39;t be exact:\n `5.3 - 5.0` is not exactly `0.3`.\n\n ## Examples\n\n \n &gt; loosely_equals(5.0, with: 5.3, tolerating: 0.5)\n True\n \n\n \n &gt; loosely_equals(5.0, with: 5.1, tolerating: 0.1)\n False\n \n\nSynonyms:\ngleam/float.loosely_equals\ngleam/float loosely_equals","url":"gleam/float.html#loosely_equals"},{"doc":"gleam/float","title":"max","content":"pub fn max(a: Float, b: Float) -&gt; Float\n Compares two `Float`s, returning the larger of the two.\n\n ## Examples\n\n \n &gt; max(2.0, 2.3)\n 2.3\n \n\nSynonyms:\ngleam/float.max\ngleam/float max","url":"gleam/float.html#max"},{"doc":"gleam/float","title":"min","content":"pub fn min(a: Float, b: Float) -&gt; Float\n Compares two `Float`s, returning the smaller of the two.\n\n ## Examples\n\n \n &gt; min(2.0, 2.3)\n 2.0\n \n\nSynonyms:\ngleam/float.min\ngleam/float min","url":"gleam/float.html#min"},{"doc":"gleam/float","title":"multiply","content":"pub fn multiply(a: Float, b: Float) -&gt; Float\n Multiplies two floats together.\n\n It&#39;s the function equivalent of the `*.` operator.\n This function is useful in higher order functions or pipes.\n\n ## Examples\n\n \n &gt; multiply(2.0, 4.0)\n 8.0\n \n\n \n import gleam/list\n &gt; list.fold([2.0, 3.0, 4.0], 1.0, multiply)\n 24.0\n \n\n \n &gt; 3.0 |&gt; multiply(2.0)\n 6.0\n \n\nSynonyms:\ngleam/float.multiply\ngleam/float multiply","url":"gleam/float.html#multiply"},{"doc":"gleam/float","title":"negate","content":"pub fn negate(x: Float) -&gt; Float\n Returns the negative of the value provided.\n\n ## Examples\n\n \n &gt; negate(1.0)\n -1.0\n \n\nSynonyms:\ngleam/float.negate\ngleam/float negate","url":"gleam/float.html#negate"},{"doc":"gleam/float","title":"parse","content":"pub fn parse(string: String) -&gt; Result(Float, Nil)\n Attempts to parse a string as a `Float`, returning `Error(Nil)` if it was\n not possible.\n\n ## Examples\n\n \n &gt; parse(&quot;2.3&quot;)\n Ok(2.3)\n \n\n \n &gt; parse(&quot;ABC&quot;)\n Error(Nil)\n \n\nSynonyms:\ngleam/float.parse\ngleam/float parse","url":"gleam/float.html#parse"},{"doc":"gleam/float","title":"power","content":"pub fn power(\n  base: Float,\n  of exponent: Float,\n) -&gt; Result(Float, Nil)\n Returns the results of the base being raised to the power of the\n exponent, as a `Float`.\n\n ## Examples\n\n \n &gt; power(2.0, -1.0)\n Ok(0.5)\n \n\n \n &gt; power(2.0, 2.0)\n Ok(4.0)\n \n\n \n &gt; power(8.0, 1.5)\n Ok(22.627416997969522)\n \n\n \n &gt; 4.0 |&gt; power(of: 2.0)\n Ok(16.0)\n \n\n \n &gt; power(-1.0, 0.5)\n Error(Nil)\n \n\nSynonyms:\ngleam/float.power\ngleam/float power","url":"gleam/float.html#power"},{"doc":"gleam/float","title":"product","content":"pub fn product(numbers: List(Float)) -&gt; Float\n Multiplies a list of `Float`s and returns the product.\n\n ## Example\n\n \n &gt; product([2.5, 3.2, 4.2])\n 33.6\n \n\nSynonyms:\ngleam/float.product\ngleam/float product","url":"gleam/float.html#product"},{"doc":"gleam/float","title":"random","content":"pub fn random(min: Float, max: Float) -&gt; Float\n Generates a random float between the given minimum and maximum values.\n\n\n ## Examples\n\n \n &gt; random(1.0, 5.0)\n 2.646355926896028\n \n\nSynonyms:\ngleam/float.random\ngleam/float random","url":"gleam/float.html#random"},{"doc":"gleam/float","title":"round","content":"pub fn round(x: Float) -&gt; Int\n Rounds the value to the nearest whole number as an `Int`.\n\n ## Examples\n\n \n &gt; round(2.3)\n 2\n \n\n \n &gt; round(2.5)\n 3\n \n\nSynonyms:\ngleam/float.round\ngleam/float round","url":"gleam/float.html#round"},{"doc":"gleam/float","title":"square_root","content":"pub fn square_root(x: Float) -&gt; Result(Float, Nil)\n Returns the square root of the input as a `Float`.\n\n ## Examples\n\n \n &gt; square_root(4.0)\n Ok(2.0)\n \n\n \n &gt; square_root(-16.0)\n Error(Nil)\n \n\nSynonyms:\ngleam/float.square_root\ngleam/float square_root","url":"gleam/float.html#square_root"},{"doc":"gleam/float","title":"subtract","content":"pub fn subtract(a: Float, b: Float) -&gt; Float\n Subtracts one float from another.\n\n It&#39;s the function equivalent of the `-.` operator.\n This function is useful in higher order functions or pipes.\n\n ## Examples\n\n \n &gt; subtract(3.0, 1.0)\n 2.0\n \n\n \n &gt; import gleam/list\n &gt; list.fold([1.0, 2.0, 3.0], 10.0, subtract)\n 4.0\n \n\n \n &gt; 3.0 |&gt; subtract(_, 2.0)\n 1.0\n \n\n \n &gt; 3.0 |&gt; subtract(2.0, _)\n -1.0\n \n\nSynonyms:\ngleam/float.subtract\ngleam/float subtract","url":"gleam/float.html#subtract"},{"doc":"gleam/float","title":"sum","content":"pub fn sum(numbers: List(Float)) -&gt; Float\n Sums a list of `Float`s.\n\n ## Example\n\n \n &gt; sum([1.0, 2.2, 3.3])\n 6.5\n \n\nSynonyms:\ngleam/float.sum\ngleam/float sum","url":"gleam/float.html#sum"},{"doc":"gleam/float","title":"to_string","content":"pub fn to_string(x: Float) -&gt; String\n Returns the string representation of the provided `Float`.\n\n ## Examples\n\n \n &gt; to_string(2.3)\n &quot;2.3&quot;\n \n\nSynonyms:\ngleam/float.to_string\ngleam/float to_string","url":"gleam/float.html#to_string"},{"doc":"gleam/float","title":"truncate","content":"pub fn truncate(x: Float) -&gt; Int\n Returns the value as an `Int`, truncating all decimal digits.\n\n ## Examples\n\n \n &gt; truncate(2.4343434847383438)\n 2\n \n\nSynonyms:\ngleam/float.truncate\ngleam/float truncate","url":"gleam/float.html#truncate"},{"doc":"gleam/float","title":"gleam/float","content":"","url":"gleam/float.html"},{"doc":"gleam/int","title":"InvalidBase","content":"pub type InvalidBase {\n  InvalidBase\n}\n Error value when trying to operate with a base out of the allowed range.\n\nInvalidBase\n\n\nSynonyms:\ngleam/int.InvalidBase\ngleam/int InvalidBase","url":"gleam/int.html#InvalidBase"},{"doc":"gleam/int","title":"absolute_value","content":"pub fn absolute_value(x: Int) -&gt; Int\n Returns the absolute value of the input.\n\n ## Examples\n\n \n &gt; absolute_value(-12)\n 12\n \n\n \n &gt; absolute_value(10)\n 10\n \n\nSynonyms:\ngleam/int.absolute_value\ngleam/int absolute_value","url":"gleam/int.html#absolute_value"},{"doc":"gleam/int","title":"add","content":"pub fn add(a: Int, b: Int) -&gt; Int\n Adds two integers together.\n\n It&#39;s the function equivalent of the `+` operator.\n This function is useful in higher order functions or pipes.\n\n ## Examples\n\n \n &gt; add(1, 2)\n 3\n \n\n \n import gleam/list\n &gt; list.fold([1, 2, 3], 0, add)\n 6\n \n\n \n &gt; 3 |&gt; add(2)\n 5\n \n\nSynonyms:\ngleam/int.add\ngleam/int add","url":"gleam/int.html#add"},{"doc":"gleam/int","title":"base_parse","content":"pub fn base_parse(string: String, base: Int) -&gt; Result(Int, Nil)\n Parses a given string as an int in a given base if possible.\n Supports only bases 2 to 36, for values outside of which this function returns an `Error(Nil)`.\n\n ## Examples\n\n \n &gt; base_parse(&quot;10&quot;, 2)\n Ok(2)\n\n &gt; base_parse(&quot;30&quot;, 16)\n Ok(48)\n\n &gt; base_parse(&quot;1C&quot;, 36)\n Ok(48)\n\n &gt; base_parse(&quot;48&quot;, 1)\n Error(Nil)\n\n &gt; base_parse(&quot;48&quot;, 37)\n Error(Nil)\n \n\nSynonyms:\ngleam/int.base_parse\ngleam/int base_parse","url":"gleam/int.html#base_parse"},{"doc":"gleam/int","title":"bitwise_and","content":"pub fn bitwise_and(x: Int, y: Int) -&gt; Int\n Calculates the bitwise AND of its arguments.\n\n The exact behaviour of this function depends on the target platform.\n On Erlang it is equivalent to bitwise operations on ints, on JavaScript it\n is equivalent to bitwise operations on big-ints.\n\nSynonyms:\ngleam/int.bitwise_and\ngleam/int bitwise_and","url":"gleam/int.html#bitwise_and"},{"doc":"gleam/int","title":"bitwise_exclusive_or","content":"pub fn bitwise_exclusive_or(x: Int, y: Int) -&gt; Int\n Calculates the bitwise XOR of its arguments.\n\n The exact behaviour of this function depends on the target platform.\n On Erlang it is equivalent to bitwise operations on ints, on JavaScript it\n is equivalent to bitwise operations on big-ints.\n\nSynonyms:\ngleam/int.bitwise_exclusive_or\ngleam/int bitwise_exclusive_or","url":"gleam/int.html#bitwise_exclusive_or"},{"doc":"gleam/int","title":"bitwise_not","content":"pub fn bitwise_not(x: Int) -&gt; Int\n Calculates the bitwise NOT of its argument.\n\n The exact behaviour of this function depends on the target platform.\n On Erlang it is equivalent to bitwise operations on ints, on JavaScript it\n is equivalent to bitwise operations on big-ints.\n\nSynonyms:\ngleam/int.bitwise_not\ngleam/int bitwise_not","url":"gleam/int.html#bitwise_not"},{"doc":"gleam/int","title":"bitwise_or","content":"pub fn bitwise_or(x: Int, y: Int) -&gt; Int\n Calculates the bitwise OR of its arguments.\n\n The exact behaviour of this function depends on the target platform.\n On Erlang it is equivalent to bitwise operations on ints, on JavaScript it\n is equivalent to bitwise operations on big-ints.\n\nSynonyms:\ngleam/int.bitwise_or\ngleam/int bitwise_or","url":"gleam/int.html#bitwise_or"},{"doc":"gleam/int","title":"bitwise_shift_left","content":"pub fn bitwise_shift_left(x: Int, y: Int) -&gt; Int\n Calculates the result of an arithmetic left bitshift.\n\n The exact behaviour of this function depends on the target platform.\n On Erlang it is equivalent to bitwise operations on ints, on JavaScript it\n is equivalent to bitwise operations on big-ints.\n\nSynonyms:\ngleam/int.bitwise_shift_left\ngleam/int bitwise_shift_left","url":"gleam/int.html#bitwise_shift_left"},{"doc":"gleam/int","title":"bitwise_shift_right","content":"pub fn bitwise_shift_right(x: Int, y: Int) -&gt; Int\n Calculates the result of an arithmetic right bitshift.\n\n The exact behaviour of this function depends on the target platform.\n On Erlang it is equivalent to bitwise operations on ints, on JavaScript it\n is equivalent to bitwise operations on big-ints.\n\nSynonyms:\ngleam/int.bitwise_shift_right\ngleam/int bitwise_shift_right","url":"gleam/int.html#bitwise_shift_right"},{"doc":"gleam/int","title":"clamp","content":"pub fn clamp(\n  x: Int,\n  min min_bound: Int,\n  max max_bound: Int,\n) -&gt; Int\n Restricts an int between a lower and upper bound.\n\n ## Examples\n\n \n &gt; clamp(40, min: 50, max: 60)\n 50\n \n\nSynonyms:\ngleam/int.clamp\ngleam/int clamp","url":"gleam/int.html#clamp"},{"doc":"gleam/int","title":"compare","content":"pub fn compare(a: Int, with b: Int) -&gt; Order\n Compares two ints, returning an order.\n\n ## Examples\n\n \n &gt; compare(2, 3)\n Lt\n \n\n \n &gt; compare(4, 3)\n Gt\n \n\n \n &gt; compare(3, 3)\n Eq\n \n\nSynonyms:\ngleam/int.compare\ngleam/int compare","url":"gleam/int.html#compare"},{"doc":"gleam/int","title":"digits","content":"pub fn digits(\n  x: Int,\n  base: Int,\n) -&gt; Result(List(Int), InvalidBase)\n Splits an integer into its digit representation in the specified base\n\n ## Examples\n\n \n &gt; digits(234, 10)\n Ok([2,3,4])\n \n\n \n &gt; digits(234, 1)\n Error(InvalidBase)\n \n\nSynonyms:\ngleam/int.digits\ngleam/int digits","url":"gleam/int.html#digits"},{"doc":"gleam/int","title":"divide","content":"pub fn divide(dividend: Int, by divisor: Int) -&gt; Result(Int, Nil)\n Performs a truncated integer division.\n\n Returns division of the inputs as a `Result`: If the given divisor equals\n `0`, this function returns an `Error`.\n\n ## Examples\n\n \n &gt; divide(0, 1)\n Ok(1)\n \n\n \n &gt; divide(1, 0)\n Error(Nil)\n \n\n \n &gt; divide(5, 2)\n Ok(2)\n \n\n \n &gt; divide(-99, 2)\n Ok(-49)\n \n\nSynonyms:\ngleam/int.divide\ngleam/int divide","url":"gleam/int.html#divide"},{"doc":"gleam/int","title":"floor_divide","content":"pub fn floor_divide(\n  dividend: Int,\n  by divisor: Int,\n) -&gt; Result(Int, Nil)\n Performs a *floored* integer division, which means that the result will\n always be rounded towards negative infinity.\n\n If you want to perform truncated integer division (rounding towards zero),\n use `int.divide()` or the `/` operator instead.\n\n Returns division of the inputs as a `Result`: If the given divisor equals\n `0`, this function returns an `Error`.\n\n ## Examples\n\n \n &gt; floor_divide(1, 0)\n Error(Nil)\n \n\n \n &gt; floor_divide(5, 2)\n Ok(2)\n \n\n \n &gt; floor_divide(6, -4)\n Ok(-2)\n \n\n \n &gt; floor_divide(-99, 2)\n Ok(-50)\n \n\nSynonyms:\ngleam/int.floor_divide\ngleam/int floor_divide","url":"gleam/int.html#floor_divide"},{"doc":"gleam/int","title":"is_even","content":"pub fn is_even(x: Int) -&gt; Bool\n Returns whether the value provided is even.\n\n ## Examples\n\n \n &gt; is_even(2)\n True\n \n\n \n &gt; is_even(3)\n False\n \n\nSynonyms:\ngleam/int.is_even\ngleam/int is_even","url":"gleam/int.html#is_even"},{"doc":"gleam/int","title":"is_odd","content":"pub fn is_odd(x: Int) -&gt; Bool\n Returns whether the value provided is odd.\n\n ## Examples\n\n \n &gt; is_odd(3)\n True\n \n\n \n &gt; is_odd(2)\n False\n \n\nSynonyms:\ngleam/int.is_odd\ngleam/int is_odd","url":"gleam/int.html#is_odd"},{"doc":"gleam/int","title":"max","content":"pub fn max(a: Int, b: Int) -&gt; Int\n Compares two ints, returning the larger of the two.\n\n ## Examples\n\n \n &gt; max(2, 3)\n 3\n \n\nSynonyms:\ngleam/int.max\ngleam/int max","url":"gleam/int.html#max"},{"doc":"gleam/int","title":"min","content":"pub fn min(a: Int, b: Int) -&gt; Int\n Compares two ints, returning the smaller of the two.\n\n ## Examples\n\n \n &gt; min(2, 3)\n 2\n \n\nSynonyms:\ngleam/int.min\ngleam/int min","url":"gleam/int.html#min"},{"doc":"gleam/int","title":"modulo","content":"pub fn modulo(dividend: Int, by divisor: Int) -&gt; Result(Int, Nil)\n Computes the modulo of an integer division of inputs as a `Result`.\n\n Returns division of the inputs as a `Result`: If the given divisor equals\n `0`, this function returns an `Error`.\n\n Most the time you will want to use the `%` operator instead of this\n function.\n\n ## Examples\n\n \n &gt; modulo(3, 2)\n Ok(1)\n \n\n \n &gt; modulo(1, 0)\n Error(Nil)\n \n\n \n &gt; modulo(10, -1)\n Ok(0)\n \n\n \n &gt; modulo(13, by: 3)\n Ok(1)\n \n\n \n &gt; modulo(-13, by: 3)\n Ok(2)\n \n\n \n &gt; modulo(13, by: -3)\n Ok(-2)\n \n\n \n &gt; modulo(-13, by: -3)\n Ok(-1)\n \n\nSynonyms:\ngleam/int.modulo\ngleam/int modulo","url":"gleam/int.html#modulo"},{"doc":"gleam/int","title":"multiply","content":"pub fn multiply(a: Int, b: Int) -&gt; Int\n Multiplies two integers together.\n\n It&#39;s the function equivalent of the `*` operator.\n This function is useful in higher order functions or pipes.\n\n ## Examples\n\n \n &gt; multiply(2, 4)\n 8\n \n\n \n import gleam/list\n &gt; list.fold([2, 3, 4], 1, multiply)\n 24\n \n\n \n &gt; 3 |&gt; multiply(2)\n 6\n \n\nSynonyms:\ngleam/int.multiply\ngleam/int multiply","url":"gleam/int.html#multiply"},{"doc":"gleam/int","title":"negate","content":"pub fn negate(x: Int) -&gt; Int\n Returns the negative of the value provided.\n\n ## Examples\n\n \n &gt; negate(1)\n -1\n \n\nSynonyms:\ngleam/int.negate\ngleam/int negate","url":"gleam/int.html#negate"},{"doc":"gleam/int","title":"parse","content":"pub fn parse(string: String) -&gt; Result(Int, Nil)\n Parses a given string as an int if possible.\n\n ## Examples\n\n \n &gt; parse(&quot;2&quot;)\n Ok(2)\n \n\n \n &gt; parse(&quot;ABC&quot;)\n Error(Nil)\n \n\nSynonyms:\ngleam/int.parse\ngleam/int parse","url":"gleam/int.html#parse"},{"doc":"gleam/int","title":"power","content":"pub fn power(base: Int, of exponent: Float) -&gt; Result(Float, Nil)\n Returns the results of the base being raised to the power of the\n exponent, as a `Float`.\n\n ## Examples\n\n \n &gt; power(2, -1.0)\n Ok(0.5)\n \n\n \n &gt; power(2, 2.0)\n Ok(4.0)\n \n\n \n &gt; power(8, 1.5)\n Ok(22.627416997969522)\n \n\n \n &gt; 4 |&gt; power(of: 2.0)\n Ok(16.0)\n \n\n \n &gt; power(-1, 0.5)\n Error(Nil)\n \n\nSynonyms:\ngleam/int.power\ngleam/int power","url":"gleam/int.html#power"},{"doc":"gleam/int","title":"product","content":"pub fn product(numbers: List(Int)) -&gt; Int\n Multiplies a list of ints and returns the product.\n\n ## Example\n\n \n &gt; product([2, 3, 4])\n 24\n \n\nSynonyms:\ngleam/int.product\ngleam/int product","url":"gleam/int.html#product"},{"doc":"gleam/int","title":"random","content":"pub fn random(min: Int, max: Int) -&gt; Int\n Generates a random int between the given minimum and maximum values.\n\n ## Examples\n\n \n &gt; random(1, 5)\n 2\n \n\nSynonyms:\ngleam/int.random\ngleam/int random","url":"gleam/int.html#random"},{"doc":"gleam/int","title":"remainder","content":"pub fn remainder(\n  dividend: Int,\n  by divisor: Int,\n) -&gt; Result(Int, Nil)\n Computes the remainder of an integer division of inputs as a `Result`.\n\n Returns division of the inputs as a `Result`: If the given divisor equals\n `0`, this function returns an `Error`.\n\n Most the time you will want to use the `%` operator instead of this\n function.\n\n ## Examples\n\n \n &gt; remainder(3, 2)\n Ok(1)\n \n\n \n &gt; remainder(1, 0)\n Error(Nil)\n \n\n \n &gt; remainder(10, -1)\n Ok(0)\n \n\n \n &gt; remainder(13, by: 3)\n Ok(1)\n \n\n \n &gt; remainder(-13, by: 3)\n Ok(-1)\n \n\n \n &gt; remainder(13, by: -3)\n Ok(1)\n \n\n \n &gt; remainder(-13, by: -3)\n Ok(-1)\n \n\nSynonyms:\ngleam/int.remainder\ngleam/int remainder","url":"gleam/int.html#remainder"},{"doc":"gleam/int","title":"square_root","content":"pub fn square_root(x: Int) -&gt; Result(Float, Nil)\n Returns the square root of the input as a `Float`.\n\n ## Examples\n\n \n &gt; square_root(4)\n Ok(2.0)\n \n\n \n &gt; square_root(-16)\n Error(Nil)\n \n\nSynonyms:\ngleam/int.square_root\ngleam/int square_root","url":"gleam/int.html#square_root"},{"doc":"gleam/int","title":"subtract","content":"pub fn subtract(a: Int, b: Int) -&gt; Int\n Subtracts one int from another.\n\n It&#39;s the function equivalent of the `-` operator.\n This function is useful in higher order functions or pipes.\n\n ## Examples\n\n \n &gt; subtract(3, 1)\n 2.0\n \n\n \n import gleam/list\n &gt; list.fold([1, 2, 3], 10, subtract)\n 4\n \n\n \n &gt; 3 |&gt; subtract(2)\n 1\n \n\n \n &gt; 3 |&gt; subtract(2, _)\n -1\n \n\nSynonyms:\ngleam/int.subtract\ngleam/int subtract","url":"gleam/int.html#subtract"},{"doc":"gleam/int","title":"sum","content":"pub fn sum(numbers: List(Int)) -&gt; Int\n Sums a list of ints.\n\n ## Example\n\n \n &gt; sum([1, 2, 3])\n 6\n \n\nSynonyms:\ngleam/int.sum\ngleam/int sum","url":"gleam/int.html#sum"},{"doc":"gleam/int","title":"to_base16","content":"pub fn to_base16(x: Int) -&gt; String\n Prints a given int to a string using base-16.\n\n ## Examples\n\n \n &gt; to_base16(48)\n &quot;30&quot;\n \n\nSynonyms:\ngleam/int.to_base16\ngleam/int to_base16","url":"gleam/int.html#to_base16"},{"doc":"gleam/int","title":"to_base2","content":"pub fn to_base2(x: Int) -&gt; String\n Prints a given int to a string using base-2.\n\n ## Examples\n\n \n &gt; to_base2(2)\n &quot;10&quot;\n \n\nSynonyms:\ngleam/int.to_base2\ngleam/int to_base2","url":"gleam/int.html#to_base2"},{"doc":"gleam/int","title":"to_base36","content":"pub fn to_base36(x: Int) -&gt; String\n Prints a given int to a string using base-36.\n\n ## Examples\n\n \n &gt; to_base36(48)\n &quot;1C&quot;\n \n\nSynonyms:\ngleam/int.to_base36\ngleam/int to_base36","url":"gleam/int.html#to_base36"},{"doc":"gleam/int","title":"to_base8","content":"pub fn to_base8(x: Int) -&gt; String\n Prints a given int to a string using base-8.\n\n ## Examples\n\n \n &gt; to_base8(15)\n &quot;17&quot;\n \n\nSynonyms:\ngleam/int.to_base8\ngleam/int to_base8","url":"gleam/int.html#to_base8"},{"doc":"gleam/int","title":"to_base_string","content":"pub fn to_base_string(\n  x: Int,\n  base: Int,\n) -&gt; Result(String, InvalidBase)\n Prints a given int to a string using the base number provided.\n Supports only bases 2 to 36, for values outside of which this function returns an `Error(InvalidBase)`.\n For common bases (2, 8, 16, 36), use the `to_baseN` functions.\n\n ## Examples\n\n \n &gt; to_base_string(2, 2)\n Ok(&quot;10&quot;)\n \n\n \n &gt; to_base_string(48, 16)\n Ok(&quot;30&quot;)\n \n\n \n &gt; to_base_string(48, 36)\n Ok(&quot;1C&quot;)\n \n\n \n &gt; to_base_string(48, 1)\n Error(InvalidBase)\n \n\n \n &gt; to_base_string(48, 37)\n Error(InvalidBase)\n \n\nSynonyms:\ngleam/int.to_base_string\ngleam/int to_base_string","url":"gleam/int.html#to_base_string"},{"doc":"gleam/int","title":"to_float","content":"pub fn to_float(x: Int) -&gt; Float\n Takes an int and returns its value as a float.\n\n ## Examples\n\n \n &gt; to_float(5)\n 5.0\n \n\n \n &gt; to_float(0)\n 0.0\n \n\n \n &gt; to_float(-3)\n -3.0\n \n\nSynonyms:\ngleam/int.to_float\ngleam/int to_float","url":"gleam/int.html#to_float"},{"doc":"gleam/int","title":"to_string","content":"pub fn to_string(x: Int) -&gt; String\n Prints a given int to a string.\n\n ## Examples\n\n \n &gt; to_string(2)\n &quot;2&quot;\n \n\nSynonyms:\ngleam/int.to_string\ngleam/int to_string","url":"gleam/int.html#to_string"},{"doc":"gleam/int","title":"undigits","content":"pub fn undigits(\n  numbers: List(Int),\n  base: Int,\n) -&gt; Result(Int, InvalidBase)\n Joins a list of digits into a single value.\n Returns an error if the base is less than 2 or if the list contains a digit greater than or equal to the specified base.\n\n ## Examples\n\n \n &gt; undigits([2,3,4], 10)\n Ok(234)\n \n\n \n &gt; undigits([2,3,4], 1)\n Error(InvalidBase)\n \n\n \n &gt; undigits([2,3,4], 2)\n Error(InvalidBase)\n \n\nSynonyms:\ngleam/int.undigits\ngleam/int undigits","url":"gleam/int.html#undigits"},{"doc":"gleam/int","title":"gleam/int","content":"","url":"gleam/int.html"},{"doc":"gleam/pair","title":"first","content":"pub fn first(pair: #(a, b)) -&gt; a\n Returns the first element in a pair.\n\n ## Examples\n\n \n &gt; first(#(1, 2))\n 1\n \n\nSynonyms:\ngleam/pair.first\ngleam/pair first","url":"gleam/pair.html#first"},{"doc":"gleam/pair","title":"map_first","content":"pub fn map_first(\n  of pair: #(a, b),\n  with fun: fn(a) -&gt; c,\n) -&gt; #(c, b)\n Returns a new pair with the first element having had `with` applied to\n it.\n\n ## Examples\n\n \n &gt; #(1, 2) |&gt; map_first(fn(n) { n * 2 })\n #(2, 2)\n \n\nSynonyms:\ngleam/pair.map_first\ngleam/pair map_first","url":"gleam/pair.html#map_first"},{"doc":"gleam/pair","title":"map_second","content":"pub fn map_second(\n  of pair: #(a, b),\n  with fun: fn(b) -&gt; c,\n) -&gt; #(a, c)\n Returns a new pair with the second element having had `with` applied to\n it.\n\n ## Examples\n\n \n &gt; #(1, 2) |&gt; map_second(fn(n) { n * 2 })\n #(1, 4)\n \n\nSynonyms:\ngleam/pair.map_second\ngleam/pair map_second","url":"gleam/pair.html#map_second"},{"doc":"gleam/pair","title":"new","content":"pub fn new(first: a, second: b) -&gt; #(a, b)\n Returns a new pair with the given elements. This can also be done using the dedicated\n syntax instead: `new(1, 2) == #(1, 2)`.\n \n ## Examples\n \n \n &gt; new(1, 2)\n #(1, 2)\n \n \nSynonyms:\ngleam/pair.new\ngleam/pair new","url":"gleam/pair.html#new"},{"doc":"gleam/pair","title":"second","content":"pub fn second(pair: #(a, b)) -&gt; b\n Returns the second element in a pair.\n\n ## Examples\n\n \n &gt; second(#(1, 2))\n 2\n \n\nSynonyms:\ngleam/pair.second\ngleam/pair second","url":"gleam/pair.html#second"},{"doc":"gleam/pair","title":"swap","content":"pub fn swap(pair: #(a, b)) -&gt; #(b, a)\n Returns a new pair with the elements swapped.\n\n ## Examples\n\n \n &gt; swap(#(1, 2))\n #(2, 1)\n \n\nSynonyms:\ngleam/pair.swap\ngleam/pair swap","url":"gleam/pair.html#swap"},{"doc":"gleam/pair","title":"gleam/pair","content":"","url":"gleam/pair.html"},{"doc":"gleam/option","title":"Option","content":"pub type Option(a) {\n  Some(a)\n  None\n}\n `Option` represents a value that may be present or not. `Some` means the value is\n present, `None` means the value is not.\n\n This is Gleam&#39;s alternative to having a value that could be Null, as is\n possible in some other languages.\n\nSome(a)\n\n\nNone\n\n\nSynonyms:\ngleam/option.Option\ngleam/option Option","url":"gleam/option.html#Option"},{"doc":"gleam/option","title":"all","content":"pub fn all(list: List(Option(a))) -&gt; Option(List(a))\n Combines a list of `Option`s into a single `Option`.\n If all elements in the list are `Some` then returns a `Some` holding the list of values.\n If any element is `None` then returns`None`.\n\n ## Examples\n\n \n &gt; all([Some(1), Some(2)])\n Some([1, 2])\n \n\n \n &gt; all([Some(1), None])\n None\n \n\nSynonyms:\ngleam/option.all\ngleam/option all","url":"gleam/option.html#all"},{"doc":"gleam/option","title":"flatten","content":"pub fn flatten(option: Option(Option(a))) -&gt; Option(a)\n Merges a nested `Option` into a single layer.\n\n ## Examples\n\n \n &gt; flatten(Some(Some(1)))\n Some(1)\n \n\n \n &gt; flatten(Some(None))\n None\n \n\n \n &gt; flatten(None)\n None\n \n\nSynonyms:\ngleam/option.flatten\ngleam/option flatten","url":"gleam/option.html#flatten"},{"doc":"gleam/option","title":"from_result","content":"pub fn from_result(result: Result(a, b)) -&gt; Option(a)\n Converts a `Result` type to an `Option` type.\n\n ## Examples\n\n \n &gt; from_result(Ok(1))\n Some(1)\n \n\n \n &gt; from_result(Error(&quot;some_error&quot;))\n None\n \n\nSynonyms:\ngleam/option.from_result\ngleam/option from_result","url":"gleam/option.html#from_result"},{"doc":"gleam/option","title":"is_none","content":"pub fn is_none(option: Option(a)) -&gt; Bool\n Checks whether the `Option` is a `None` value.\n\n ## Examples\n\n \n &gt; is_none(Some(1))\n False\n \n\n \n &gt; is_none(None)\n True\n \n\nSynonyms:\ngleam/option.is_none\ngleam/option is_none","url":"gleam/option.html#is_none"},{"doc":"gleam/option","title":"is_some","content":"pub fn is_some(option: Option(a)) -&gt; Bool\n Checks whether the `Option` is a `Some` value.\n\n ## Examples\n\n \n &gt; is_some(Some(1))\n True\n \n\n \n &gt; is_some(None)\n False\n \n\nSynonyms:\ngleam/option.is_some\ngleam/option is_some","url":"gleam/option.html#is_some"},{"doc":"gleam/option","title":"lazy_or","content":"pub fn lazy_or(\n  first: Option(a),\n  second: fn() -&gt; Option(a),\n) -&gt; Option(a)\n Returns the first value if it is `Some`, otherwise evaluates the given function for a fallback value.\n\n ## Examples\n\n \n &gt; lazy_or(Some(1), fn() { Some(2) })\n Some(1)\n \n\n \n &gt; lazy_or(Some(1), fn() { None })\n Some(1)\n \n\n \n &gt; lazy_or(None, fn() { Some(2) })\n Some(2)\n \n\n \n &gt; lazy_or(None, fn() { None })\n None\n \n\nSynonyms:\ngleam/option.lazy_or\ngleam/option lazy_or","url":"gleam/option.html#lazy_or"},{"doc":"gleam/option","title":"lazy_unwrap","content":"pub fn lazy_unwrap(option: Option(a), or default: fn() -&gt; a) -&gt; a\n Extracts the value from an `Option`, evaluating the default function if the option is `None`.\n\n ## Examples\n\n \n &gt; lazy_unwrap(Some(1), fn() { 0 })\n 1\n \n\n \n &gt; lazy_unwrap(None, fn() { 0 })\n 0\n \n\nSynonyms:\ngleam/option.lazy_unwrap\ngleam/option lazy_unwrap","url":"gleam/option.html#lazy_unwrap"},{"doc":"gleam/option","title":"map","content":"pub fn map(\n  over option: Option(a),\n  with fun: fn(a) -&gt; b,\n) -&gt; Option(b)\n Updates a value held within the `Some` of an `Option` by calling a given function\n on it.\n\n If the `Option` is a `None` rather than `Some`, the function is not called and the\n `Option` stays the same.\n\n ## Examples\n\n \n &gt; map(over: Some(1), with: fn(x) { x + 1 })\n Some(2)\n \n\n \n &gt; map(over: None, with: fn(x) { x + 1 })\n None\n \n\nSynonyms:\ngleam/option.map\ngleam/option map","url":"gleam/option.html#map"},{"doc":"gleam/option","title":"or","content":"pub fn or(first: Option(a), second: Option(a)) -&gt; Option(a)\n Returns the first value if it is `Some`, otherwise returns the second value.\n\n ## Examples\n\n \n &gt; or(Some(1), Some(2))\n Some(1)\n \n\n \n &gt; or(Some(1), None)\n Some(1)\n \n\n \n &gt; or(None, Some(2))\n Some(2)\n \n\n \n &gt; or(None, None)\n None\n \n\nSynonyms:\ngleam/option.or\ngleam/option or","url":"gleam/option.html#or"},{"doc":"gleam/option","title":"then","content":"pub fn then(\n  option: Option(a),\n  apply fun: fn(a) -&gt; Option(b),\n) -&gt; Option(b)\n Updates a value held within the `Some` of an `Option` by calling a given function\n on it, where the given function also returns an `Option`. The two options are\n then merged together into one `Option`.\n\n If the `Option` is a `None` rather than `Some` the function is not called and the\n option stays the same.\n\n This function is the equivalent of calling `map` followed by `flatten`, and\n it is useful for chaining together multiple functions that return `Option`.\n\n ## Examples\n\n \n &gt; then(Some(1), fn(x) { Some(x + 1) })\n Some(2)\n \n\n \n &gt; then(Some(1), fn(x) { Some(#(&quot;a&quot;, x)) })\n Some(#(&quot;a&quot;, 1))\n \n\n \n &gt; then(Some(1), fn(_) { None })\n None\n \n\n \n &gt; then(None, fn(x) { Some(x + 1) })\n None\n \n\nSynonyms:\ngleam/option.then\ngleam/option then","url":"gleam/option.html#then"},{"doc":"gleam/option","title":"to_result","content":"pub fn to_result(option: Option(a), e: b) -&gt; Result(a, b)\n Converts an `Option` type to a `Result` type.\n\n ## Examples\n\n \n &gt; to_result(Some(1), &quot;some_error&quot;)\n Ok(1)\n \n\n \n &gt; to_result(None, &quot;some_error&quot;)\n Error(&quot;some_error&quot;)\n \n\nSynonyms:\ngleam/option.to_result\ngleam/option to_result","url":"gleam/option.html#to_result"},{"doc":"gleam/option","title":"unwrap","content":"pub fn unwrap(option: Option(a), or default: a) -&gt; a\n Extracts the value from an `Option`, returning a default value if there is none.\n\n ## Examples\n\n \n &gt; unwrap(Some(1), 0)\n 1\n \n\n \n &gt; unwrap(None, 0)\n 0\n \n\nSynonyms:\ngleam/option.unwrap\ngleam/option unwrap","url":"gleam/option.html#unwrap"},{"doc":"gleam/option","title":"values","content":"pub fn values(options: List(Option(a))) -&gt; List(a)\n Given a list of `Option`s,\n returns only the values inside `Some`.\n\n ## Examples\n\n \n &gt; values([Some(1), None, Some(3)])\n [1, 3]\n \n\nSynonyms:\ngleam/option.values\ngleam/option values","url":"gleam/option.html#values"},{"doc":"gleam/option","title":"gleam/option","content":"","url":"gleam/option.html"},{"doc":"gleam/map","title":"Map","content":"pub type Map(key, value)\n A dictionary of keys and values.\n\n Any type can be used for the keys and values of a map, but all the keys\n must be of the same type and all the values must be of the same type.\n\n Each key can only be present in a map once.\n\n Maps are not ordered in any way, and any unintentional ordering is not to\n be relied upon in your code as it may change in future versions of Erlang\n or Gleam.\n\n See [the Erlang map module](https://erlang.org/doc/man/maps.html) for more\n information.\n\n\nSynonyms:\ngleam/map.Map\ngleam/map Map","url":"gleam/map.html#Map"},{"doc":"gleam/map","title":"delete","content":"pub fn delete(from map: Map(a, b), delete key: a) -&gt; Map(a, b)\n Creates a new map from a given map with all the same entries except for the\n one with a given key, if it exists.\n\n ## Examples\n\n \n &gt; delete([#(&quot;a&quot;, 0), #(&quot;b&quot;, 1)], &quot;a&quot;)\n from_list([#(&quot;b&quot;, 1)])\n \n\n \n &gt; delete([#(&quot;a&quot;, 0), #(&quot;b&quot;, 1)], &quot;c&quot;)\n from_list([#(&quot;a&quot;, 0), #(&quot;b&quot;, 1)])\n \n\nSynonyms:\ngleam/map.delete\ngleam/map delete","url":"gleam/map.html#delete"},{"doc":"gleam/map","title":"drop","content":"pub fn drop(\n  from map: Map(a, b),\n  drop disallowed_keys: List(a),\n) -&gt; Map(a, b)\n Creates a new map from a given map with all the same entries except any with\n keys found in a given list.\n\n ## Examples\n\n \n &gt; drop([#(&quot;a&quot;, 0), #(&quot;b&quot;, 1)], [&quot;a&quot;])\n from_list([#(&quot;b&quot;, 2)])\n \n\n \n &gt; delete([#(&quot;a&quot;, 0), #(&quot;b&quot;, 1)], [&quot;c&quot;])\n from_list([#(&quot;a&quot;, 0), #(&quot;b&quot;, 1)])\n \n\n \n &gt; drop([#(&quot;a&quot;, 0), #(&quot;b&quot;, 1)], [&quot;a&quot;, &quot;b&quot;, &quot;c&quot;])\n from_list([])\n \n\nSynonyms:\ngleam/map.drop\ngleam/map drop","url":"gleam/map.html#drop"},{"doc":"gleam/map","title":"filter","content":"pub fn filter(\n  in map: Map(a, b),\n  keeping predicate: fn(a, b) -&gt; Bool,\n) -&gt; Map(a, b)\n Creates a new map from a given map, minus any entries that a given function\n returns `False` for.\n\n ## Examples\n\n \n &gt; from_list([#(&quot;a&quot;, 0), #(&quot;b&quot;, 1)])\n &gt; |&gt; filter(fn(key, value) { value != 0 })\n from_list([#(&quot;b&quot;, 1)])\n \n\n \n &gt; from_list([#(&quot;a&quot;, 0), #(&quot;b&quot;, 1)])\n &gt; |&gt; filter(fn(key, value) { True })\n from_list([#(&quot;a&quot;, 0), #(&quot;b&quot;, 1)])\n \n\nSynonyms:\ngleam/map.filter\ngleam/map filter","url":"gleam/map.html#filter"},{"doc":"gleam/map","title":"fold","content":"pub fn fold(\n  over map: Map(a, b),\n  from initial: c,\n  with fun: fn(c, a, b) -&gt; c,\n) -&gt; c\n Combines all entries into a single value by calling a given function on each\n one.\n\n Maps are not ordered so the values are not returned in any specific order. Do\n not write code that relies on the order entries are used by this function\n as it may change in later versions of Gleam or Erlang.\n\n # Examples\n\n \n &gt; let map = from_list([#(&quot;a&quot;, 1), #(&quot;b&quot;, 3), #(&quot;c&quot;, 9)])\n &gt; fold(map, 0, fn(accumulator, key, value) { accumulator + value })\n 13\n \n\n \n &gt; import gleam/string.{append}\n &gt; fold(map, &quot;&quot;, fn(accumulator, key, value) { append(accumulator, key) })\n &quot;abc&quot;\n \n\nSynonyms:\ngleam/map.fold\ngleam/map fold","url":"gleam/map.html#fold"},{"doc":"gleam/map","title":"from_list","content":"pub fn from_list(list: List(#(a, b))) -&gt; Map(a, b)\n Converts a list of 2-element tuples `#(key, value)` to a map.\n\n If two tuples have the same key the last one in the list will be the one\n that is present in the map.\n\nSynonyms:\ngleam/map.from_list\ngleam/map from_list","url":"gleam/map.html#from_list"},{"doc":"gleam/map","title":"get","content":"pub fn get(from: Map(a, b), get: a) -&gt; Result(b, Nil)\n Fetches a value from a map for a given key.\n\n The map may not have a value for the key, so the value is wrapped in a\n `Result`.\n\n ## Examples\n\n \n &gt; new() |&gt; insert(&quot;a&quot;, 0) |&gt; get(&quot;a&quot;)\n Ok(0)\n \n\n \n &gt; new() |&gt; insert(&quot;a&quot;, 0) |&gt; get(&quot;b&quot;)\n Error(Nil)\n \n\nSynonyms:\ngleam/map.get\ngleam/map get","url":"gleam/map.html#get"},{"doc":"gleam/map","title":"has_key","content":"pub fn has_key(map: Map(a, b), key: a) -&gt; Bool\n Determines whether or not a value present in the map for a given key.\n\n ## Examples\n\n \n &gt; new() |&gt; insert(&quot;a&quot;, 0) |&gt; has_key(&quot;a&quot;)\n True\n \n\n \n &gt; new() |&gt; insert(&quot;a&quot;, 0) |&gt; has_key(&quot;b&quot;)\n False\n \n\nSynonyms:\ngleam/map.has_key\ngleam/map has_key","url":"gleam/map.html#has_key"},{"doc":"gleam/map","title":"insert","content":"pub fn insert(\n  into map: Map(a, b),\n  for key: a,\n  insert value: b,\n) -&gt; Map(a, b)\n Inserts a value into the map with the given key.\n\n If the map already has a value for the given key then the value is\n replaced with the new value.\n\n ## Examples\n\n \n &gt; new() |&gt; insert(&quot;a&quot;, 0) |&gt; to_list\n [#(&quot;a&quot;, 0)]\n \n\n \n &gt; new() |&gt; insert(&quot;a&quot;, 0) |&gt; insert(&quot;a&quot;, 5) |&gt; to_list\n [#(&quot;a&quot;, 5)]\n \n\nSynonyms:\ngleam/map.insert\ngleam/map insert","url":"gleam/map.html#insert"},{"doc":"gleam/map","title":"keys","content":"pub fn keys(map: Map(a, b)) -&gt; List(a)\n Gets a list of all keys in a given map.\n\n Maps are not ordered so the keys are not returned in any specific order. Do\n not write code that relies on the order keys are returned by this function\n as it may change in later versions of Gleam or Erlang.\n\n ## Examples\n\n \n &gt; keys([#(&quot;a&quot;, 0), #(&quot;b&quot;, 1)])\n [&quot;a&quot;, &quot;b&quot;]\n \n\nSynonyms:\ngleam/map.keys\ngleam/map keys","url":"gleam/map.html#keys"},{"doc":"gleam/map","title":"map_values","content":"pub fn map_values(\n  in map: Map(a, b),\n  with fun: fn(a, b) -&gt; c,\n) -&gt; Map(a, c)\n Updates all values in a given map by calling a given function on each key\n and value.\n\n ## Examples\n\n \n &gt; [#(3, 3), #(2, 4)]\n &gt; |&gt; from_list\n &gt; |&gt; map_values(fn(key, value) { key * value })\n [#(3, 9), #(2, 8)]\n \n\nSynonyms:\ngleam/map.map_values\ngleam/map map_values","url":"gleam/map.html#map_values"},{"doc":"gleam/map","title":"merge","content":"pub fn merge(\n  into map: Map(a, b),\n  from new_entries: Map(a, b),\n) -&gt; Map(a, b)\n Creates a new map from a pair of given maps by combining their entries.\n\n If there are entries with the same keys in both maps the entry from the\n second map takes precedence.\n\n ## Examples\n\n \n &gt; let a = from_list([#(&quot;a&quot;, 0), #(&quot;b&quot;, 1)])\n &gt; let b = from_list([#(&quot;b&quot;, 2), #(&quot;c&quot;, 3)])\n &gt; merge(a, b)\n from_list([#(&quot;a&quot;, 0), #(&quot;b&quot;, 2), #(&quot;c&quot;, 3)])\n \n\nSynonyms:\ngleam/map.merge\ngleam/map merge","url":"gleam/map.html#merge"},{"doc":"gleam/map","title":"new","content":"pub fn new() -&gt; Map(a, b)\n Creates a fresh map that contains no values.\n\nSynonyms:\ngleam/map.new\ngleam/map new","url":"gleam/map.html#new"},{"doc":"gleam/map","title":"size","content":"pub fn size(map: Map(a, b)) -&gt; Int\n Determines the number of key-value pairs in the map.\n This function runs in constant time and does not need to iterate the map.\n\n ## Examples\n\n \n &gt; new() |&gt; size()\n 0\n \n\n \n &gt; new() |&gt; insert(&quot;key&quot;, &quot;value&quot;) |&gt; size()\n 1\n \n\nSynonyms:\ngleam/map.size\ngleam/map size","url":"gleam/map.html#size"},{"doc":"gleam/map","title":"take","content":"pub fn take(\n  from map: Map(a, b),\n  keeping desired_keys: List(a),\n) -&gt; Map(a, b)\n Creates a new map from a given map, only including any entries for which the\n keys are in a given list.\n\n ## Examples\n\n \n &gt; from_list([#(&quot;a&quot;, 0), #(&quot;b&quot;, 1)])\n &gt; |&gt; take([&quot;b&quot;])\n from_list([#(&quot;b&quot;, 1)])\n \n\n \n &gt; from_list([#(&quot;a&quot;, 0), #(&quot;b&quot;, 1)])\n &gt; |&gt; take([&quot;a&quot;, &quot;b&quot;, &quot;c&quot;])\n from_list([#(&quot;a&quot;, 0), #(&quot;b&quot;, 1)])\n \n\nSynonyms:\ngleam/map.take\ngleam/map take","url":"gleam/map.html#take"},{"doc":"gleam/map","title":"to_list","content":"pub fn to_list(map: Map(a, b)) -&gt; List(#(a, b))\n Converts the map to a list of 2-element tuples `#(key, value)`, one for\n each key-value pair in the map.\n\n The tuples in the list have no specific order.\n\n ## Examples\n\n \n &gt; new() |&gt; to_list()\n []\n \n\n \n &gt; new() |&gt; insert(&quot;key&quot;, 0) |&gt; to_list()\n [#(&quot;key&quot;, 0)]\n \n\nSynonyms:\ngleam/map.to_list\ngleam/map to_list","url":"gleam/map.html#to_list"},{"doc":"gleam/map","title":"update","content":"pub fn update(\n  in map: Map(a, b),\n  update key: a,\n  with fun: fn(Option(b)) -&gt; b,\n) -&gt; Map(a, b)\n Creates a new map with one entry updated using a given function.\n\n If there was not an entry in the map for the given key then the function\n gets `None` as its argument, otherwise it gets `Some(value)`.\n\n ## Example\n\n \n &gt; let increment = fn(x) {\n &gt;   case x {\n &gt;     Some(i) -&gt; i + 1\n &gt;     None -&gt; 0\n &gt;   }\n &gt; }\n &gt; let map = from_list([#(&quot;a&quot;, 0)])\n &gt;\n &gt; update(map, &quot;a&quot;, increment)\n from_list([#(&quot;a&quot;, 1)])\n \n\n \n &gt; update(map, &quot;b&quot;, increment)\n from_list([#(&quot;a&quot;, 0), #(&quot;b&quot;, 0)])\n \n\nSynonyms:\ngleam/map.update\ngleam/map update","url":"gleam/map.html#update"},{"doc":"gleam/map","title":"values","content":"pub fn values(map: Map(a, b)) -&gt; List(b)\n Gets a list of all values in a given map.\n\n Maps are not ordered so the values are not returned in any specific order. Do\n not write code that relies on the order values are returned by this function\n as it may change in later versions of Gleam or Erlang.\n\n ## Examples\n\n \n &gt; values(from_list([#(&quot;a&quot;, 0), #(&quot;b&quot;, 1)]))\n [0, 1]\n \n\nSynonyms:\ngleam/map.values\ngleam/map values","url":"gleam/map.html#values"},{"doc":"gleam/map","title":"gleam/map","content":"","url":"gleam/map.html"},{"doc":"gleam/list","title":"ContinueOrStop","content":"pub type ContinueOrStop(a) {\n  Continue(a)\n  Stop(a)\n}\n\nContinue(a)\n\n\nStop(a)\n\n\nSynonyms:\ngleam/list.ContinueOrStop\ngleam/list ContinueOrStop","url":"gleam/list.html#ContinueOrStop"},{"doc":"gleam/list","title":"LengthMismatch","content":"pub type LengthMismatch {\n  LengthMismatch\n}\n An error value returned by the `strict_zip` function.\n\nLengthMismatch\n\n\nSynonyms:\ngleam/list.LengthMismatch\ngleam/list LengthMismatch","url":"gleam/list.html#LengthMismatch"},{"doc":"gleam/list","title":"all","content":"pub fn all(\n  in list: List(a),\n  satisfying predicate: fn(a) -&gt; Bool,\n) -&gt; Bool\n Returns `True` if the given function returns `True` for all the elements in\n the given list. If the function returns `False` for any of the elements it\n immediately returns `False` without checking the rest of the list.\n\n ## Examples\n\n \n &gt; all([], fn(x) { x &gt; 3 })\n True\n \n\n \n &gt; all([4, 5], fn(x) { x &gt; 3 })\n True\n \n\n \n &gt; all([4, 3], fn(x) { x &gt; 3 })\n False\n \n\nSynonyms:\ngleam/list.all\ngleam/list all","url":"gleam/list.html#all"},{"doc":"gleam/list","title":"any","content":"pub fn any(\n  in list: List(a),\n  satisfying predicate: fn(a) -&gt; Bool,\n) -&gt; Bool\n Returns `True` if the given function returns `True` for any the elements in\n the given list. If the function returns `True` for any of the elements it\n immediately returns `True` without checking the rest of the list.\n\n ## Examples\n\n \n &gt; any([], fn(x) { x &gt; 3 })\n False\n \n\n \n &gt; any([4, 5], fn(x) { x &gt; 3 })\n True\n \n\n \n &gt; any([4, 3], fn(x) { x &gt; 4 })\n False\n \n\n \n &gt; any([3, 4], fn(x) { x &gt; 3 })\n True\n \n\nSynonyms:\ngleam/list.any\ngleam/list any","url":"gleam/list.html#any"},{"doc":"gleam/list","title":"append","content":"pub fn append(first: List(a), second: List(a)) -&gt; List(a)\n Joins one list onto the end of another.\n\n This function runs in linear time, and it traverses and copies the first\n list.\n\n ## Examples\n\n \n &gt; append([1, 2], [3])\n [1, 2, 3]\n \n\nSynonyms:\ngleam/list.append\ngleam/list append","url":"gleam/list.html#append"},{"doc":"gleam/list","title":"at","content":"pub fn at(in list: List(a), get index: Int) -&gt; Result(a, Nil)\n Returns the element in the Nth position in the list, with 0 being the first\n position.\n\n `Error(Nil)` is returned if the list is not long enough for the given index\n or if the index is less than 0.\n\n ## Examples\n\n \n &gt; at([1, 2, 3], 1)\n Ok(2)\n \n\n \n &gt; at([1, 2, 3], 5)\n Error(Nil)\n \n\nSynonyms:\ngleam/list.at\ngleam/list at","url":"gleam/list.html#at"},{"doc":"gleam/list","title":"chunk","content":"pub fn chunk(in list: List(a), by f: fn(a) -&gt; b) -&gt; List(List(a))\n Returns a list of chunks in which\n the return value of calling `f` on each element is the same.\n\n ## Examples\n\n \n &gt; [1, 2, 2, 3, 4, 4, 6, 7, 7] |&gt; chunk(by: fn(n) { n % 2 })\n [[1], [2, 2], [3], [4, 4, 6], [7, 7]]\n \n\nSynonyms:\ngleam/list.chunk\ngleam/list chunk","url":"gleam/list.html#chunk"},{"doc":"gleam/list","title":"combination_pairs","content":"pub fn combination_pairs(items: List(a)) -&gt; List(#(a, a))\n Return unique pair combinations of elements in the list\n\n ## Examples\n\n \n &gt; combination_pairs([1, 2, 3])\n [#(1, 2), #(1, 3), #(2, 3)]\n \n\nSynonyms:\ngleam/list.combination_pairs\ngleam/list combination_pairs","url":"gleam/list.html#combination_pairs"},{"doc":"gleam/list","title":"combinations","content":"pub fn combinations(items: List(a), by n: Int) -&gt; List(List(a))\n Return unique combinations of elements in the list.\n\n ## Examples\n\n \n &gt; combinations([1, 2, 3], 2)\n [[1, 2], [1, 3], [2, 3]]\n \n\n \n &gt; combinations([1, 2, 3, 4], 3)\n [[1, 2, 3], [1, 2, 4], [1, 3, 4], [2, 3, 4]]\n \n\nSynonyms:\ngleam/list.combinations\ngleam/list combinations","url":"gleam/list.html#combinations"},{"doc":"gleam/list","title":"concat","content":"pub fn concat(lists: List(List(a))) -&gt; List(a)\n Joins a list of lists into a single list.\n\n This function traverses all elements twice.\n\n ## Examples\n\n \n &gt; concat([[1], [2, 3], []])\n [1, 2, 3]\n \n\nSynonyms:\ngleam/list.concat\ngleam/list concat","url":"gleam/list.html#concat"},{"doc":"gleam/list","title":"contains","content":"pub fn contains(list: List(a), any elem: a) -&gt; Bool\n Determines whether or not a given element exists within a given list.\n\n This function traverses the list to find the element, so it runs in linear\n time.\n\n ## Examples\n\n \n &gt; [] |&gt; contains(any: 0)\n False\n \n\n \n &gt; [0] |&gt; contains(any: 0)\n True\n \n\n \n &gt; [1] |&gt; contains(any: 0)\n False\n \n\n \n &gt; [1, 1] |&gt; contains(any: 0)\n False\n \n\n \n &gt; [1, 0] |&gt; contains(any: 0)\n True\n \n\nSynonyms:\ngleam/list.contains\ngleam/list contains","url":"gleam/list.html#contains"},{"doc":"gleam/list","title":"drop","content":"pub fn drop(from list: List(a), up_to n: Int) -&gt; List(a)\n Returns a list that is the given list with up to the given number of\n elements removed from the front of the list.\n\n If the element has less than the number of elements an empty list is\n returned.\n\n This function runs in linear time but does not copy the list.\n\n ## Examples\n\n \n &gt; drop([1, 2, 3, 4], 2)\n [3, 4]\n \n\n \n &gt; drop([1, 2, 3, 4], 9)\n []\n \n\nSynonyms:\ngleam/list.drop\ngleam/list drop","url":"gleam/list.html#drop"},{"doc":"gleam/list","title":"drop_while","content":"pub fn drop_while(\n  in list: List(a),\n  satisfying predicate: fn(a) -&gt; Bool,\n) -&gt; List(a)\n Drops the first elements in a given list for which the predicate function returns `True`.\n\n ## Examples\n\n \n &gt; drop_while([1, 2, 3, 4], fn (x) { x &lt; 3 })\n [3, 4]\n \n\nSynonyms:\ngleam/list.drop_while\ngleam/list drop_while","url":"gleam/list.html#drop_while"},{"doc":"gleam/list","title":"each","content":"pub fn each(list: List(a), f: fn(a) -&gt; b) -&gt; Nil\n Calls a function for each element in a list, discarding the return value.\n\n Useful for calling a side effect for every item of a list.\n\n \n &gt; list.each([1, 2, 3], io.println)\n Nil\n \n\nSynonyms:\ngleam/list.each\ngleam/list each","url":"gleam/list.html#each"},{"doc":"gleam/list","title":"filter","content":"pub fn filter(\n  list: List(a),\n  keeping predicate: fn(a) -&gt; Bool,\n) -&gt; List(a)\n Returns a new list containing only the elements from the first list for\n which the given functions returns `True`.\n\n ## Examples\n\n \n &gt; filter([2, 4, 6, 1], fn(x) { x &gt; 2 })\n [4, 6]\n \n\n \n &gt; filter([2, 4, 6, 1], fn(x) { x &gt; 6 })\n []\n \n\nSynonyms:\ngleam/list.filter\ngleam/list filter","url":"gleam/list.html#filter"},{"doc":"gleam/list","title":"filter_map","content":"pub fn filter_map(\n  list: List(a),\n  with fun: fn(a) -&gt; Result(b, c),\n) -&gt; List(b)\n Returns a new list containing only the elements from the first list for\n which the given functions returns `Ok(_)`.\n\n ## Examples\n\n \n &gt; filter_map([2, 4, 6, 1], Error)\n []\n \n\n \n &gt; filter_map([2, 4, 6, 1], fn(x) { Ok(x + 1) })\n [3, 5, 7, 2]\n \n\nSynonyms:\ngleam/list.filter_map\ngleam/list filter_map","url":"gleam/list.html#filter_map"},{"doc":"gleam/list","title":"find","content":"pub fn find(\n  in haystack: List(a),\n  one_that is_desired: fn(a) -&gt; Bool,\n) -&gt; Result(a, Nil)\n Finds the first element in a given list for which the given function returns\n `True`.\n\n Returns `Error(Nil)` if no such element is found.\n\n ## Examples\n\n \n &gt; find([1, 2, 3], fn(x) { x &gt; 2 })\n Ok(3)\n \n\n \n &gt; find([1, 2, 3], fn(x) { x &gt; 4 })\n Error(Nil)\n \n\n \n &gt; find([], fn(_) { True })\n Error(Nil)\n \n\nSynonyms:\ngleam/list.find\ngleam/list find","url":"gleam/list.html#find"},{"doc":"gleam/list","title":"find_map","content":"pub fn find_map(\n  in haystack: List(a),\n  with fun: fn(a) -&gt; Result(b, c),\n) -&gt; Result(b, Nil)\n Finds the first element in a given list for which the given function returns\n `Ok(new_value)`, then returns the wrapped `new_value`.\n\n Returns `Error(Nil)` if no such element is found.\n\n ## Examples\n\n \n &gt; find_map([[], [2], [3]], first)\n Ok(2)\n \n\n \n &gt; find_map([[], []], first)\n Error(Nil)\n \n\n \n &gt; find_map([], first)\n Error(Nil)\n \n\nSynonyms:\ngleam/list.find_map\ngleam/list find_map","url":"gleam/list.html#find_map"},{"doc":"gleam/list","title":"first","content":"pub fn first(list: List(a)) -&gt; Result(a, Nil)\n Gets the first element from the start of the list, if there is one.\n\n ## Examples\n\n \n &gt; first([])\n Error(Nil)\n \n\n \n &gt; first([0])\n Ok(0)\n \n\n \n &gt; first([1, 2])\n Ok(1)\n \n\nSynonyms:\ngleam/list.first\ngleam/list first","url":"gleam/list.html#first"},{"doc":"gleam/list","title":"flat_map","content":"pub fn flat_map(\n  over list: List(a),\n  with fun: fn(a) -&gt; List(b),\n) -&gt; List(b)\n Maps the list with the given function into a list of lists, and then flattens it.\n\n ## Examples\n\n \n &gt; flat_map([2, 4, 6], fn(x) { [x, x + 1] })\n [2, 3, 4, 5, 6, 7]\n \n\nSynonyms:\ngleam/list.flat_map\ngleam/list flat_map","url":"gleam/list.html#flat_map"},{"doc":"gleam/list","title":"flatten","content":"pub fn flatten(lists: List(List(a))) -&gt; List(a)\n This is the same as `concat`: it joins a list of lists into a single\n list.\n \n This function traverses all elements twice.\n \n ## Examples\n \n \n &gt; flatten([[1], [2, 3], []])\n [1, 2, 3]\n \n \nSynonyms:\ngleam/list.flatten\ngleam/list flatten","url":"gleam/list.html#flatten"},{"doc":"gleam/list","title":"fold","content":"pub fn fold(\n  over list: List(a),\n  from initial: b,\n  with fun: fn(b, a) -&gt; b,\n) -&gt; b\n Reduces a list of elements into a single value by calling a given function\n on each element, going from left to right.\n\n `fold([1, 2, 3], 0, add)` is the equivalent of\n `add(add(add(0, 1), 2), 3)`.\n\n This function runs in linear time.\n\nSynonyms:\ngleam/list.fold\ngleam/list fold","url":"gleam/list.html#fold"},{"doc":"gleam/list","title":"fold_right","content":"pub fn fold_right(\n  over list: List(a),\n  from initial: b,\n  with fun: fn(b, a) -&gt; b,\n) -&gt; b\n Reduces a list of elements into a single value by calling a given function\n on each element, going from right to left.\n\n `fold_right([1, 2, 3], 0, add)` is the equivalent of\n `add(add(add(0, 3), 2), 1)`.\n\n This function runs in linear time.\n\n Unlike `fold` this function is not tail recursive. Where possible use\n `fold` instead as it will use less memory.\n\nSynonyms:\ngleam/list.fold_right\ngleam/list fold_right","url":"gleam/list.html#fold_right"},{"doc":"gleam/list","title":"fold_until","content":"pub fn fold_until(\n  over collection: List(a),\n  from accumulator: b,\n  with fun: fn(b, a) -&gt; ContinueOrStop(b),\n) -&gt; b\n A variant of fold that allows to stop folding earlier.\n\n The folding function should return `ContinueOrStop(accumulator)`.\n If the returned value is `Continue(accumulator)` fold_until will try the next value in the list.\n If the returned value is `Stop(accumulator)` fold_until will stop and return that accumulator.\n\n ## Examples\n\n \n [1, 2, 3, 4]\n |&gt; fold_until(0, fn(acc, i) {\n   case i &lt; 3 {\n     True -&gt; Continue(acc + i)\n     False -&gt; Stop(acc)\n   }\n })\n \n\nSynonyms:\ngleam/list.fold_until\ngleam/list fold_until","url":"gleam/list.html#fold_until"},{"doc":"gleam/list","title":"group","content":"pub fn group(\n  list: List(a),\n  by key: fn(a) -&gt; b,\n) -&gt; Map(b, List(a))\n Takes a list and groups the values by a key\n which is built from a key function.\n\n Does not preserve the initial value order.\n\n ## Examples\n\n \n &gt; [Ok(3), Error(&quot;Wrong&quot;), Ok(200), Ok(73)]\n   |&gt; group(by: fn(i) {\n     case i {\n       Ok(_) -&gt; &quot;Successful&quot;\n       Error(_) -&gt; &quot;Failed&quot;\n     }\n   })\n   |&gt; map.to_list\n\n [\n   #(&quot;Failed&quot;, [Error(&quot;Wrong&quot;)]),\n   #(&quot;Successful&quot;, [Ok(73), Ok(200), Ok(3)])\n ]\n\n &gt; group([1,2,3,4,5], by: fn(i) { i - i / 3 * 3 })\n |&gt; map.to_list\n [#(0, [3]), #(1, [4, 1]), #(2, [5, 2])]\n \n\nSynonyms:\ngleam/list.group\ngleam/list group","url":"gleam/list.html#group"},{"doc":"gleam/list","title":"index_fold","content":"pub fn index_fold(\n  over over: List(a),\n  from initial: b,\n  with fun: fn(b, a, Int) -&gt; b,\n) -&gt; b\n Like fold but the folding function also receives the index of the current element.\n\n ## Examples\n\n \n [&quot;a&quot;, &quot;b&quot;, &quot;c&quot;]\n |&gt; index_fold([], fn(acc, item, index) { ... })\n \n\nSynonyms:\ngleam/list.index_fold\ngleam/list index_fold","url":"gleam/list.html#index_fold"},{"doc":"gleam/list","title":"index_map","content":"pub fn index_map(\n  list: List(a),\n  with fun: fn(Int, a) -&gt; b,\n) -&gt; List(b)\n Returns a new list containing only the elements of the first list after the\n function has been applied to each one and their index.\n\n The index starts at 0, so the first element is 0, the second is 1, and so\n on.\n\n ## Examples\n\n \n &gt; index_map([&quot;a&quot;, &quot;b&quot;], fn(i, x) { #(i, x) })\n [#(0, &quot;a&quot;), #(1, &quot;b&quot;)]\n \n\nSynonyms:\ngleam/list.index_map\ngleam/list index_map","url":"gleam/list.html#index_map"},{"doc":"gleam/list","title":"interleave","content":"pub fn interleave(list: List(List(a))) -&gt; List(a)\n Make a list alternating the elements from the given lists\n\n ## Examples\n\n \n &gt; list.interleave([[1, 2], [101, 102], [201, 202]])\n [1, 101, 201, 2, 102, 202]\n \n\nSynonyms:\ngleam/list.interleave\ngleam/list interleave","url":"gleam/list.html#interleave"},{"doc":"gleam/list","title":"intersperse","content":"pub fn intersperse(list: List(a), with elem: a) -&gt; List(a)\n Inserts a given value between each existing element in a given list.\n\n This function runs in linear time and copies the list.\n\n ## Examples\n\n \n &gt; intersperse([1, 1, 1], 2)\n [1, 2, 1, 2, 1]\n \n\n \n &gt; intersperse([], 2)\n []\n \n\nSynonyms:\ngleam/list.intersperse\ngleam/list intersperse","url":"gleam/list.html#intersperse"},{"doc":"gleam/list","title":"is_empty","content":"pub fn is_empty(list: List(a)) -&gt; Bool\n Determines whether or not the list is empty.\n\n This function runs in constant time.\n\n ## Examples\n\n \n &gt; is_empty([])\n True\n \n\n \n &gt; is_empty([1])\n False\n \n\n \n &gt; is_empty([1, 1])\n False\n \n\nSynonyms:\ngleam/list.is_empty\ngleam/list is_empty","url":"gleam/list.html#is_empty"},{"doc":"gleam/list","title":"key_filter","content":"pub fn key_filter(\n  in keyword_list: List(#(a, b)),\n  find desired_key: a,\n) -&gt; List(b)\n Given a list of 2-element tuples, finds all tuples that have a given\n key as the first element and returns the second element.\n\n This function may be useful for interacting with Erlang code where lists of\n tuples are common.\n\n ## Examples\n\n \n &gt; key_filter([#(&quot;a&quot;, 0), #(&quot;b&quot;, 1), #(&quot;a&quot;, 2)], &quot;a&quot;)\n [0, 2]\n \n\n \n &gt; key_filter([#(&quot;a&quot;, 0), #(&quot;b&quot;, 1)], &quot;c&quot;)\n []\n \n\nSynonyms:\ngleam/list.key_filter\ngleam/list key_filter","url":"gleam/list.html#key_filter"},{"doc":"gleam/list","title":"key_find","content":"pub fn key_find(\n  in keyword_list: List(#(a, b)),\n  find desired_key: a,\n) -&gt; Result(b, Nil)\n Given a list of 2-element tuples, finds the first tuple that has a given\n key as the first element and returns the second element.\n\n If no tuple is found with the given key then `Error(Nil)` is returned.\n\n This function may be useful for interacting with Erlang code where lists of\n tuples are common.\n\n ## Examples\n\n \n &gt; key_find([#(&quot;a&quot;, 0), #(&quot;b&quot;, 1)], &quot;a&quot;)\n Ok(0)\n \n\n \n &gt; key_find([#(&quot;a&quot;, 0), #(&quot;b&quot;, 1)], &quot;b&quot;)\n Ok(1)\n \n\n \n &gt; key_find([#(&quot;a&quot;, 0), #(&quot;b&quot;, 1)], &quot;c&quot;)\n Error(Nil)\n \n\nSynonyms:\ngleam/list.key_find\ngleam/list key_find","url":"gleam/list.html#key_find"},{"doc":"gleam/list","title":"key_pop","content":"pub fn key_pop(\n  haystack: List(#(a, b)),\n  key: a,\n) -&gt; Result(#(b, List(#(a, b))), Nil)\n Given a list of 2-element tuples, finds the first tuple that has a given\n key as the first element. This function will return the second element\n of the found tuple and list with tuple removed.\n\n If no tuple is found with the given key then `Error(Nil)` is returned.\n\n ## Examples\n\n \n &gt; key_pop([#(&quot;a&quot;, 0), #(&quot;b&quot;, 1)], &quot;a&quot;)\n Ok(#(0, [#(&quot;b&quot;, 1)]))\n \n\n \n &gt; key_pop([#(&quot;a&quot;, 0), #(&quot;b&quot;, 1)], &quot;b&quot;)\n Ok(#(1, [#(&quot;a&quot;, 0)]))\n \n\n \n &gt; key_pop([#(&quot;a&quot;, 0), #(&quot;b&quot;, 1)], &quot;c&quot;)\n Error(Nil)\n \n\nSynonyms:\ngleam/list.key_pop\ngleam/list key_pop","url":"gleam/list.html#key_pop"},{"doc":"gleam/list","title":"key_set","content":"pub fn key_set(\n  list: List(#(a, b)),\n  key: a,\n  value: b,\n) -&gt; List(#(a, b))\n Given a list of 2-element tuples, inserts a key and value into the list.\n\n If there was already a tuple with the key then it is replaced, otherwise it\n is added to the end of the list.\n\n ## Examples\n\n \n &gt; key_set([#(5, 0), #(4, 1)], 4, 100)\n [#(5, 0), #(4, 100)]\n \n\n \n &gt; key_set([#(5, 0), #(4, 1)], 1, 100)\n [#(5, 0), #(4, 1), #(1, 100)]\n \n\nSynonyms:\ngleam/list.key_set\ngleam/list key_set","url":"gleam/list.html#key_set"},{"doc":"gleam/list","title":"last","content":"pub fn last(list: List(a)) -&gt; Result(a, Nil)\n Returns the last element in the given list.\n\n Returns `Error(Nil)` if the list is empty.\n\n This function runs in linear time.\n For a collection oriented around performant access at either end,\n see `gleam/queue.Queue`.\n\n ## Examples\n\n \n &gt; last([])\n Error(Nil)\n \n\n \n &gt; last([1, 2, 3, 4, 5])\n Ok(5)\n \n\nSynonyms:\ngleam/list.last\ngleam/list last","url":"gleam/list.html#last"},{"doc":"gleam/list","title":"length","content":"pub fn length(of list: List(a)) -&gt; Int\n Counts the number of elements in a given list.\n\n This function has to traverse the list to determine the number of elements,\n so it runs in linear time.\n\n This function is natively implemented by the virtual machine and is highly\n optimised.\n\n ## Examples\n\n \n &gt; length([])\n 0\n \n\n \n &gt; length([1])\n 1\n \n\n \n &gt; length([1, 2])\n 2\n \n\nSynonyms:\ngleam/list.length\ngleam/list length","url":"gleam/list.html#length"},{"doc":"gleam/list","title":"map","content":"pub fn map(list: List(a), with fun: fn(a) -&gt; b) -&gt; List(b)\n Returns a new list containing only the elements of the first list after the\n function has been applied to each one.\n\n ## Examples\n\n \n &gt; map([2, 4, 6], fn(x) { x * 2 })\n [4, 8, 12]\n \n\nSynonyms:\ngleam/list.map\ngleam/list map","url":"gleam/list.html#map"},{"doc":"gleam/list","title":"map2","content":"pub fn map2(\n  list1: List(a),\n  list2: List(b),\n  with fun: fn(a, b) -&gt; c,\n) -&gt; List(c)\n Combines two lists into a single list using the given function.\n \n If a list is longer than the other the extra elements are dropped.\n \n ## Examples\n \n \n &gt; map2([1, 2, 3], [4, 5, 6], fn(x, y) { x + y })\n [5, 7, 9]\n \n \n \n &gt; map2([1, 2], [&quot;a&quot;, &quot;b&quot;, &quot;c&quot;], fn(i, x) { #(i, x) })\n [#(1, &quot;a&quot;), #(2, &quot;b&quot;)]\n \n \nSynonyms:\ngleam/list.map2\ngleam/list map2","url":"gleam/list.html#map2"},{"doc":"gleam/list","title":"map_fold","content":"pub fn map_fold(\n  over list: List(a),\n  from acc: b,\n  with fun: fn(b, a) -&gt; #(b, c),\n) -&gt; #(b, List(c))\n Similar to `map` but also lets you pass around an accumulated value.\n\n ## Examples\n\n \n &gt; map_fold(\n     over: [1, 2, 3],\n     from: 100,\n     with: fn(memo, i) { #(memo + i, i * 2) }\n   )\n #(106, [2, 4, 6])\n \n\nSynonyms:\ngleam/list.map_fold\ngleam/list map_fold","url":"gleam/list.html#map_fold"},{"doc":"gleam/list","title":"new","content":"pub fn new() -&gt; List(a)\n Returns a new empty list.\n\n ## Examples\n\n \n &gt; new()\n []\n \n\nSynonyms:\ngleam/list.new\ngleam/list new","url":"gleam/list.html#new"},{"doc":"gleam/list","title":"partition","content":"pub fn partition(\n  list: List(a),\n  with categorise: fn(a) -&gt; Bool,\n) -&gt; #(List(a), List(a))\n Partitions a list into a tuple/pair of lists\n by a given categorisation function.\n\n ## Examples\n\n \n &gt; [1, 2, 3, 4, 5] |&gt; list.partition(int.is_odd)\n #([1, 3, 5], [2, 4])\n \n\nSynonyms:\ngleam/list.partition\ngleam/list partition","url":"gleam/list.html#partition"},{"doc":"gleam/list","title":"permutations","content":"pub fn permutations(l: List(a)) -&gt; List(List(a))\n Returns all the permutations of a list.\n\n ## Examples\n\n \n &gt; permutations([1, 2])\n [[1, 2], [2, 1]]\n \n\nSynonyms:\ngleam/list.permutations\ngleam/list permutations","url":"gleam/list.html#permutations"},{"doc":"gleam/list","title":"pop","content":"pub fn pop(\n  in haystack: List(a),\n  one_that is_desired: fn(a) -&gt; Bool,\n) -&gt; Result(#(a, List(a)), Nil)\n Removes the first element in a given list for which the predicate function returns `True`.\n\n Returns `Error(Nil)` if no such element is found.\n\n ## Examples\n\n \n &gt; pop([1, 2, 3], fn(x) { x &gt; 2 })\n Ok(#(3, [1, 2]))\n \n\n \n &gt; pop([1, 2, 3], fn(x) { x &gt; 4 })\n Error(Nil)\n \n\n \n &gt; pop([], fn(_) { True })\n Error(Nil)\n \n\nSynonyms:\ngleam/list.pop\ngleam/list pop","url":"gleam/list.html#pop"},{"doc":"gleam/list","title":"pop_map","content":"pub fn pop_map(\n  in haystack: List(a),\n  one_that is_desired: fn(a) -&gt; Result(b, c),\n) -&gt; Result(#(b, List(a)), Nil)\n Removes the first element in a given list for which the given function returns\n `Ok(new_value)`, then returns the wrapped `new_value` as well as list with the value removed.\n\n Returns `Error(Nil)` if no such element is found.\n\n ## Examples\n\n \n &gt; pop_map([[], [2], [3]], first)\n Ok(#(2, [[], [3]]))\n \n\n \n &gt; pop_map([[], []], first)\n Error(Nil)\n \n\n \n &gt; pop_map([], first)\n Error(Nil)\n \n\nSynonyms:\ngleam/list.pop_map\ngleam/list pop_map","url":"gleam/list.html#pop_map"},{"doc":"gleam/list","title":"prepend","content":"pub fn prepend(to list: List(a), this item: a) -&gt; List(a)\n Prefixes an item to a list. This can also be done using the dedicated\n syntax instead\n\n \n let new_list = [1, ..existing_list]\n \n\nSynonyms:\ngleam/list.prepend\ngleam/list prepend","url":"gleam/list.html#prepend"},{"doc":"gleam/list","title":"range","content":"pub fn range(from start: Int, to stop: Int) -&gt; List(Int)\n Creates a list of ints ranging from a given start and finish.\n\n ## Examples\n\n \n &gt; range(0, 0)\n [0]\n \n\n \n &gt; range(0, 5)\n [0, 1, 2, 3, 4, 5]\n \n\n \n &gt; range(1, -5)\n [1, 0, -1, -2, -3, -4, -5]\n \n\nSynonyms:\ngleam/list.range\ngleam/list range","url":"gleam/list.html#range"},{"doc":"gleam/list","title":"reduce","content":"pub fn reduce(\n  over list: List(a),\n  with fun: fn(a, a) -&gt; a,\n) -&gt; Result(a, Nil)\n This function acts similar to fold, but does not take an initial state.\n Instead, it starts from the first element in the list\n and combines it with each subsequent element in turn using the given\n function. The function is called as `fun(accumulator, current_element)`.\n\n Returns `Ok` to indicate a successful run, and `Error` if called on an\n empty list.\n\n ## Examples\n\n \n &gt; [] |&gt; reduce(fn(acc, x) { acc + x })\n Error(Nil)\n \n\n \n &gt; [1, 2, 3, 4, 5] |&gt; reduce(fn(acc, x) { acc + x })\n Ok(15)\n \n\nSynonyms:\ngleam/list.reduce\ngleam/list reduce","url":"gleam/list.html#reduce"},{"doc":"gleam/list","title":"repeat","content":"pub fn repeat(item a: a, times times: Int) -&gt; List(a)\n Builds a list of a given value a given number of times.\n\n ## Examples\n\n \n &gt; repeat(&quot;a&quot;, times: 0)\n []\n \n\n \n &gt; repeat(&quot;a&quot;, times: 5)\n [&quot;a&quot;, &quot;a&quot;, &quot;a&quot;, &quot;a&quot;, &quot;a&quot;]\n \n\nSynonyms:\ngleam/list.repeat\ngleam/list repeat","url":"gleam/list.html#repeat"},{"doc":"gleam/list","title":"rest","content":"pub fn rest(list: List(a)) -&gt; Result(List(a), Nil)\n Returns the list minus the first element. If the list is empty, `Error(Nil)` is\n returned.\n\n This function runs in constant time and does not make a copy of the list.\n\n ## Examples\n\n \n &gt; rest([])\n Error(Nil)\n \n\n \n &gt; rest([0])\n Ok([])\n \n\n \n &gt; rest([1, 2])\n Ok([2])\n \n\nSynonyms:\ngleam/list.rest\ngleam/list rest","url":"gleam/list.html#rest"},{"doc":"gleam/list","title":"reverse","content":"pub fn reverse(xs: List(a)) -&gt; List(a)\n Creates a new list from a given list containing the same elements but in the\n opposite order.\n\n This function has to traverse the list to create the new reversed list, so\n it runs in linear time.\n\n This function is natively implemented by the virtual machine and is highly\n optimised.\n\n ## Examples\n\n \n &gt; reverse([])\n []\n \n\n \n &gt; reverse([1])\n [1]\n \n\n \n &gt; reverse([1, 2])\n [2, 1]\n \n\nSynonyms:\ngleam/list.reverse\ngleam/list reverse","url":"gleam/list.html#reverse"},{"doc":"gleam/list","title":"scan","content":"pub fn scan(\n  over list: List(a),\n  from initial: b,\n  with fun: fn(b, a) -&gt; b,\n) -&gt; List(b)\n Similar to `fold`, but yields the state of the accumulator at each stage.\n\n ## Examples\n\n \n &gt; scan(over: [1, 2, 3], from: 100, with: fn(acc, i) { acc + i })\n [101, 103, 106]\n \n\nSynonyms:\ngleam/list.scan\ngleam/list scan","url":"gleam/list.html#scan"},{"doc":"gleam/list","title":"shuffle","content":"pub fn shuffle(list: List(a)) -&gt; List(a)\n Takes a list, randomly sorts all items and returns the shuffled list.\n\n This function uses Erlang&#39;s `:rand` module or Javascript&#39;s\n `Math.random()` to calculate the index shuffling.\n\n ## Example\n\n \n &gt; range(1, 10)\n &gt; |&gt; shuffle()\n [1, 6, 9, 10, 3, 8, 4, 2, 7, 5]\n \n\nSynonyms:\ngleam/list.shuffle\ngleam/list shuffle","url":"gleam/list.html#shuffle"},{"doc":"gleam/list","title":"sized_chunk","content":"pub fn sized_chunk(\n  in list: List(a),\n  into count: Int,\n) -&gt; List(List(a))\n Returns a list of chunks containing `count` elements each.\n\n If the last chunk does not have `count` elements, it is instead\n a partial chunk, with less than `count` elements.\n\n For any `count` less than 1 this function behaves as if it was set to 1.\n\n ## Examples\n\n \n &gt; [1, 2, 3, 4, 5, 6] |&gt; sized_chunk(into: 2)\n [[1, 2], [3, 4], [5, 6]]\n \n\n \n &gt; [1, 2, 3, 4, 5, 6, 7, 8] |&gt; sized_chunk(into: 3)\n [[1, 2, 3], [4, 5, 6], [7, 8]]\n \n\nSynonyms:\ngleam/list.sized_chunk\ngleam/list sized_chunk","url":"gleam/list.html#sized_chunk"},{"doc":"gleam/list","title":"sort","content":"pub fn sort(\n  list: List(a),\n  by compare: fn(a, a) -&gt; Order,\n) -&gt; List(a)\n Sorts from smallest to largest based upon the ordering specified by a given\n function.\n\n ## Examples\n\n \n &gt; import gleam/int\n &gt; list.sort([4, 3, 6, 5, 4, 1, 2], by: int.compare)\n [1, 2, 3, 4, 4, 5, 6]\n \n\nSynonyms:\ngleam/list.sort\ngleam/list sort","url":"gleam/list.html#sort"},{"doc":"gleam/list","title":"split","content":"pub fn split(\n  list list: List(a),\n  at index: Int,\n) -&gt; #(List(a), List(a))\n Splits a list in two before the given index.\n\n If the list is not long enough to have the given index the before list will\n be the input list, and the after list will be empty.\n\n ## Examples\n\n \n &gt; split([6, 7, 8, 9], 0)\n #([], [6, 7, 8, 9])\n \n\n \n &gt; split([6, 7, 8, 9], 2)\n #([6, 7], [8, 9])\n \n\n \n &gt; split([6, 7, 8, 9], 4)\n #([6, 7, 8, 9], [])\n \n\nSynonyms:\ngleam/list.split\ngleam/list split","url":"gleam/list.html#split"},{"doc":"gleam/list","title":"split_while","content":"pub fn split_while(\n  list list: List(a),\n  satisfying predicate: fn(a) -&gt; Bool,\n) -&gt; #(List(a), List(a))\n Splits a list in two before the first element that a given function returns\n `False` for.\n\n If the function returns `True` for all elements the first list will be the\n input list, and the second list will be empty.\n\n ## Examples\n\n \n &gt; split_while([1, 2, 3, 4, 5], fn(x) { x &lt;= 3 })\n #([1, 2, 3], [4, 5])\n \n\n \n &gt; split_while([1, 2, 3, 4, 5], fn(x) { x &lt;= 5 })\n #([1, 2, 3, 4, 5], [])\n \n\nSynonyms:\ngleam/list.split_while\ngleam/list split_while","url":"gleam/list.html#split_while"},{"doc":"gleam/list","title":"strict_zip","content":"pub fn strict_zip(\n  list: List(a),\n  with other: List(b),\n) -&gt; Result(List(#(a, b)), LengthMismatch)\n Takes two lists and returns a single list of 2-element tuples.\n\n If one of the lists is longer than the other, an `Error` is returned.\n\n ## Examples\n\n \n &gt; strict_zip([], [])\n Ok([])\n \n\n \n &gt; strict_zip([1, 2], [3])\n Error(LengthMismatch)\n \n\n \n &gt; strict_zip([1], [3, 4])\n Error(LengthMismatch)\n \n\n \n &gt; strict_zip([1, 2], [3, 4])\n Ok([#(1, 3), #(2, 4)])\n \n\nSynonyms:\ngleam/list.strict_zip\ngleam/list strict_zip","url":"gleam/list.html#strict_zip"},{"doc":"gleam/list","title":"take","content":"pub fn take(from list: List(a), up_to n: Int) -&gt; List(a)\n Returns a list containing the first given number of elements from the given\n list.\n\n If the element has less than the number of elements then the full list is\n returned.\n\n This function runs in linear time but does not copy the list.\n\n ## Examples\n\n \n &gt; take([1, 2, 3, 4], 2)\n [1, 2]\n \n\n \n &gt; take([1, 2, 3, 4], 9)\n [1, 2, 3, 4]\n \n\nSynonyms:\ngleam/list.take\ngleam/list take","url":"gleam/list.html#take"},{"doc":"gleam/list","title":"take_while","content":"pub fn take_while(\n  in list: List(a),\n  satisfying predicate: fn(a) -&gt; Bool,\n) -&gt; List(a)\n Takes the first elements in a given list for which the predicate function returns `True`.\n\n ## Examples\n\n \n &gt; take_while([1, 2, 3, 2, 4], fn (x) { x &lt; 3 })\n [1, 2]\n \n\nSynonyms:\ngleam/list.take_while\ngleam/list take_while","url":"gleam/list.html#take_while"},{"doc":"gleam/list","title":"transpose","content":"pub fn transpose(list_of_list: List(List(a))) -&gt; List(List(a))\n Transpose rows and columns of the list of lists.\n\n Notice: This function is not tail recursive,\n and thus may exceed stack size if called,\n with large lists (on target JavaScript).\n\n ## Examples\n\n \n &gt; transpose([[1, 2, 3], [101, 102, 103]])\n [[1, 101], [2, 102], [3, 103]]\n \n\nSynonyms:\ngleam/list.transpose\ngleam/list transpose","url":"gleam/list.html#transpose"},{"doc":"gleam/list","title":"try_each","content":"pub fn try_each(\n  over list: List(a),\n  with fun: fn(a) -&gt; Result(b, c),\n) -&gt; Result(Nil, c)\n Calls a `Result` returning function for each element in a list, discarding\n the return value. If the function returns `Error` then the iteration is\n stopped and the error is returned.\n\n Useful for calling a side effect for every item of a list.\n\n ## Examples\n\n \n &gt; try_each(\n &gt;   over: [1, 2, 3],\n &gt;   with: function_that_might_fail,\n &gt; )\n Ok(Nil)\n \n\nSynonyms:\ngleam/list.try_each\ngleam/list try_each","url":"gleam/list.html#try_each"},{"doc":"gleam/list","title":"try_fold","content":"pub fn try_fold(\n  over collection: List(a),\n  from accumulator: b,\n  with fun: fn(b, a) -&gt; Result(b, c),\n) -&gt; Result(b, c)\n A variant of fold that might fail.\n\n The folding function should return `Result(accumulator, error)`.\n If the returned value is `Ok(accumulator)` try_fold will try the next value in the list.\n If the returned value is `Error(error)` try_fold will stop and return that error.\n\n ## Examples\n\n \n [1, 2, 3, 4]\n |&gt; try_fold(0, fn(acc, i) {\n   case i &lt; 3 {\n     True -&gt; Ok(acc + i)\n     False -&gt; Error(Nil)\n   }\n })\n \n\nSynonyms:\ngleam/list.try_fold\ngleam/list try_fold","url":"gleam/list.html#try_fold"},{"doc":"gleam/list","title":"try_map","content":"pub fn try_map(\n  over list: List(a),\n  with fun: fn(a) -&gt; Result(b, c),\n) -&gt; Result(List(b), c)\n Takes a function that returns a `Result` and applies it to each element in a\n given list in turn.\n\n If the function returns `Ok(new_value)` for all elements in the list then a\n list of the new values is returned.\n\n If the function returns `Error(reason)` for any of the elements then it is\n returned immediately. None of the elements in the list are processed after\n one returns an `Error`.\n\n ## Examples\n\n \n &gt; try_map([1, 2, 3], fn(x) { Ok(x + 2) })\n Ok([3, 4, 5])\n \n\n \n &gt; try_map([1, 2, 3], fn(_) { Error(0) })\n Error(0)\n \n\n \n &gt; try_map([[1], [2, 3]], first)\n Ok([1, 2])\n \n\n \n &gt; try_map([[1], [], [2]], first)\n Error(Nil)\n \n\nSynonyms:\ngleam/list.try_map\ngleam/list try_map","url":"gleam/list.html#try_map"},{"doc":"gleam/list","title":"unique","content":"pub fn unique(list: List(a)) -&gt; List(a)\n Removes any duplicate elements from a given list.\n\n This function returns in loglinear time.\n\n ## Examples\n\n \n &gt; unique([1, 1, 1, 4, 7, 3, 3, 4])\n [1, 4, 7, 3]\n \n\nSynonyms:\ngleam/list.unique\ngleam/list unique","url":"gleam/list.html#unique"},{"doc":"gleam/list","title":"unzip","content":"pub fn unzip(input: List(#(a, b))) -&gt; #(List(a), List(b))\n Takes a single list of 2-element tuples and returns two lists.\n\n ## Examples\n\n \n &gt; unzip([#(1, 2), #(3, 4)])\n #([1, 3], [2, 4])\n \n\n \n &gt; unzip([])\n #([], [])\n \n\nSynonyms:\ngleam/list.unzip\ngleam/list unzip","url":"gleam/list.html#unzip"},{"doc":"gleam/list","title":"window","content":"pub fn window(l: List(a), by n: Int) -&gt; List(List(a))\n Returns a list of sliding windows.\n\n ## Examples\n\n \n &gt; window([1,2,3,4,5], 3)\n [[1, 2, 3], [2, 3, 4], [3, 4, 5]]\n \n\n \n &gt; window([1, 2], 4)\n []\n \n\nSynonyms:\ngleam/list.window\ngleam/list window","url":"gleam/list.html#window"},{"doc":"gleam/list","title":"window_by_2","content":"pub fn window_by_2(l: List(a)) -&gt; List(#(a, a))\n Returns a list of tuples containing two contiguous elements.\n\n ## Examples\n\n \n &gt; window_by_2([1,2,3,4])\n [#(1, 2), #(2, 3), #(3, 4)]\n \n\n \n &gt; window_by_2([1])\n []\n \n\nSynonyms:\ngleam/list.window_by_2\ngleam/list window_by_2","url":"gleam/list.html#window_by_2"},{"doc":"gleam/list","title":"zip","content":"pub fn zip(list: List(a), with other: List(b)) -&gt; List(#(a, b))\n Takes two lists and returns a single list of 2-element tuples.\n\n If one of the lists is longer than the other, the remaining elements from\n the longer list are not used.\n\n ## Examples\n\n \n &gt; zip([], [])\n []\n \n\n \n &gt; zip([1, 2], [3])\n [#(1, 3)]\n \n\n \n &gt; zip([1], [3, 4])\n [#(1, 3)]\n \n\n \n &gt; zip([1, 2], [3, 4])\n [#(1, 3), #(2, 4)]\n \n\nSynonyms:\ngleam/list.zip\ngleam/list zip","url":"gleam/list.html#zip"},{"doc":"gleam/list","title":"gleam/list","content":" Lists are an ordered sequence of elements and are one of the most common\n data types in Gleam.\n\n New elements can be added and removed from the front of a list in\n constant time, while adding and removing from the end requires traversing\n the copying the whole list, so keep this in mind when designing your\n programs.\n\n There is a dedicated syntax for prefixing to a list:\n\n ```gleam\n let new_list = [1, 2, ..existing_list]\n ```\n\n And a matching syntax for getting the first elements of a list:\n\n ```gleam\n case list {\n   [first_element, ..rest] -&gt; first_element\n   _ -&gt; &quot;this pattern matches when the list is empty&quot;\n }\n ```\n","url":"gleam/list.html"},{"doc":"gleam/queue","title":"Queue","content":"pub opaque type Queue(element)\n A queue is an ordered collection of elements. It is similar to a list, but\n unlike a list elements can be added to or removed from either the front or\n the back in a performant fashion.\n\n The internal representation may be different for two queues with the same\n elements in the same order if the queues were constructed in different\n ways. This is the price paid for a queue&#39;s fast access at both the front\n and the back.\n\n Because of unpredictable internal representation the equality operator `==`\n may return surprising results, and the `is_equal` and `is_logically_equal`\n functions are the recommended way to test queues for equality.\n\n\nSynonyms:\ngleam/queue.Queue\ngleam/queue Queue","url":"gleam/queue.html#Queue"},{"doc":"gleam/queue","title":"from_list","content":"pub fn from_list(list: List(a)) -&gt; Queue(a)\n Converts a list of elements into a queue of the same elements in the same\n order. The first element in the list becomes the front element in the queue.\n\n This function runs in constant time.\n\n # Examples\n\n \n &gt; [1, 2, 3] |&gt; from_list |&gt; length\n 3\n \n\nSynonyms:\ngleam/queue.from_list\ngleam/queue from_list","url":"gleam/queue.html#from_list"},{"doc":"gleam/queue","title":"is_empty","content":"pub fn is_empty(queue: Queue(a)) -&gt; Bool\n Determines whether or not the queue is empty.\n\n This function runs in constant time.\n\n ## Examples\n\n \n &gt; [] |&gt; from_list |&gt; is_empty\n True\n \n\n \n &gt; [1] |&gt; from_list |&gt; is_empty\n False\n \n\n \n &gt; [1, 2] |&gt; from_list |&gt; is_empty\n False\n \n\nSynonyms:\ngleam/queue.is_empty\ngleam/queue is_empty","url":"gleam/queue.html#is_empty"},{"doc":"gleam/queue","title":"is_equal","content":"pub fn is_equal(a: Queue(a), to b: Queue(a)) -&gt; Bool\n Checks whether two queues have the same elements in the same order.\n\n This function is useful as the internal representation may be different for\n two queues with the same elements in the same order depending on how they\n were constructed, so the equality operator `==` may return surprising\n results.\n\n This function runs in linear time.\n\nSynonyms:\ngleam/queue.is_equal\ngleam/queue is_equal","url":"gleam/queue.html#is_equal"},{"doc":"gleam/queue","title":"is_logically_equal","content":"pub fn is_logically_equal(\n  a: Queue(a),\n  to b: Queue(a),\n  checking element_is_equal: fn(a, a) -&gt; Bool,\n) -&gt; Bool\n Checks whether two queues have equal elements in the same order, where the\n equality of elements is determined by a given equality checking function.\n\n This function is useful as the internal representation may be different for\n two queues with the same elements in the same order depending on how they\n were constructed, so the equality operator `==` may return surprising\n results.\n\n This function runs in linear time multiplied by the time taken by the\n element equality checking function.\n\nSynonyms:\ngleam/queue.is_logically_equal\ngleam/queue is_logically_equal","url":"gleam/queue.html#is_logically_equal"},{"doc":"gleam/queue","title":"length","content":"pub fn length(queue: Queue(a)) -&gt; Int\n Counts the number of elements in a given queue.\n\n This function has to traverse the queue to determine the number of elements,\n so it runs in linear time.\n\n ## Examples\n\n \n &gt; length(from_list([]))\n 0\n \n\n \n &gt; length(from_list([1]))\n 1\n \n\n \n &gt; length(from_list([1, 2]))\n 2\n \n\nSynonyms:\ngleam/queue.length\ngleam/queue length","url":"gleam/queue.html#length"},{"doc":"gleam/queue","title":"new","content":"pub fn new() -&gt; Queue(a)\n Creates a fresh queue that contains no values.\n\nSynonyms:\ngleam/queue.new\ngleam/queue new","url":"gleam/queue.html#new"},{"doc":"gleam/queue","title":"pop_back","content":"pub fn pop_back(\n  from queue: Queue(a),\n) -&gt; Result(#(a, Queue(a)), Nil)\n Gets the last element from the queue, returning the\n element and a new queue without that element.\n\n This function typically runs in constant time, but will occasionally run in\n linear time.\n\n # Examples\n\n \n &gt; new()\n &gt; |&gt; push_back(0)\n &gt; |&gt; push_back(1)\n &gt; |&gt; pop_back()\n Ok(#(1, push_front(new(), 0)))\n \n\n \n &gt; new()\n &gt; |&gt; push_front(0)\n &gt; |&gt; pop_back()\n Ok(#(0, new()))\n \n\n \n &gt; new()\n &gt; |&gt; pop_back()\n Error(Nil)\n \n\nSynonyms:\ngleam/queue.pop_back\ngleam/queue pop_back","url":"gleam/queue.html#pop_back"},{"doc":"gleam/queue","title":"pop_front","content":"pub fn pop_front(\n  from queue: Queue(a),\n) -&gt; Result(#(a, Queue(a)), Nil)\n Gets the first element from the queue, returning the\n element and a new queue without that element.\n\n This function typically runs in constant time, but will occasionally run in\n linear time.\n\n # Examples\n\n \n &gt; queue.new()\n &gt; |&gt; queue.push_front(1)\n &gt; |&gt; queue.push_front(0)\n &gt; |&gt; queue.pop_front()\n Ok(#(0, queue.push_back(queue.new(), 1)))\n \n\n \n &gt; queue.new()\n &gt; |&gt; queue.push_back(0)\n &gt; |&gt; queue.pop_front()\n Ok(#(0, queue.new()))\n \n\n \n &gt; queue.new()\n &gt; |&gt; queue.pop_back()\n Error(Nil)\n \n\nSynonyms:\ngleam/queue.pop_front\ngleam/queue pop_front","url":"gleam/queue.html#pop_front"},{"doc":"gleam/queue","title":"push_back","content":"pub fn push_back(onto queue: Queue(a), this item: a) -&gt; Queue(a)\n Pushes an element onto the back of the queue.\n\n # Examples\n\n \n &gt; [1, 2] |&gt; from_list |&gt; push_back(3) |&gt; to_list\n [1, 2, 3]\n \n\nSynonyms:\ngleam/queue.push_back\ngleam/queue push_back","url":"gleam/queue.html#push_back"},{"doc":"gleam/queue","title":"push_front","content":"pub fn push_front(onto queue: Queue(a), this item: a) -&gt; Queue(a)\n Pushes an element onto the front of the queue.\n\n # Examples\n\n \n &gt; [0, 0] |&gt; from_list |&gt; push_front(1) |&gt; to_list\n [1, 0, 0]\n \n\nSynonyms:\ngleam/queue.push_front\ngleam/queue push_front","url":"gleam/queue.html#push_front"},{"doc":"gleam/queue","title":"reverse","content":"pub fn reverse(queue: Queue(a)) -&gt; Queue(a)\n Creates a new queue from a given queue containing the same elements, but in\n the opposite order.\n\n This function runs in constant time.\n\n ## Examples\n\n \n &gt; [] |&gt; from_list |&gt; reverse |&gt; to_list\n []\n \n\n \n &gt; [1] |&gt; from_list |&gt; reverse |&gt; to_list\n [1]\n \n\n \n &gt; [1, 2] |&gt; from_list |&gt; reverse |&gt; to_list\n [2, 1]\n \n\nSynonyms:\ngleam/queue.reverse\ngleam/queue reverse","url":"gleam/queue.html#reverse"},{"doc":"gleam/queue","title":"to_list","content":"pub fn to_list(queue: Queue(a)) -&gt; List(a)\n Converts a queue of elements into a list of the same elements in the same\n order. The front element in the queue becomes the first element in the list.\n\n This function runs in linear time.\n\n # Examples\n\n \n &gt; new() |&gt; push_back(1) |&gt; push_back(2) |&gt; to_list\n [1, 2]\n \n\nSynonyms:\ngleam/queue.to_list\ngleam/queue to_list","url":"gleam/queue.html#to_list"},{"doc":"gleam/queue","title":"gleam/queue","content":"","url":"gleam/queue.html"},{"doc":"gleam/result","title":"all","content":"pub fn all(results: List(Result(a, b))) -&gt; Result(List(a), b)\n Combines a list of results into a single result.\n If all elements in the list are `Ok` then returns an `Ok` holding the list of values.\n If any element is `Error` then returns the first error.\n\n ## Examples\n\n \n &gt; all([Ok(1), Ok(2)])\n Ok([1, 2])\n \n\n \n &gt; all([Ok(1), Error(&quot;e&quot;)])\n Error(&quot;e&quot;)\n \n\nSynonyms:\ngleam/result.all\ngleam/result all","url":"gleam/result.html#all"},{"doc":"gleam/result","title":"flatten","content":"pub fn flatten(result: Result(Result(a, b), b)) -&gt; Result(a, b)\n Merges a nested `Result` into a single layer.\n\n ## Examples\n\n \n &gt; flatten(Ok(Ok(1)))\n Ok(1)\n \n\n \n &gt; flatten(Ok(Error(&quot;&quot;)))\n Error(&quot;&quot;)\n \n\n \n &gt; flatten(Error(Nil))\n Error(Nil)\n \n\nSynonyms:\ngleam/result.flatten\ngleam/result flatten","url":"gleam/result.html#flatten"},{"doc":"gleam/result","title":"is_error","content":"pub fn is_error(result: Result(a, b)) -&gt; Bool\n Checks whether the result is an `Error` value.\n\n ## Examples\n\n \n &gt; is_error(Ok(1))\n False\n \n\n \n &gt; is_error(Error(Nil))\n True\n \n\nSynonyms:\ngleam/result.is_error\ngleam/result is_error","url":"gleam/result.html#is_error"},{"doc":"gleam/result","title":"is_ok","content":"pub fn is_ok(result: Result(a, b)) -&gt; Bool\n Checks whether the result is an `Ok` value.\n\n ## Examples\n\n \n &gt; is_ok(Ok(1))\n True\n \n\n \n &gt; is_ok(Error(Nil))\n False\n \n\nSynonyms:\ngleam/result.is_ok\ngleam/result is_ok","url":"gleam/result.html#is_ok"},{"doc":"gleam/result","title":"lazy_or","content":"pub fn lazy_or(\n  first: Result(a, b),\n  second: fn() -&gt; Result(a, b),\n) -&gt; Result(a, b)\n Returns the first value if it is `Ok`, otherwise evaluates the given function for a fallback value.\n\n ## Examples\n\n \n &gt; lazy_or(Ok(1), fn() { Ok(2) })\n Ok(1)\n \n\n \n &gt; lazy_or(Ok(1), fn() { Error(&quot;Error 2&quot;) })\n Ok(1)\n \n\n \n &gt; lazy_or(Error(&quot;Error 1&quot;), fn() { Ok(2) })\n Ok(2)\n \n\n \n &gt; lazy_or(Error(&quot;Error 1&quot;), fn() { Error(&quot;Error 2&quot;) })\n Error(&quot;Error 2&quot;)\n \n\nSynonyms:\ngleam/result.lazy_or\ngleam/result lazy_or","url":"gleam/result.html#lazy_or"},{"doc":"gleam/result","title":"lazy_unwrap","content":"pub fn lazy_unwrap(\n  result: Result(a, b),\n  or default: fn() -&gt; a,\n) -&gt; a\n Extracts the `Ok` value from a result, evaluating the default function if the result\n is an `Error`.\n\n ## Examples\n\n \n &gt; lazy_unwrap(Ok(1), fn() { 0 })\n 1\n \n\n \n &gt; lazy_unwrap(Error(&quot;&quot;), fn() { 0 })\n 0\n \n\nSynonyms:\ngleam/result.lazy_unwrap\ngleam/result lazy_unwrap","url":"gleam/result.html#lazy_unwrap"},{"doc":"gleam/result","title":"map","content":"pub fn map(\n  over result: Result(a, b),\n  with fun: fn(a) -&gt; c,\n) -&gt; Result(c, b)\n Updates a value held within the `Ok` of a result by calling a given function\n on it.\n\n If the result is an `Error` rather than `Ok` the function is not called and the\n result stays the same.\n\n ## Examples\n\n \n &gt; map(over: Ok(1), with: fn(x) { x + 1 })\n Ok(2)\n \n\n \n &gt; map(over: Error(1), with: fn(x) { x + 1 })\n Error(1)\n \n\nSynonyms:\ngleam/result.map\ngleam/result map","url":"gleam/result.html#map"},{"doc":"gleam/result","title":"map_error","content":"pub fn map_error(\n  over result: Result(a, b),\n  with fun: fn(b) -&gt; c,\n) -&gt; Result(a, c)\n Updates a value held within the `Error` of a result by calling a given function\n on it.\n\n If the result is `Ok` rather than `Error` the function is not called and the\n result stays the same.\n\n ## Examples\n\n \n &gt; map_error(over: Error(1), with: fn(x) { x + 1 })\n Error(2)\n \n\n \n &gt; map_error(over: Ok(1), with: fn(x) { x + 1 })\n Ok(1)\n \n\nSynonyms:\ngleam/result.map_error\ngleam/result map_error","url":"gleam/result.html#map_error"},{"doc":"gleam/result","title":"nil_error","content":"pub fn nil_error(result: Result(a, b)) -&gt; Result(a, Nil)\n Transforms any error into `Error(Nil)`.\n\n ## Examples\n\n \n &gt; nil_error(Error(1))\n Error(Nil)\n \n\n \n &gt; nil_error(Ok(1))\n Ok(1)\n \n\nSynonyms:\ngleam/result.nil_error\ngleam/result nil_error","url":"gleam/result.html#nil_error"},{"doc":"gleam/result","title":"or","content":"pub fn or(\n  first: Result(a, b),\n  second: Result(a, b),\n) -&gt; Result(a, b)\n Returns the first value if it is `Ok`, otherwise returns the second value.\n\n ## Examples\n\n \n &gt; or(Ok(1), Ok(2))\n Ok(1)\n \n\n \n &gt; or(Ok(1), Error(&quot;Error 2&quot;))\n Ok(1)\n \n\n \n &gt; or(Error(&quot;Error 1&quot;), Ok(2))\n Ok(2)\n \n\n \n &gt; or(Error(&quot;Error 1&quot;), Error(&quot;Error 2&quot;))\n Error(&quot;Error 2&quot;)\n \n\nSynonyms:\ngleam/result.or\ngleam/result or","url":"gleam/result.html#or"},{"doc":"gleam/result","title":"partition","content":"pub fn partition(\n  results: List(Result(a, b)),\n) -&gt; #(List(a), List(b))\n Given a list of results, returns a pair where the first element is a list\n of all the values inside `Ok` and the second element is a list with all the\n values inside `Error`. The values in both lists appear in reverse order with\n respect to their position in the original list of results. \n\n ## Examples\n\n \n &gt; partition([Ok(1), Error(&quot;a&quot;), Error(&quot;b&quot;), Ok(2)])\n #([2, 1], [&quot;b&quot;, &quot;a&quot;])\n \n\nSynonyms:\ngleam/result.partition\ngleam/result partition","url":"gleam/result.html#partition"},{"doc":"gleam/result","title":"replace","content":"pub fn replace(result: Result(a, b), value: c) -&gt; Result(c, b)\n Replace the value within a result\n\n ## Examples\n\n \n &gt; replace(Ok(1), Nil)\n Ok(Nil)\n \n\n \n &gt; replace(Error(1), Nil)\n Error(1)\n \n\nSynonyms:\ngleam/result.replace\ngleam/result replace","url":"gleam/result.html#replace"},{"doc":"gleam/result","title":"replace_error","content":"pub fn replace_error(\n  result: Result(a, b),\n  error: c,\n) -&gt; Result(a, c)\n Replace the error within a result\n\n ## Examples\n\n \n &gt; replace_error(Error(1), Nil)\n Error(Nil)\n \n\n \n &gt; replace_error(Ok(1), Nil)\n Ok(1)\n \n\nSynonyms:\ngleam/result.replace_error\ngleam/result replace_error","url":"gleam/result.html#replace_error"},{"doc":"gleam/result","title":"then","content":"pub fn then(\n  result: Result(a, b),\n  apply fun: fn(a) -&gt; Result(c, b),\n) -&gt; Result(c, b)\n An alias for `try`. See the documentation for that function for more information.\n\nSynonyms:\ngleam/result.then\ngleam/result then","url":"gleam/result.html#then"},{"doc":"gleam/result","title":"try","content":"pub fn try(\n  result: Result(a, b),\n  apply fun: fn(a) -&gt; Result(c, b),\n) -&gt; Result(c, b)\n &quot;Updates&quot; an `Ok` result by passing its value to a function that yields a result,\n and returning the yielded result. (This may &quot;replace&quot; the `Ok` with an `Error`.)\n\n If the input is an `Error` rather than an `Ok`, the function is not called and\n the original `Error` is returned.\n\n This function is the equivalent of calling `map` followed by `flatten`, and\n it is useful for chaining together multiple functions that may fail.\n\n ## Examples\n\n \n &gt; try(Ok(1), fn(x) { Ok(x + 1) })\n Ok(2)\n \n\n \n &gt; try(Ok(1), fn(x) { Ok(#(&quot;a&quot;, x)) })\n Ok(#(&quot;a&quot;, 1))\n \n\n \n &gt; try(Ok(1), fn(_) { Error(&quot;Oh no&quot;) })\n Error(&quot;Oh no&quot;)\n \n\n \n &gt; try(Error(Nil), fn(x) { Ok(x + 1) })\n Error(Nil)\n \n\nSynonyms:\ngleam/result.try\ngleam/result try","url":"gleam/result.html#try"},{"doc":"gleam/result","title":"try_recover","content":"pub fn try_recover(\n  result: Result(a, b),\n  with fun: fn(b) -&gt; Result(a, c),\n) -&gt; Result(a, c)\n Updates a value held within the `Error` of a result by calling a given function\n on it, where the given function also returns a result. The two results are\n then merged together into one result.\n\n If the result is an `Ok` rather than `Error` the function is not called and the\n result stays the same.\n \n This function is useful for chaining together computations that may fail\n and trying to recover from possible errors.\n\n ## Examples\n\n \n &gt; Ok(1) |&gt; try_recover(with: fn(_) { Error(&quot;failed to recover&quot;) })\n Ok(1)\n \n\n \n &gt; Error(1) |&gt; try_recover(with: fn(error) { Ok(error + 1) })\n Ok(2)\n \n\n \n &gt; Error(1) |&gt; try_recover(with: fn(error) { Error(&quot;failed to recover&quot;) })\n Error(&quot;failed to recover&quot;)\n \n\nSynonyms:\ngleam/result.try_recover\ngleam/result try_recover","url":"gleam/result.html#try_recover"},{"doc":"gleam/result","title":"unwrap","content":"pub fn unwrap(result: Result(a, b), or default: a) -&gt; a\n Extracts the `Ok` value from a result, returning a default value if the result\n is an `Error`.\n\n ## Examples\n\n \n &gt; unwrap(Ok(1), 0)\n 1\n \n\n \n &gt; unwrap(Error(&quot;&quot;), 0)\n 0\n \n\nSynonyms:\ngleam/result.unwrap\ngleam/result unwrap","url":"gleam/result.html#unwrap"},{"doc":"gleam/result","title":"unwrap_both","content":"pub fn unwrap_both(result: Result(a, a)) -&gt; a\n Extracts the inner value from a result. Both the value and error must be of\n the same type.\n\n ## Examples\n\n \n &gt; unwrap_both(Error(1))\n 1\n \n\n \n &gt; unwrap_both(Ok(2))\n 2\n \n\nSynonyms:\ngleam/result.unwrap_both\ngleam/result unwrap_both","url":"gleam/result.html#unwrap_both"},{"doc":"gleam/result","title":"unwrap_error","content":"pub fn unwrap_error(result: Result(a, b), or default: b) -&gt; b\n Extracts the `Error` value from a result, returning a default value if the result\n is an `Ok`.\n\n ## Examples\n\n \n &gt; unwrap_error(Error(1), 0)\n 1\n \n\n \n &gt; unwrap_error(Ok(&quot;&quot;), 0)\n 0\n \n\nSynonyms:\ngleam/result.unwrap_error\ngleam/result unwrap_error","url":"gleam/result.html#unwrap_error"},{"doc":"gleam/result","title":"values","content":"pub fn values(results: List(Result(a, b))) -&gt; List(a)\n Given a list of results, returns only the values inside `Ok`.\n\n ## Examples\n\n \n &gt; values([Ok(1), Error(&quot;a&quot;), Ok(3)])\n [1, 3]\n \n\nSynonyms:\ngleam/result.values\ngleam/result values","url":"gleam/result.html#values"},{"doc":"gleam/result","title":"gleam/result","content":" Result represents the result of something that may succeed or not.\n `Ok` means it was successful, `Error` means it was not successful.","url":"gleam/result.html"},{"doc":"gleam/iterator","title":"Iterator","content":"pub opaque type Iterator(element)\n An iterator is a lazily evaluated sequence of element.\n\n Iterators are useful when working with collections that are too large to\n fit in memory (or those that are infinite in size) as they only require the\n elements currently being processed to be in memory.\n\n As a lazy data structure no work is done when an iterator is filters,\n mapped, etc, instead a new iterator is returned with these transformations\n applied to the stream. Once the stream has all the required transformations\n applied it can be evaluated using functions such as `fold` and `to_list`.\n\n\nSynonyms:\ngleam/iterator.Iterator\ngleam/iterator Iterator","url":"gleam/iterator.html#Iterator"},{"doc":"gleam/iterator","title":"Step","content":"pub type Step(element, accumulator) {\n  Next(element: element, accumulator: accumulator)\n  Done\n}\n\nNext(element: element, accumulator: accumulator)\n\n\nDone\n\n\nSynonyms:\ngleam/iterator.Step\ngleam/iterator Step","url":"gleam/iterator.html#Step"},{"doc":"gleam/iterator","title":"all","content":"pub fn all(\n  in iterator: Iterator(a),\n  satisfying predicate: fn(a) -&gt; Bool,\n) -&gt; Bool\n Returns `True` if all elements emitted by the iterator satisfy the given predicate,\n `False` otherwise.\n\n This function short-circuits once it finds a non-satisfying element.\n\n An empty iterator results in `True`.\n\n ## Examples\n\n \n &gt; empty() |&gt; all(fn(n) { n % 2 == 0 })\n True\n \n\n \n &gt; from_list([2, 4, 6, 8]) |&gt; all(fn(n) { n % 2 == 0 })\n True\n \n\n \n &gt; from_list([2, 4, 5, 8]) |&gt; all(fn(n) { n % 2 == 0 })\n False\n \n\nSynonyms:\ngleam/iterator.all\ngleam/iterator all","url":"gleam/iterator.html#all"},{"doc":"gleam/iterator","title":"any","content":"pub fn any(\n  in iterator: Iterator(a),\n  satisfying predicate: fn(a) -&gt; Bool,\n) -&gt; Bool\n Returns `True` if any element emitted by the iterator satisfies the given predicate,\n `False` otherwise.\n\n This function short-circuits once it finds a satisfying element.\n\n An empty iterator results in `False`.\n\n ## Examples\n\n \n &gt; empty() |&gt; any(fn(n) { n % 2 == 0 })\n False\n \n\n \n &gt; from_list([1, 2, 5, 7, 9]) |&gt; any(fn(n) { n % 2 == 0 })\n True\n \n\n \n &gt; from_list([1, 3, 5, 7, 9]) |&gt; any(fn(n) { n % 2 == 0 })\n False\n \n\nSynonyms:\ngleam/iterator.any\ngleam/iterator any","url":"gleam/iterator.html#any"},{"doc":"gleam/iterator","title":"append","content":"pub fn append(\n  to first: Iterator(a),\n  suffix second: Iterator(a),\n) -&gt; Iterator(a)\n Appends two iterators, producing a new iterator.\n\n This function does not evaluate the elements of the iterators, the\n computation is performed when the resulting iterator is later run.\n\n ## Examples\n\n \n &gt; [1, 2]\n &gt; |&gt; from_list\n &gt; |&gt; append([3, 4] |&gt; from_list)\n &gt; |&gt; to_list\n [1, 2, 3, 4]\n \n\nSynonyms:\ngleam/iterator.append\ngleam/iterator append","url":"gleam/iterator.html#append"},{"doc":"gleam/iterator","title":"at","content":"pub fn at(\n  in iterator: Iterator(a),\n  get index: Int,\n) -&gt; Result(a, Nil)\n Returns nth element yielded by the given iterator, where `0` means the first element.\n\n If there are not enough elements in the iterator, `Error(Nil)` is returned.\n\n For any `index` less than `0` this function behaves as if it was set to `0`.\n\n ## Examples\n\n \n &gt; from_list([1, 2, 3, 4]) |&gt; at(2)\n Ok(3)\n \n\n \n &gt; from_list([1, 2, 3, 4]) |&gt; at(4)\n Error(Nil)\n \n\n \n &gt; empty() |&gt; at(0)\n Error(Nil)\n \n\nSynonyms:\ngleam/iterator.at\ngleam/iterator at","url":"gleam/iterator.html#at"},{"doc":"gleam/iterator","title":"chunk","content":"pub fn chunk(\n  over iterator: Iterator(a),\n  by f: fn(a) -&gt; b,\n) -&gt; Iterator(List(a))\n Creates an iterator that emits chunks of elements\n for which `f` returns the same value.\n\n ## Examples\n\n \n &gt; from_list([1, 2, 2, 3, 4, 4, 6, 7, 7])\n &gt; |&gt; chunk(by: fn(n) { n % 2 })\n &gt; |&gt; to_list\n [[1], [2, 2], [3], [4, 4, 6], [7, 7]]\n \n\nSynonyms:\ngleam/iterator.chunk\ngleam/iterator chunk","url":"gleam/iterator.html#chunk"},{"doc":"gleam/iterator","title":"concat","content":"pub fn concat(iterators: List(Iterator(a))) -&gt; Iterator(a)\n Joins a list of iterators into a single iterator.\n\n This function does not evaluate the elements of the iterator, the\n computation is performed when the iterator is later run.\n\n ## Examples\n\n \n &gt; [[1, 2], [3, 4]]\n &gt; |&gt; map(from_list)\n &gt; |&gt; concat\n &gt; |&gt; to_list\n [1, 2, 3, 4]\n \n\nSynonyms:\ngleam/iterator.concat\ngleam/iterator concat","url":"gleam/iterator.html#concat"},{"doc":"gleam/iterator","title":"cycle","content":"pub fn cycle(iterator: Iterator(a)) -&gt; Iterator(a)\n Creates an iterator that repeats a given iterator infinitely.\n\n ## Examples\n\n \n &gt; [1, 2]\n &gt; |&gt; from_list\n &gt; |&gt; cycle\n &gt; |&gt; take(6)\n &gt; |&gt; to_list\n [1, 2, 1, 2, 1, 2]\n \n\nSynonyms:\ngleam/iterator.cycle\ngleam/iterator cycle","url":"gleam/iterator.html#cycle"},{"doc":"gleam/iterator","title":"drop","content":"pub fn drop(\n  from iterator: Iterator(a),\n  up_to desired: Int,\n) -&gt; Iterator(a)\n Evaluates and discards the first N elements in an iterator, returning a new\n iterator.\n\n If the iterator does not have enough elements an empty iterator is\n returned.\n\n This function does not evaluate the elements of the iterator, the\n computation is performed when the iterator is later run.\n\n ## Examples\n\n \n &gt; [1, 2, 3, 4, 5]\n &gt; |&gt; from_list\n &gt; |&gt; drop(up_to: 3)\n &gt; |&gt; to_list\n [4, 5]\n \n\n \n &gt; [1, 2]\n &gt; |&gt; from_list\n &gt; |&gt; drop(up_to: 3)\n &gt; |&gt; to_list\n []\n \n\nSynonyms:\ngleam/iterator.drop\ngleam/iterator drop","url":"gleam/iterator.html#drop"},{"doc":"gleam/iterator","title":"drop_while","content":"pub fn drop_while(\n  in iterator: Iterator(a),\n  satisfying predicate: fn(a) -&gt; Bool,\n) -&gt; Iterator(a)\n Creates an iterator that drops elements while the predicate returns `True`,\n and then yields the remaining elements.\n\n ## Examples\n\n \n &gt; from_list([1, 2, 3, 4, 2, 5])\n &gt; |&gt; drop_while(satisfying: fn(x) { x &lt; 4 })\n &gt; |&gt; to_list\n [4, 2, 5]\n \n\nSynonyms:\ngleam/iterator.drop_while\ngleam/iterator drop_while","url":"gleam/iterator.html#drop_while"},{"doc":"gleam/iterator","title":"each","content":"pub fn each(\n  over iterator: Iterator(a),\n  with f: fn(a) -&gt; b,\n) -&gt; Nil\n Traverse an iterator, calling a function on each element.\n\n ## Examples\n\n \n &gt; empty() |&gt; each(io.println)\n Nil\n \n\n \n &gt; from_list([&quot;Tom&quot;, &quot;Malory&quot;, &quot;Louis&quot;]) |&gt; each(io.println)\n // -&gt; Tom\n // -&gt; Malory\n // -&gt; Louis\n Nil\n \n\nSynonyms:\ngleam/iterator.each\ngleam/iterator each","url":"gleam/iterator.html#each"},{"doc":"gleam/iterator","title":"empty","content":"pub fn empty() -&gt; Iterator(a)\n Creates an iterator that yields no elements.\n\n ## Examples\n\n \n &gt; empty() |&gt; to_list\n []\n \n\nSynonyms:\ngleam/iterator.empty\ngleam/iterator empty","url":"gleam/iterator.html#empty"},{"doc":"gleam/iterator","title":"filter","content":"pub fn filter(\n  iterator: Iterator(a),\n  keeping predicate: fn(a) -&gt; Bool,\n) -&gt; Iterator(a)\n Creates an iterator from an existing iterator and a predicate function.\n\n The new iterator will contain elements from the first iterator for which\n the given function returns `True`.\n\n This function does not evaluate the elements of the iterator, the\n computation is performed when the iterator is later run.\n\n ## Examples\n\n \n &gt; import gleam/int\n &gt; [1, 2, 3, 4]\n &gt; |&gt; from_list\n &gt; |&gt; filter(int.is_even)\n &gt; |&gt; to_list\n [2, 4]\n \n\nSynonyms:\ngleam/iterator.filter\ngleam/iterator filter","url":"gleam/iterator.html#filter"},{"doc":"gleam/iterator","title":"find","content":"pub fn find(\n  in haystack: Iterator(a),\n  one_that is_desired: fn(a) -&gt; Bool,\n) -&gt; Result(a, Nil)\n Finds the first element in a given iterator for which the given function returns\n `True`.\n\n Returns `Error(Nil)` if the function does not return `True` for any of the\n elements.\n\n ## Examples\n\n \n &gt; find(from_list([1, 2, 3]), fn(x) { x &gt; 2 })\n Ok(3)\n \n\n \n &gt; find(from_list([1, 2, 3]), fn(x) { x &gt; 4 })\n Error(Nil)\n \n\n \n &gt; find(empty(), fn(_) { True })\n Error(Nil)\n \n\nSynonyms:\ngleam/iterator.find\ngleam/iterator find","url":"gleam/iterator.html#find"},{"doc":"gleam/iterator","title":"first","content":"pub fn first(from iterator: Iterator(a)) -&gt; Result(a, Nil)\n Returns the first element yielded by the given iterator, if it exists,\n or `Error(Nil)` otherwise.\n\n ## Examples\n\n \n &gt; from_list([1, 2, 3]) |&gt; first\n Ok(1)\n \n\n \n &gt; empty() |&gt; first\n Error(Nil)\n \nSynonyms:\ngleam/iterator.first\ngleam/iterator first","url":"gleam/iterator.html#first"},{"doc":"gleam/iterator","title":"flat_map","content":"pub fn flat_map(\n  over iterator: Iterator(a),\n  with f: fn(a) -&gt; Iterator(b),\n) -&gt; Iterator(b)\n Creates an iterator from an existing iterator and a transformation function.\n\n Each element in the new iterator will be the result of calling the given\n function on the elements in the given iterator and then flattening the\n results.\n\n This function does not evaluate the elements of the iterator, the\n computation is performed when the iterator is later run.\n\n ## Examples\n\n \n &gt; [1, 2]\n &gt; |&gt; from_list\n &gt; |&gt; flat_map(fn(x) { from_list([x, x + 1]) })\n &gt; |&gt; to_list\n [1, 2, 2, 3]\n \n\nSynonyms:\ngleam/iterator.flat_map\ngleam/iterator flat_map","url":"gleam/iterator.html#flat_map"},{"doc":"gleam/iterator","title":"flatten","content":"pub fn flatten(iterator: Iterator(Iterator(a))) -&gt; Iterator(a)\n Flattens an iterator of iterators, creating a new iterator.\n\n This function does not evaluate the elements of the iterator, the\n computation is performed when the iterator is later run.\n\n ## Examples\n\n \n &gt; from_list([[1, 2], [3, 4]])\n &gt; |&gt; map(from_list)\n &gt; |&gt; flatten\n &gt; |&gt; to_list\n [1, 2, 3, 4]\n \n\nSynonyms:\ngleam/iterator.flatten\ngleam/iterator flatten","url":"gleam/iterator.html#flatten"},{"doc":"gleam/iterator","title":"fold","content":"pub fn fold(\n  over iterator: Iterator(a),\n  from initial: b,\n  with f: fn(b, a) -&gt; b,\n) -&gt; b\n Reduces an iterator of elements into a single value by calling a given\n function on each element in turn.\n\n If called on an iterator of infinite length then this function will never\n return.\n\n If you do not care about the end value and only wish to evaluate the\n iterator for side effects consider using the `run` function instead.\n\n ## Examples\n\n \n &gt; [1, 2, 3, 4]\n &gt; |&gt; from_list\n &gt; |&gt; fold(from: 0, with: fn(acc, element) { element + acc })\n 10\n \n\nSynonyms:\ngleam/iterator.fold\ngleam/iterator fold","url":"gleam/iterator.html#fold"},{"doc":"gleam/iterator","title":"fold_until","content":"pub fn fold_until(\n  over iterator: Iterator(a),\n  from initial: b,\n  with f: fn(b, a) -&gt; ContinueOrStop(b),\n) -&gt; b\n Like `fold`, `fold_until` reduces an iterator of elements into a single value by calling a given\n function on each element in turn, but uses `list.ContinueOrStop` to determine\n whether or not to keep iterating.\n\n If called on an iterator of infinite length then this function will only ever\n return if the function returns `list.Stop`.\n\n ## Examples\n\n \n &gt; import gleam/list\n &gt; let f = fn(acc, e) {\n &gt;   case e {\n &gt;     _ if e &lt; 4 -&gt; list.Continue(e + acc)\n &gt;     _ -&gt; list.Stop(acc)\n &gt;   }\n &gt; }\n &gt;\n &gt; [1, 2, 3, 4]\n &gt; |&gt; from_list\n &gt; |&gt; fold_until(from: acc, with: f)\n 6\n \n\nSynonyms:\ngleam/iterator.fold_until\ngleam/iterator fold_until","url":"gleam/iterator.html#fold_until"},{"doc":"gleam/iterator","title":"from_list","content":"pub fn from_list(list: List(a)) -&gt; Iterator(a)\n Creates an iterator that yields each element from the given list.\n\n ## Examples\n\n \n &gt; from_list([1, 2, 3, 4])\n &gt; |&gt; to_list\n [1, 2, 3, 4]\n \n\nSynonyms:\ngleam/iterator.from_list\ngleam/iterator from_list","url":"gleam/iterator.html#from_list"},{"doc":"gleam/iterator","title":"group","content":"pub fn group(\n  in iterator: Iterator(a),\n  by key: fn(a) -&gt; b,\n) -&gt; Map(b, List(a))\n Returns a `Map(k, List(element))` of elements from the given iterator\n grouped with the given key function.\n\n The order within each group is preserved from the iterator.\n\n ## Examples\n\n \n &gt; from_list([1, 2, 3, 4, 5, 6]) |&gt; group(by: fn(n) { n % 3 })\n map.from_list([#(0, [3, 6]), #(1, [1, 4]), #(2, [2, 5])])\n \n\nSynonyms:\ngleam/iterator.group\ngleam/iterator group","url":"gleam/iterator.html#group"},{"doc":"gleam/iterator","title":"index","content":"pub fn index(over iterator: Iterator(a)) -&gt; Iterator(#(Int, a))\n Wraps values yielded from an iterator with indices, starting from 0.\n\n ## Examples\n\n \n &gt; from_list([&quot;a&quot;, &quot;b&quot;, &quot;c&quot;]) |&gt; index |&gt; to_list\n [#(0, &quot;a&quot;), #(1, &quot;b&quot;), #(2, &quot;c&quot;)]\n \n\nSynonyms:\ngleam/iterator.index\ngleam/iterator index","url":"gleam/iterator.html#index"},{"doc":"gleam/iterator","title":"interleave","content":"pub fn interleave(\n  left: Iterator(a),\n  with right: Iterator(a),\n) -&gt; Iterator(a)\n Creates an iterator that alternates between the two given iterators\n until both have run out.\n\n ## Examples\n\n \n &gt; from_list([1, 2, 3, 4]) |&gt; interleave(from_list([11, 12, 13, 14])) |&gt; to_list\n [1, 11, 2, 12, 3, 13, 4, 14]\n \n\n \n &gt; from_list([1, 2, 3, 4]) |&gt; interleave(from_list([100])) |&gt; to_list\n [1, 100, 2, 3, 4]\n \n\nSynonyms:\ngleam/iterator.interleave\ngleam/iterator interleave","url":"gleam/iterator.html#interleave"},{"doc":"gleam/iterator","title":"intersperse","content":"pub fn intersperse(\n  over iterator: Iterator(a),\n  with elem: a,\n) -&gt; Iterator(a)\n Creates an iterator that yields the given `elem` element\n between elements emitted by the underlying iterator.\n\n ## Examples\n\n \n &gt; empty()\n &gt; |&gt; intersperse(with: 0)\n &gt; |&gt; to_list\n []\n\n &gt; from_list([1])\n &gt; |&gt; intersperse(with: 0)\n &gt; |&gt; to_list\n [1]\n\n &gt; from_list([1, 2, 3, 4, 5])\n &gt; |&gt; intersperse(with: 0)\n &gt; |&gt; to_list\n [1, 0, 2, 0, 3, 0, 4, 0, 5]\n \n\nSynonyms:\ngleam/iterator.intersperse\ngleam/iterator intersperse","url":"gleam/iterator.html#intersperse"},{"doc":"gleam/iterator","title":"iterate","content":"pub fn iterate(\n  from initial: a,\n  with f: fn(a) -&gt; a,\n) -&gt; Iterator(a)\n Creates an iterator that inifinitely applies a function to a value.\n\n ## Examples\n\n \n &gt; iterate(1, fn(n) { n * 3 }) |&gt; take(5) |&gt; to_list\n [1, 3, 9, 27, 81]\n \n\nSynonyms:\ngleam/iterator.iterate\ngleam/iterator iterate","url":"gleam/iterator.html#iterate"},{"doc":"gleam/iterator","title":"last","content":"pub fn last(iterator: Iterator(a)) -&gt; Result(a, Nil)\n Returns the last element in the given iterator.\n\n Returns `Error(Nil)` if the iterator is empty.\n\n This function runs in linear time.\n\n ## Examples\n\n \n &gt; empty() |&gt; last\n Error(Nil)\n \n\n \n &gt; range(1, 10) |&gt; last\n Ok(9)\n \n\nSynonyms:\ngleam/iterator.last\ngleam/iterator last","url":"gleam/iterator.html#last"},{"doc":"gleam/iterator","title":"length","content":"pub fn length(over iterator: Iterator(a)) -&gt; Int\n Counts the number of elements in the given iterator.\n\n This function has to traverse the entire iterator to count its elements,\n so it runs in linear time.\n\n ## Examples\n\n \n &gt; empty() |&gt; length\n 0\n \n\n \n &gt; from_list([1, 2, 3, 4]) |&gt; length\n 4\n \n\nSynonyms:\ngleam/iterator.length\ngleam/iterator length","url":"gleam/iterator.html#length"},{"doc":"gleam/iterator","title":"map","content":"pub fn map(\n  over iterator: Iterator(a),\n  with f: fn(a) -&gt; b,\n) -&gt; Iterator(b)\n Creates an iterator from an existing iterator and a transformation function.\n\n Each element in the new iterator will be the result of calling the given\n function on the elements in the given iterator.\n\n This function does not evaluate the elements of the iterator, the\n computation is performed when the iterator is later run.\n\n ## Examples\n\n \n &gt; [1, 2, 3]\n &gt; |&gt; from_list\n &gt; |&gt; map(fn(x) { x * 2 })\n &gt; |&gt; to_list\n [2, 4, 6]\n \n\nSynonyms:\ngleam/iterator.map\ngleam/iterator map","url":"gleam/iterator.html#map"},{"doc":"gleam/iterator","title":"map2","content":"pub fn map2(\n  iterator1: Iterator(a),\n  iterator2: Iterator(b),\n  with fun: fn(a, b) -&gt; c,\n) -&gt; Iterator(c)\n Combines two interators into a single one using the given function.\n \n If an iterator is longer than the other the extra elements are dropped.\n \n This function does not evaluate the elements of the two iterators, the\n computation is performed when the resulting iterator is later run.\n \n ## Examples\n \n \n let first = from_list([1, 2, 3])\n let second = from_list([4, 5, 6])\n map2(first, second, fn(x, y) { x + y }) |&gt; to_list\n // -&gt; [5, 7, 9]\n \n \n \n let first = from_list([1, 2])\n let second = from_list([&quot;a&quot;, &quot;b&quot;, &quot;c&quot;])\n map2(first, second, fn(i, x) { #(i, x) }) |&gt; to_list\n // -&gt; [#(1, &quot;a&quot;), #(2, &quot;b&quot;)]\n \n \nSynonyms:\ngleam/iterator.map2\ngleam/iterator map2","url":"gleam/iterator.html#map2"},{"doc":"gleam/iterator","title":"once","content":"pub fn once(f: fn() -&gt; a) -&gt; Iterator(a)\n Creates an iterator that yields exactly one element provided by calling the given function.\n\n ## Examples\n\n \n &gt; once(fn() { 1 }) |&gt; to_list\n [1]\n \n\nSynonyms:\ngleam/iterator.once\ngleam/iterator once","url":"gleam/iterator.html#once"},{"doc":"gleam/iterator","title":"range","content":"pub fn range(from start: Int, to stop: Int) -&gt; Iterator(Int)\n Creates an iterator of ints, starting at a given start int and stepping by\n one to a given end int.\n\n ## Examples\n\n \n &gt; range(from: 1, to: 5) |&gt; to_list\n [1, 2, 3, 4, 5]\n \n\n \n &gt; range(from: 1, to: -2) |&gt; to_list\n [1, 0, -1, -2]\n \n\n \n &gt; range(from: 0, to: 0) |&gt; to_list\n [0]\n \n\nSynonyms:\ngleam/iterator.range\ngleam/iterator range","url":"gleam/iterator.html#range"},{"doc":"gleam/iterator","title":"reduce","content":"pub fn reduce(\n  over iterator: Iterator(a),\n  with f: fn(a, a) -&gt; a,\n) -&gt; Result(a, Nil)\n This function acts similar to fold, but does not take an initial state.\n Instead, it starts from the first yielded element\n and combines it with each subsequent element in turn using the given function.\n The function is called as `f(accumulator, current_element)`.\n\n Returns `Ok` to indicate a successful run, and `Error` if called on an empty iterator.\n\n ## Examples\n\n \n &gt; from_list([]) |&gt; reduce(fn(acc, x) { acc + x })\n Error(Nil)\n \n\n \n &gt; from_list([1, 2, 3, 4, 5]) |&gt; reduce(fn(acc, x) { acc + x })\n Ok(15)\n \n\nSynonyms:\ngleam/iterator.reduce\ngleam/iterator reduce","url":"gleam/iterator.html#reduce"},{"doc":"gleam/iterator","title":"repeat","content":"pub fn repeat(x: a) -&gt; Iterator(a)\n Creates an iterator that returns the same value infinitely.\n\n ## Examples\n\n \n &gt; repeat(10)\n &gt; |&gt; take(4)\n &gt; |&gt; to_list\n [10, 10, 10, 10]\n \n\nSynonyms:\ngleam/iterator.repeat\ngleam/iterator repeat","url":"gleam/iterator.html#repeat"},{"doc":"gleam/iterator","title":"repeatedly","content":"pub fn repeatedly(f: fn() -&gt; a) -&gt; Iterator(a)\n Creates an iterator that yields values created by calling a given function\n repeatedly.\n\nSynonyms:\ngleam/iterator.repeatedly\ngleam/iterator repeatedly","url":"gleam/iterator.html#repeatedly"},{"doc":"gleam/iterator","title":"run","content":"pub fn run(iterator: Iterator(a)) -&gt; Nil\n Evaluates all elements emitted by the given iterator. This function is useful for when\n you wish to trigger any side effects that would occur when evaluating\n the iterator.\n\nSynonyms:\ngleam/iterator.run\ngleam/iterator run","url":"gleam/iterator.html#run"},{"doc":"gleam/iterator","title":"scan","content":"pub fn scan(\n  over iterator: Iterator(a),\n  from initial: b,\n  with f: fn(b, a) -&gt; b,\n) -&gt; Iterator(b)\n Creates an iterator from an existing iterator and a stateful function.\n\n Specifically, this behaves like `fold`, but yields intermediate results.\n\n ## Examples\n\n \n // Generate a sequence of partial sums\n &gt; from_list([1, 2, 3, 4, 5])\n &gt; |&gt; scan(from: 0, with: fn(acc, el) { acc + el })\n &gt; |&gt; to_list\n [1, 3, 6, 10, 15]\n \n\nSynonyms:\ngleam/iterator.scan\ngleam/iterator scan","url":"gleam/iterator.html#scan"},{"doc":"gleam/iterator","title":"single","content":"pub fn single(elem: a) -&gt; Iterator(a)\n Creates an iterator that yields the given element exactly once.\n\n ## Examples\n\n \n &gt; single(1) |&gt; to_list\n [1]\n \n\nSynonyms:\ngleam/iterator.single\ngleam/iterator single","url":"gleam/iterator.html#single"},{"doc":"gleam/iterator","title":"sized_chunk","content":"pub fn sized_chunk(\n  over iterator: Iterator(a),\n  into count: Int,\n) -&gt; Iterator(List(a))\n Creates an iterator that emits chunks of given size.\n\n If the last chunk does not have `count` elements, it is yielded\n as a partial chunk, with less than `count` elements.\n\n For any `count` less than 1 this function behaves as if it was set to 1.\n\n ## Examples\n\n \n &gt; from_list([1, 2, 3, 4, 5, 6])\n &gt; |&gt; sized_chunk(into: 2)\n &gt; |&gt; to_list\n [[1, 2], [3, 4], [5, 6]]\n \n\n \n &gt; from_list([1, 2, 3, 4, 5, 6, 7, 8])\n &gt; |&gt; sized_chunk(into: 3)\n &gt; |&gt; to_list\n [[1, 2, 3], [4, 5, 6], [7, 8]]\n \n\nSynonyms:\ngleam/iterator.sized_chunk\ngleam/iterator sized_chunk","url":"gleam/iterator.html#sized_chunk"},{"doc":"gleam/iterator","title":"step","content":"pub fn step(iterator: Iterator(a)) -&gt; Step(a, Iterator(a))\n Eagerly accesses the first value of an iterator, returning a `Next`\n that contains the first value and the rest of the iterator.\n\n If called on an empty iterator, `Done` is returned.\n\n ## Examples\n\n \n &gt; let assert Next(first, rest) = [1, 2, 3, 4]\n &gt;   |&gt; from_list\n &gt;   |&gt; step\n &gt; first\n 1\n \n\n \n &gt; rest |&gt; to_list\n [2, 3, 4]\n \n\n \n &gt; empty() |&gt; step\n Done\n \n\nSynonyms:\ngleam/iterator.step\ngleam/iterator step","url":"gleam/iterator.html#step"},{"doc":"gleam/iterator","title":"take","content":"pub fn take(\n  from iterator: Iterator(a),\n  up_to desired: Int,\n) -&gt; Iterator(a)\n Creates an iterator that only yields the first `desired` elements.\n\n If the iterator does not have enough elements all of them are yielded.\n\n ## Examples\n\n \n &gt; [1, 2, 3, 4, 5]\n &gt; |&gt; from_list\n &gt; |&gt; take(up_to: 3)\n &gt; |&gt; to_list\n [1, 2, 3]\n \n\n \n &gt; [1, 2]\n &gt; |&gt; from_list\n &gt; |&gt; take(up_to: 3)\n &gt; |&gt; to_list\n [1, 2]\n \n\nSynonyms:\ngleam/iterator.take\ngleam/iterator take","url":"gleam/iterator.html#take"},{"doc":"gleam/iterator","title":"take_while","content":"pub fn take_while(\n  in iterator: Iterator(a),\n  satisfying predicate: fn(a) -&gt; Bool,\n) -&gt; Iterator(a)\n Creates an iterator that yields elements while the predicate returns `True`.\n\n ## Examples\n\n \n &gt; from_list([1, 2, 3, 2, 4])\n &gt; |&gt; take_while(satisfying: fn(x) { x &lt; 3 })\n &gt; |&gt; to_list\n [1, 2]\n \n\nSynonyms:\ngleam/iterator.take_while\ngleam/iterator take_while","url":"gleam/iterator.html#take_while"},{"doc":"gleam/iterator","title":"to_list","content":"pub fn to_list(iterator: Iterator(a)) -&gt; List(a)\n Evaluates an iterator and returns all the elements as a list.\n\n If called on an iterator of infinite length then this function will never\n return.\n\n ## Examples\n\n \n &gt; [1, 2, 3]\n &gt; |&gt; from_list\n &gt; |&gt; map(fn(x) { x * 2 })\n &gt; |&gt; to_list\n [2, 4, 6]\n \n\nSynonyms:\ngleam/iterator.to_list\ngleam/iterator to_list","url":"gleam/iterator.html#to_list"},{"doc":"gleam/iterator","title":"transform","content":"pub fn transform(\n  over iterator: Iterator(a),\n  from initial: b,\n  with f: fn(b, a) -&gt; Step(c, b),\n) -&gt; Iterator(c)\n Creates an iterator from an existing iterator\n and a stateful function that may short-circuit.\n\n `f` takes arguments `acc` for current state and `el` for current element from underlying iterator,\n and returns either `Next` with yielded element and new state value, or `Done` to halt the iterator.\n\n ## Examples\n\n Approximate implementation of `index` in terms of `transform`:\n\n \n &gt; from_list([&quot;a&quot;, &quot;b&quot;, &quot;c&quot;])\n &gt; |&gt; transform(0, fn(i, el) { Next(#(i, el), i + 1) })\n &gt; |&gt; to_list\n [#(0, &quot;a&quot;), #(1, &quot;b&quot;), #(2, &quot;c&quot;)]\n \nSynonyms:\ngleam/iterator.transform\ngleam/iterator transform","url":"gleam/iterator.html#transform"},{"doc":"gleam/iterator","title":"try_fold","content":"pub fn try_fold(\n  over iterator: Iterator(a),\n  from initial: b,\n  with f: fn(b, a) -&gt; Result(b, c),\n) -&gt; Result(b, c)\n A variant of fold that might fail.\n\n The folding function should return `Result(accumulator, error)`.\n If the returned value is `Ok(accumulator)` try_fold will try the next value in the iterator.\n If the returned value is `Error(error)` try_fold will stop and return that error.\n\n ## Examples\n\n \n &gt; [1, 2, 3, 4]\n &gt; |&gt; iterator.from_list()\n &gt; |&gt; try_fold(0, fn(acc, i) {\n &gt;   case i &lt; 3 {\n &gt;     True -&gt; Ok(acc + i)\n &gt;     False -&gt; Error(Nil)\n &gt;   }\n &gt; })\n Error(Nil)\n \n\nSynonyms:\ngleam/iterator.try_fold\ngleam/iterator try_fold","url":"gleam/iterator.html#try_fold"},{"doc":"gleam/iterator","title":"unfold","content":"pub fn unfold(\n  from initial: a,\n  with f: fn(a) -&gt; Step(b, a),\n) -&gt; Iterator(b)\n Creates an iterator from a given function and accumulator.\n\n The function is called on the accumulator and returns either `Done`,\n indicating the iterator has no more elements, or `Next` which contains a\n new element and accumulator. The element is yielded by the iterator and the\n new accumulator is used with the function to compute the next element in\n the sequence.\n\n ## Examples\n\n \n &gt; unfold(from: 5, with: fn(n) {\n &gt;  case n {\n &gt;    0 -&gt; Done\n &gt;    n -&gt; Next(element: n, accumulator: n - 1)\n &gt;  }\n &gt; })\n &gt; |&gt; to_list\n [5, 4, 3, 2, 1]\n \n\nSynonyms:\ngleam/iterator.unfold\ngleam/iterator unfold","url":"gleam/iterator.html#unfold"},{"doc":"gleam/iterator","title":"yield","content":"pub fn yield(\n  element: a,\n  next: fn() -&gt; Iterator(a),\n) -&gt; Iterator(a)\n Add a new element to the start of an iterator.\n \n This function is for use with `use` expressions, to replicate the behaviour\n of the `yield` keyword found in other languages.\n \n ## Examples\n \n \n &gt; use &lt;- iterator.yield(1)\n &gt; use &lt;- iterator.yield(2)\n &gt; use &lt;- iterator.yield(3)\n &gt; iterator.empty()\n iterator.from_list([1, 2, 3])\n \n \nSynonyms:\ngleam/iterator.yield\ngleam/iterator yield","url":"gleam/iterator.html#yield"},{"doc":"gleam/iterator","title":"zip","content":"pub fn zip(\n  left: Iterator(a),\n  right: Iterator(b),\n) -&gt; Iterator(#(a, b))\n Zips two iterators together, emitting values from both\n until the shorter one runs out.\n\n ## Examples\n\n \n &gt; from_list([&quot;a&quot;, &quot;b&quot;, &quot;c&quot;])\n &gt; |&gt; zip(range(20, 30))\n &gt; |&gt; to_list\n [#(&quot;a&quot;, 20), #(&quot;b&quot;, 21), #(&quot;c&quot;, 22)]\n \n\nSynonyms:\ngleam/iterator.zip\ngleam/iterator zip","url":"gleam/iterator.html#zip"},{"doc":"gleam/iterator","title":"gleam/iterator","content":"","url":"gleam/iterator.html"},{"doc":"gleam/string_builder","title":"StringBuilder","content":"pub type StringBuilder\n `StringBuilder` is a type used for efficiently building strings.\n\n When we append one string to another the strings must be copied to a\n new location in memory so that they can sit together. This behaviour\n enables efficient reading of the string but copying can be expensive,\n especially if we want to join many strings together.\n\n `StringBuilder` is different in that it can be joined together in constant time\n using minimal memory, and then can be efficiently converted to a string\n using the `to_string` function.\n\n On Erlang this type is compatible with Erlang&#39;s iodata. On JavaScript this\n type is compatible with normal strings.\n\n\nSynonyms:\ngleam/string_builder.StringBuilder\ngleam/string_builder StringBuilder","url":"gleam/string_builder.html#StringBuilder"},{"doc":"gleam/string_builder","title":"append","content":"pub fn append(\n  to builder: StringBuilder,\n  suffix second: String,\n) -&gt; StringBuilder\n Appends a `String` onto the end of some `StringBuilder`.\n\n Runs in constant time.\n\nSynonyms:\ngleam/string_builder.append\ngleam/string_builder append","url":"gleam/string_builder.html#append"},{"doc":"gleam/string_builder","title":"append_builder","content":"pub fn append_builder(\n  to builder: StringBuilder,\n  suffix suffix: StringBuilder,\n) -&gt; StringBuilder\n Appends some `StringBuilder` onto the end of another.\n\n Runs in constant time.\n\nSynonyms:\ngleam/string_builder.append_builder\ngleam/string_builder append_builder","url":"gleam/string_builder.html#append_builder"},{"doc":"gleam/string_builder","title":"byte_size","content":"pub fn byte_size(builder: StringBuilder) -&gt; Int\n Returns the size of the `StringBuilder` in bytes.\n\nSynonyms:\ngleam/string_builder.byte_size\ngleam/string_builder byte_size","url":"gleam/string_builder.html#byte_size"},{"doc":"gleam/string_builder","title":"concat","content":"pub fn concat(builders: List(StringBuilder)) -&gt; StringBuilder\n Joins a list of builders into a single builder.\n\n Runs in constant time.\n\nSynonyms:\ngleam/string_builder.concat\ngleam/string_builder concat","url":"gleam/string_builder.html#concat"},{"doc":"gleam/string_builder","title":"from_string","content":"pub fn from_string(string: String) -&gt; StringBuilder\n Converts a string into a builder.\n\n Runs in constant time.\n\nSynonyms:\ngleam/string_builder.from_string\ngleam/string_builder from_string","url":"gleam/string_builder.html#from_string"},{"doc":"gleam/string_builder","title":"from_strings","content":"pub fn from_strings(strings: List(String)) -&gt; StringBuilder\n Converts a list of strings into a builder.\n\n Runs in constant time.\n\nSynonyms:\ngleam/string_builder.from_strings\ngleam/string_builder from_strings","url":"gleam/string_builder.html#from_strings"},{"doc":"gleam/string_builder","title":"is_empty","content":"pub fn is_empty(builder: StringBuilder) -&gt; Bool\n Inspects a builder to determine if it is equivalent to an empty string.\n\n ## Examples\n\n \n &gt; from_string(&quot;ok&quot;) |&gt; is_empty\n False\n \n\n \n &gt; from_string(&quot;&quot;) |&gt; is_empty\n True\n \n\n \n &gt; from_strings([]) |&gt; is_empty\n True\n \n\nSynonyms:\ngleam/string_builder.is_empty\ngleam/string_builder is_empty","url":"gleam/string_builder.html#is_empty"},{"doc":"gleam/string_builder","title":"is_equal","content":"pub fn is_equal(a: StringBuilder, b: StringBuilder) -&gt; Bool\n Compares two builders to determine if they have the same textual content.\n\n Comparing two iodata using the `==` operator may return `False` even if they\n have the same content as they may have been build in different ways, so\n using this function is often preferred.\n\n ## Examples\n\n \n &gt; from_strings([&quot;a&quot;, &quot;b&quot;]) == from_string(&quot;ab&quot;)\n False\n \n\n \n &gt; is_equal(from_strings([&quot;a&quot;, &quot;b&quot;]), from_string(&quot;ab&quot;))\n True\n \n\nSynonyms:\ngleam/string_builder.is_equal\ngleam/string_builder is_equal","url":"gleam/string_builder.html#is_equal"},{"doc":"gleam/string_builder","title":"join","content":"pub fn join(\n  builders: List(StringBuilder),\n  with sep: String,\n) -&gt; StringBuilder\n Joins the given builders into a new builder separated with the given string\n\nSynonyms:\ngleam/string_builder.join\ngleam/string_builder join","url":"gleam/string_builder.html#join"},{"doc":"gleam/string_builder","title":"lowercase","content":"pub fn lowercase(builder: StringBuilder) -&gt; StringBuilder\n Converts a builder to a new builder where the contents have been\n lowercased.\n\nSynonyms:\ngleam/string_builder.lowercase\ngleam/string_builder lowercase","url":"gleam/string_builder.html#lowercase"},{"doc":"gleam/string_builder","title":"new","content":"pub fn new() -&gt; StringBuilder\n Create an empty `StringBuilder`. Useful as the start of a pipe chaining many\n builders together.\n\nSynonyms:\ngleam/string_builder.new\ngleam/string_builder new","url":"gleam/string_builder.html#new"},{"doc":"gleam/string_builder","title":"prepend","content":"pub fn prepend(\n  to builder: StringBuilder,\n  prefix prefix: String,\n) -&gt; StringBuilder\n Prepends a `String` onto the start of some `StringBuilder`.\n\n Runs in constant time.\n\nSynonyms:\ngleam/string_builder.prepend\ngleam/string_builder prepend","url":"gleam/string_builder.html#prepend"},{"doc":"gleam/string_builder","title":"prepend_builder","content":"pub fn prepend_builder(\n  to builder: StringBuilder,\n  prefix prefix: StringBuilder,\n) -&gt; StringBuilder\n Prepends some `StringBuilder` onto the start of another.\n\n Runs in constant time.\n\nSynonyms:\ngleam/string_builder.prepend_builder\ngleam/string_builder prepend_builder","url":"gleam/string_builder.html#prepend_builder"},{"doc":"gleam/string_builder","title":"replace","content":"pub fn replace(\n  in builder: StringBuilder,\n  each pattern: String,\n  with substitute: String,\n) -&gt; StringBuilder\n Replaces all instances of a pattern with a given string substitute.\n\nSynonyms:\ngleam/string_builder.replace\ngleam/string_builder replace","url":"gleam/string_builder.html#replace"},{"doc":"gleam/string_builder","title":"reverse","content":"pub fn reverse(builder: StringBuilder) -&gt; StringBuilder\n Converts a builder to a new builder with the contents reversed.\n\nSynonyms:\ngleam/string_builder.reverse\ngleam/string_builder reverse","url":"gleam/string_builder.html#reverse"},{"doc":"gleam/string_builder","title":"split","content":"pub fn split(\n  iodata: StringBuilder,\n  on pattern: String,\n) -&gt; List(StringBuilder)\n Splits a builder on a given pattern into a list of builders.\n\nSynonyms:\ngleam/string_builder.split\ngleam/string_builder split","url":"gleam/string_builder.html#split"},{"doc":"gleam/string_builder","title":"to_string","content":"pub fn to_string(builder: StringBuilder) -&gt; String\n Turns an `StringBuilder` into a `String`\n\n This function is implemented natively by the virtual machine and is highly\n optimised.\n\nSynonyms:\ngleam/string_builder.to_string\ngleam/string_builder to_string","url":"gleam/string_builder.html#to_string"},{"doc":"gleam/string_builder","title":"uppercase","content":"pub fn uppercase(builder: StringBuilder) -&gt; StringBuilder\n Converts a builder to a new builder where the contents have been\n uppercased.\n\nSynonyms:\ngleam/string_builder.uppercase\ngleam/string_builder uppercase","url":"gleam/string_builder.html#uppercase"},{"doc":"gleam/string_builder","title":"gleam/string_builder","content":"","url":"gleam/string_builder.html"},{"doc":"gleam/string","title":"append","content":"pub fn append(to first: String, suffix second: String) -&gt; String\n Creates a new `String` by joining two `String`s together.\n\n This function copies both `String`s and runs in linear time. If you find\n yourself joining `String`s frequently consider using the [`string_builder`](../gleam/string_builder.html)\n module as it can append `String`s much faster!\n\n ## Examples\n\n \n &gt; append(to: &quot;butter&quot;, suffix: &quot;fly&quot;)\n &quot;butterfly&quot;\n \n\nSynonyms:\ngleam/string.append\ngleam/string append","url":"gleam/string.html#append"},{"doc":"gleam/string","title":"byte_size","content":"pub fn byte_size(string: String) -&gt; Int\n Returns the number of bytes in a `String`.\n \n This function runs in constant time on Erlang and in linear time on\n JavaScript.\n\nSynonyms:\ngleam/string.byte_size\ngleam/string byte_size","url":"gleam/string.html#byte_size"},{"doc":"gleam/string","title":"capitalise","content":"pub fn capitalise(s: String) -&gt; String\n Creates a new `String` with the first grapheme in the input `String`\n converted to uppercase and the remaining graphemes to lowercase.\n\n ## Examples\n\n \n &gt; capitalise(&quot;mamouna&quot;)\n &quot;Mamouna&quot;\n \n\nSynonyms:\ngleam/string.capitalise\ngleam/string capitalise","url":"gleam/string.html#capitalise"},{"doc":"gleam/string","title":"compare","content":"pub fn compare(a: String, b: String) -&gt; Order\n Compares two `String`s to see which is &quot;larger&quot; by comparing their graphemes.\n\n This does not compare the size or length of the given `String`s.\n\n ## Examples\n\n \n &gt; compare(&quot;Anthony&quot;, &quot;Anthony&quot;)\n order.Eq\n \n\n \n &gt; compare(&quot;A&quot;, &quot;B&quot;)\n order.Lt\n \n\nSynonyms:\ngleam/string.compare\ngleam/string compare","url":"gleam/string.html#compare"},{"doc":"gleam/string","title":"concat","content":"pub fn concat(strings: List(String)) -&gt; String\n Creates a new `String` by joining many `String`s together.\n\n This function copies both `String`s and runs in linear time. If you find\n yourself joining `String`s frequently consider using the [`string_builder`](../gleam/string_builder.html)\n module as it can append `String`s much faster!\n\n ## Examples\n\n \n &gt; concat([&quot;never&quot;, &quot;the&quot;, &quot;less&quot;])\n &quot;nevertheless&quot;\n \n\nSynonyms:\ngleam/string.concat\ngleam/string concat","url":"gleam/string.html#concat"},{"doc":"gleam/string","title":"contains","content":"pub fn contains(\n  does haystack: String,\n  contain needle: String,\n) -&gt; Bool\n Checks if the first `String` contains the second.\n\n ## Examples\n\n \n &gt; contains(does: &quot;theory&quot;, contain: &quot;ory&quot;)\n True\n \n\n \n &gt; contains(does: &quot;theory&quot;, contain: &quot;the&quot;)\n True\n \n\n \n &gt; contains(does: &quot;theory&quot;, contain: &quot;THE&quot;)\n False\n \n\nSynonyms:\ngleam/string.contains\ngleam/string contains","url":"gleam/string.html#contains"},{"doc":"gleam/string","title":"crop","content":"pub fn crop(\n  from string: String,\n  before substring: String,\n) -&gt; String\n Drops contents of the first `String` that occur before the second `String`.\n If the `from` string does not contain the `before` string, `from` is returned unchanged.\n\n ## Examples\n\n \n &gt; crop(from: &quot;The Lone Gunmen&quot;, before: &quot;Lone&quot;)\n &quot;Lone Gunmen&quot;\n \n\nSynonyms:\ngleam/string.crop\ngleam/string crop","url":"gleam/string.html#crop"},{"doc":"gleam/string","title":"drop_left","content":"pub fn drop_left(\n  from string: String,\n  up_to num_graphemes: Int,\n) -&gt; String\n Drops *n* graphemes from the left side of a `String`.\n\n ## Examples\n\n \n &gt; drop_left(from: &quot;The Lone Gunmen&quot;, up_to: 2)\n &quot;e Lone Gunmen&quot;\n \n\nSynonyms:\ngleam/string.drop_left\ngleam/string drop_left","url":"gleam/string.html#drop_left"},{"doc":"gleam/string","title":"drop_right","content":"pub fn drop_right(\n  from string: String,\n  up_to num_graphemes: Int,\n) -&gt; String\n Drops *n* graphemes from the right side of a `String`.\n\n ## Examples\n\n \n &gt; drop_right(from: &quot;Cigarette Smoking Man&quot;, up_to: 2)\n &quot;Cigarette Smoking M&quot;\n \n\nSynonyms:\ngleam/string.drop_right\ngleam/string drop_right","url":"gleam/string.html#drop_right"},{"doc":"gleam/string","title":"ends_with","content":"pub fn ends_with(string: String, suffix: String) -&gt; Bool\n Checks whether the first `String` ends with the second one.\n\n ## Examples\n\n \n &gt; ends_with(&quot;theory&quot;, &quot;ory&quot;)\n True\n \n\nSynonyms:\ngleam/string.ends_with\ngleam/string ends_with","url":"gleam/string.html#ends_with"},{"doc":"gleam/string","title":"first","content":"pub fn first(s: String) -&gt; Result(String, Nil)\n Returns the first grapheme cluster in a given `String` and wraps it in a\n `Result(String, Nil)`. If the `String` is empty, it returns `Error(Nil)`.\n Otherwise, it returns `Ok(String)`.\n\n ## Examples\n\n \n &gt; first(&quot;&quot;)\n Error(Nil)\n \n\n \n &gt; first(&quot;icecream&quot;)\n Ok(&quot;i&quot;)\n \n\nSynonyms:\ngleam/string.first\ngleam/string first","url":"gleam/string.html#first"},{"doc":"gleam/string","title":"from_utf_codepoints","content":"pub fn from_utf_codepoints(\n  utf_codepoints: List(UtfCodepoint),\n) -&gt; String\n Converts a `List` of `UtfCodepoint`s to a `String`.\n\n See &lt;https://en.wikipedia.org/wiki/Code_point&gt; and\n &lt;https://en.wikipedia.org/wiki/Unicode#Codespace_and_Code_Points&gt; for an\n explanation on code points.\n\n ## Examples\n\n \n &gt; {\n &gt;   let assert #(Ok(a), Ok(b), Ok(c)) = #(\n &gt;     utf_codepoint(97),\n &gt;     utf_codepoint(98),\n &gt;     utf_codepoint(99),\n &gt;   )\n &gt;   [a, b, c]\n &gt; }\n &gt; |&gt; from_utf_codepoints\n &quot;abc&quot;\n \n\nSynonyms:\ngleam/string.from_utf_codepoints\ngleam/string from_utf_codepoints","url":"gleam/string.html#from_utf_codepoints"},{"doc":"gleam/string","title":"inspect","content":"pub fn inspect(term: a) -&gt; String\n Returns a `String` representation of a term in Gleam syntax.\n\nSynonyms:\ngleam/string.inspect\ngleam/string inspect","url":"gleam/string.html#inspect"},{"doc":"gleam/string","title":"is_empty","content":"pub fn is_empty(str: String) -&gt; Bool\n Determines if a `String` is empty.\n\n ## Examples\n\n \n &gt; is_empty(&quot;&quot;)\n True\n \n\n \n &gt; is_empty(&quot;the world&quot;)\n False\n \n\nSynonyms:\ngleam/string.is_empty\ngleam/string is_empty","url":"gleam/string.html#is_empty"},{"doc":"gleam/string","title":"join","content":"pub fn join(\n  strings: List(String),\n  with separator: String,\n) -&gt; String\n Joins many `String`s together with a given separator.\n\n This function runs in linear time.\n\n ## Examples\n\n \n &gt; join([&quot;home&quot;,&quot;evan&quot;,&quot;Desktop&quot;], with: &quot;/&quot;)\n &quot;home/evan/Desktop&quot;\n \n\nSynonyms:\ngleam/string.join\ngleam/string join","url":"gleam/string.html#join"},{"doc":"gleam/string","title":"last","content":"pub fn last(s: String) -&gt; Result(String, Nil)\n Returns the last grapheme cluster in a given `String` and wraps it in a\n `Result(String, Nil)`. If the `String` is empty, it returns `Error(Nil)`.\n Otherwise, it returns `Ok(String)`.\n\n ## Examples\n\n \n &gt; last(&quot;&quot;)\n Error(Nil)\n \n\n \n &gt; last(&quot;icecream&quot;)\n Ok(&quot;m&quot;)\n \n\nSynonyms:\ngleam/string.last\ngleam/string last","url":"gleam/string.html#last"},{"doc":"gleam/string","title":"length","content":"pub fn length(string: String) -&gt; Int\n Gets the number of grapheme clusters in a given `String`.\n\n This function has to iterate across the whole string to count the number of\n graphemes, so it runs in linear time.\n\n ## Examples\n\n \n &gt; length(&quot;Gleam&quot;)\n 5\n \n\n \n &gt; length(&quot;ß↑e̊&quot;)\n 3\n \n\n \n &gt; length(&quot;&quot;)\n 0\n \n\nSynonyms:\ngleam/string.length\ngleam/string length","url":"gleam/string.html#length"},{"doc":"gleam/string","title":"lowercase","content":"pub fn lowercase(string: String) -&gt; String\n Creates a new `String` with all the graphemes in the input `String` converted to\n lowercase.\n\n Useful for case-insensitive comparisons.\n\n ## Examples\n\n \n &gt; lowercase(&quot;X-FILES&quot;)\n &quot;x-files&quot;\n \n\nSynonyms:\ngleam/string.lowercase\ngleam/string lowercase","url":"gleam/string.html#lowercase"},{"doc":"gleam/string","title":"pad_left","content":"pub fn pad_left(\n  string: String,\n  to desired_length: Int,\n  with pad_string: String,\n) -&gt; String\n Pads a `String` on the left until it has at least given number of graphemes.\n\n ## Examples\n\n \n &gt; pad_left(&quot;121&quot;, to: 5, with: &quot;.&quot;)\n &quot;..121&quot;\n \n\n \n &gt; pad_left(&quot;121&quot;, to: 3, with: &quot;.&quot;)\n &quot;121&quot;\n \n\n \n &gt; pad_left(&quot;121&quot;, to: 2, with: &quot;.&quot;)\n &quot;121&quot;\n \n\nSynonyms:\ngleam/string.pad_left\ngleam/string pad_left","url":"gleam/string.html#pad_left"},{"doc":"gleam/string","title":"pad_right","content":"pub fn pad_right(\n  string: String,\n  to desired_length: Int,\n  with pad_string: String,\n) -&gt; String\n Pads a `String` on the right until it has a given length.\n\n ## Examples\n\n \n &gt; pad_right(&quot;123&quot;, to: 5, with: &quot;.&quot;)\n &quot;123..&quot;\n \n\n \n &gt; pad_right(&quot;123&quot;, to: 3, with: &quot;.&quot;)\n &quot;123&quot;\n \n\n \n &gt; pad_right(&quot;123&quot;, to: 2, with: &quot;.&quot;)\n &quot;123&quot;\n \n\nSynonyms:\ngleam/string.pad_right\ngleam/string pad_right","url":"gleam/string.html#pad_right"},{"doc":"gleam/string","title":"pop_grapheme","content":"pub fn pop_grapheme(\n  string: String,\n) -&gt; Result(#(String, String), Nil)\n Splits a non-empty `String` into its first element (head) and rest (tail).\n This lets you pattern match on `String`s exactly as you would with lists.\n\n Note on JavaScript using the function to iterate over a string will likely\n be slower than using `to_graphemes` due to string slicing being more\n expensive on JavaScript than Erlang.\n\n ## Examples\n\n \n &gt; pop_grapheme(&quot;gleam&quot;)\n Ok(#(&quot;g&quot;, &quot;leam&quot;))\n \n\n \n &gt; pop_grapheme(&quot;&quot;)\n Error(Nil)\n \n\nSynonyms:\ngleam/string.pop_grapheme\ngleam/string pop_grapheme","url":"gleam/string.html#pop_grapheme"},{"doc":"gleam/string","title":"repeat","content":"pub fn repeat(string: String, times times: Int) -&gt; String\n Creates a new `String` by repeating a `String` a given number of times.\n\n This function runs in linear time.\n\n ## Examples\n\n \n &gt; repeat(&quot;ha&quot;, times: 3)\n &quot;hahaha&quot;\n \n\nSynonyms:\ngleam/string.repeat\ngleam/string repeat","url":"gleam/string.html#repeat"},{"doc":"gleam/string","title":"replace","content":"pub fn replace(\n  in string: String,\n  each pattern: String,\n  with substitute: String,\n) -&gt; String\n Creates a new `String` by replacing all occurrences of a given substring.\n\n ## Examples\n\n \n &gt; replace(&quot;www.example.com&quot;, each: &quot;.&quot;, with: &quot;-&quot;)\n &quot;www-example-com&quot;\n \n\n \n &gt; replace(&quot;a,b,c,d,e&quot;, each: &quot;,&quot;, with: &quot;/&quot;)\n &quot;a/b/c/d/e&quot;\n \n\nSynonyms:\ngleam/string.replace\ngleam/string replace","url":"gleam/string.html#replace"},{"doc":"gleam/string","title":"reverse","content":"pub fn reverse(string: String) -&gt; String\n Reverses a `String`.\n\n This function has to iterate across the whole `String` so it runs in linear\n time.\n\n ## Examples\n\n \n &gt; reverse(&quot;stressed&quot;)\n &quot;desserts&quot;\n \n\nSynonyms:\ngleam/string.reverse\ngleam/string reverse","url":"gleam/string.html#reverse"},{"doc":"gleam/string","title":"slice","content":"pub fn slice(\n  from string: String,\n  at_index idx: Int,\n  length len: Int,\n) -&gt; String\n Takes a substring given a start grapheme index and a length. Negative indexes\n are taken starting from the *end* of the list.\n\n ## Examples\n\n \n &gt; slice(from: &quot;gleam&quot;, at_index: 1, length: 2)\n &quot;le&quot;\n \n\n \n &gt; slice(from: &quot;gleam&quot;, at_index: 1, length: 10)\n &quot;leam&quot;\n \n\n \n &gt; slice(from: &quot;gleam&quot;, at_index: 10, length: 3)\n &quot;&quot;\n \n\n \n &gt; slice(from: &quot;gleam&quot;, at_index: -2, length: 2)\n &quot;am&quot;\n \n\n \n &gt; slice(from: &quot;gleam&quot;, at_index: -12, length: 2)\n &quot;&quot;\n \n\nSynonyms:\ngleam/string.slice\ngleam/string slice","url":"gleam/string.html#slice"},{"doc":"gleam/string","title":"split","content":"pub fn split(x: String, on substring: String) -&gt; List(String)\n Creates a list of `String`s by splitting a given string on a given substring.\n\n ## Examples\n\n \n &gt; split(&quot;home/gleam/desktop/&quot;, on: &quot;/&quot;)\n [&quot;home&quot;, &quot;gleam&quot;, &quot;desktop&quot;, &quot;&quot;]\n \n\nSynonyms:\ngleam/string.split\ngleam/string split","url":"gleam/string.html#split"},{"doc":"gleam/string","title":"split_once","content":"pub fn split_once(\n  x: String,\n  on substring: String,\n) -&gt; Result(#(String, String), Nil)\n Splits a `String` a single time on the given substring.\n\n Returns an `Error` if substring not present.\n\n ## Examples\n\n \n &gt; split_once(&quot;home/gleam/desktop/&quot;, on: &quot;/&quot;)\n Ok(#(&quot;home&quot;, &quot;gleam/desktop/&quot;))\n \n\n \n &gt; split_once(&quot;home/gleam/desktop/&quot;, on: &quot;?&quot;)\n Error(Nil)\n \n\nSynonyms:\ngleam/string.split_once\ngleam/string split_once","url":"gleam/string.html#split_once"},{"doc":"gleam/string","title":"starts_with","content":"pub fn starts_with(string: String, prefix: String) -&gt; Bool\n Checks whether the first `String` starts with the second one.\n\n ## Examples\n\n \n &gt; starts_with(&quot;theory&quot;, &quot;ory&quot;)\n False\n \n\nSynonyms:\ngleam/string.starts_with\ngleam/string starts_with","url":"gleam/string.html#starts_with"},{"doc":"gleam/string","title":"to_graphemes","content":"pub fn to_graphemes(string: String) -&gt; List(String)\n Converts a `String` to a list of\n [graphemes](https://en.wikipedia.org/wiki/Grapheme).\n\n \n &gt; to_graphemes(&quot;abc&quot;)\n [&quot;a&quot;, &quot;b&quot;, &quot;c&quot;]\n \n\nSynonyms:\ngleam/string.to_graphemes\ngleam/string to_graphemes","url":"gleam/string.html#to_graphemes"},{"doc":"gleam/string","title":"to_option","content":"pub fn to_option(s: String) -&gt; Option(String)\n Converts a `String` into `Option(String)` where an empty `String` becomes\n `None`.\n\n ## Examples\n\n \n &gt; to_option(&quot;&quot;)\n None\n \n\n \n &gt; to_option(&quot;hats&quot;)\n Some(&quot;hats&quot;)\n \n\nSynonyms:\ngleam/string.to_option\ngleam/string to_option","url":"gleam/string.html#to_option"},{"doc":"gleam/string","title":"to_utf_codepoints","content":"pub fn to_utf_codepoints(string: String) -&gt; List(UtfCodepoint)\n Converts a `String` to a `List` of `UtfCodepoint`.\n\n See &lt;https://en.wikipedia.org/wiki/Code_point&gt; and\n &lt;https://en.wikipedia.org/wiki/Unicode#Codespace_and_Code_Points&gt; for an\n explanation on code points.\n\n ## Examples\n\n \n &gt; &quot;a&quot; |&gt; to_utf_codepoints\n [UtfCodepoint(97)]\n \n\n \n // Semantically the same as:\n // [&quot;🏳&quot;, &quot;️&quot;, &quot;‍&quot;, &quot;🌈&quot;] or:\n // [waving_white_flag, variant_selector_16, zero_width_joiner, rainbow]\n &gt; &quot;🏳️‍🌈&quot; |&gt; to_utf_codepoints\n [UtfCodepoint(127987), UtfCodepoint(65039), UtfCodepoint(8205), UtfCodepoint(127752)]\n \n\nSynonyms:\ngleam/string.to_utf_codepoints\ngleam/string to_utf_codepoints","url":"gleam/string.html#to_utf_codepoints"},{"doc":"gleam/string","title":"trim","content":"pub fn trim(string: String) -&gt; String\n Removes whitespace on both sides of a `String`.\n\n ## Examples\n\n \n &gt; trim(&quot;  hats  \\n&quot;)\n &quot;hats&quot;\n \n\nSynonyms:\ngleam/string.trim\ngleam/string trim","url":"gleam/string.html#trim"},{"doc":"gleam/string","title":"trim_left","content":"pub fn trim_left(string: String) -&gt; String\n Removes whitespace on the left of a `String`.\n\n ## Examples\n\n \n &gt; trim_left(&quot;  hats  \\n&quot;)\n &quot;hats  \\n&quot;\n \n\nSynonyms:\ngleam/string.trim_left\ngleam/string trim_left","url":"gleam/string.html#trim_left"},{"doc":"gleam/string","title":"trim_right","content":"pub fn trim_right(string: String) -&gt; String\n Removes whitespace on the right of a `String`.\n\n ## Examples\n\n \n &gt; trim_right(&quot;  hats  \\n&quot;)\n &quot;  hats&quot;\n \n\nSynonyms:\ngleam/string.trim_right\ngleam/string trim_right","url":"gleam/string.html#trim_right"},{"doc":"gleam/string","title":"uppercase","content":"pub fn uppercase(string: String) -&gt; String\n Creates a new `String` with all the graphemes in the input `String` converted to\n uppercase.\n\n Useful for case-insensitive comparisons and VIRTUAL YELLING.\n\n ## Examples\n\n \n &gt; uppercase(&quot;skinner&quot;)\n &quot;SKINNER&quot;\n \n\nSynonyms:\ngleam/string.uppercase\ngleam/string uppercase","url":"gleam/string.html#uppercase"},{"doc":"gleam/string","title":"utf_codepoint","content":"pub fn utf_codepoint(value: Int) -&gt; Result(UtfCodepoint, Nil)\n Converts an integer to a `UtfCodepoint`.\n\n Returns an `Error` if the integer does not represent a valid UTF codepoint.\n\nSynonyms:\ngleam/string.utf_codepoint\ngleam/string utf_codepoint","url":"gleam/string.html#utf_codepoint"},{"doc":"gleam/string","title":"utf_codepoint_to_int","content":"pub fn utf_codepoint_to_int(cp: UtfCodepoint) -&gt; Int\n Converts an UtfCodepoint to its ordinal code point value.\n\n ## Examples\n\n \n &gt; utf_codepoint_to_int(128013) |&gt; to_utf_codepoint_int\n 128013\n \n\nSynonyms:\ngleam/string.utf_codepoint_to_int\ngleam/string utf_codepoint_to_int","url":"gleam/string.html#utf_codepoint_to_int"},{"doc":"gleam/string","title":"gleam/string","content":" Strings in Gleam are UTF-8 binaries. They can be written in your code as\n text surrounded by `&quot;double quotes&quot;`.","url":"gleam/string.html"},{"doc":"gleam/bit_array","title":"append","content":"pub fn append(\n  to first: BitArray,\n  suffix second: BitArray,\n) -&gt; BitArray\n Creates a new bit array by joining two bit arrays.\n\n ## Examples\n\n \n &gt; append(to: from_string(&quot;butter&quot;), suffix: from_string(&quot;fly&quot;))\n from_string(&quot;butterfly&quot;)\n \n\nSynonyms:\ngleam/bit_array.append\ngleam/bit_array append","url":"gleam/bit_array.html#append"},{"doc":"gleam/bit_array","title":"base16_decode","content":"pub fn base16_decode(input: String) -&gt; Result(BitArray, Nil)\n\nSynonyms:\ngleam/bit_array.base16_decode\ngleam/bit_array base16_decode","url":"gleam/bit_array.html#base16_decode"},{"doc":"gleam/bit_array","title":"base16_encode","content":"pub fn base16_encode(input: BitArray) -&gt; String\n\nSynonyms:\ngleam/bit_array.base16_encode\ngleam/bit_array base16_encode","url":"gleam/bit_array.html#base16_encode"},{"doc":"gleam/bit_array","title":"base64_decode","content":"pub fn base64_decode(encoded: String) -&gt; Result(BitArray, Nil)\n Decodes a base 64 encoded string into a `BitArray`.\n\nSynonyms:\ngleam/bit_array.base64_decode\ngleam/bit_array base64_decode","url":"gleam/bit_array.html#base64_decode"},{"doc":"gleam/bit_array","title":"base64_encode","content":"pub fn base64_encode(input: BitArray, padding: Bool) -&gt; String\n Encodes a BitArray into a base 64 encoded string.\n\nSynonyms:\ngleam/bit_array.base64_encode\ngleam/bit_array base64_encode","url":"gleam/bit_array.html#base64_encode"},{"doc":"gleam/bit_array","title":"base64_url_decode","content":"pub fn base64_url_decode(\n  encoded: String,\n) -&gt; Result(BitArray, Nil)\n Decodes a base 64 encoded string with URL and filename safe alphabet into a `BitArray`.\n\nSynonyms:\ngleam/bit_array.base64_url_decode\ngleam/bit_array base64_url_decode","url":"gleam/bit_array.html#base64_url_decode"},{"doc":"gleam/bit_array","title":"base64_url_encode","content":"pub fn base64_url_encode(\n  input: BitArray,\n  padding: Bool,\n) -&gt; String\n Encodes a `BitArray` into a base 64 encoded string with URL and filename safe alphabet.\n\nSynonyms:\ngleam/bit_array.base64_url_encode\ngleam/bit_array base64_url_encode","url":"gleam/bit_array.html#base64_url_encode"},{"doc":"gleam/bit_array","title":"byte_size","content":"pub fn byte_size(x: BitArray) -&gt; Int\n Returns an integer which is the number of bytes in the bit array.\n\nSynonyms:\ngleam/bit_array.byte_size\ngleam/bit_array byte_size","url":"gleam/bit_array.html#byte_size"},{"doc":"gleam/bit_array","title":"concat","content":"pub fn concat(bit_arrays: List(BitArray)) -&gt; BitArray\n Creates a new bit array by joining multiple binaries.\n\n ## Examples\n\n \n &gt; concat([from_string(&quot;butter&quot;), from_string(&quot;fly&quot;)])\n from_string(&quot;butterfly&quot;)\n \n\nSynonyms:\ngleam/bit_array.concat\ngleam/bit_array concat","url":"gleam/bit_array.html#concat"},{"doc":"gleam/bit_array","title":"from_string","content":"pub fn from_string(x: String) -&gt; BitArray\n Converts a UTF-8 `String` type into a `BitArray`.\n\nSynonyms:\ngleam/bit_array.from_string\ngleam/bit_array from_string","url":"gleam/bit_array.html#from_string"},{"doc":"gleam/bit_array","title":"is_utf8","content":"pub fn is_utf8(bits: BitArray) -&gt; Bool\n Tests to see whether a bit array is valid UTF-8.\n\nSynonyms:\ngleam/bit_array.is_utf8\ngleam/bit_array is_utf8","url":"gleam/bit_array.html#is_utf8"},{"doc":"gleam/bit_array","title":"slice","content":"pub fn slice(\n  from string: BitArray,\n  at position: Int,\n  take length: Int,\n) -&gt; Result(BitArray, Nil)\n Extracts a sub-section of a bit array.\n\n The slice will start at given position and continue up to specified\n length.\n A negative length can be used to extract bytes at the end of a bit array.\n\n This function runs in constant time.\n\nSynonyms:\ngleam/bit_array.slice\ngleam/bit_array slice","url":"gleam/bit_array.html#slice"},{"doc":"gleam/bit_array","title":"to_string","content":"pub fn to_string(bits: BitArray) -&gt; Result(String, Nil)\n Converts a bit array to a string.\n\n Returns an error if the bit array is invalid UTF-8 data.\n\nSynonyms:\ngleam/bit_array.to_string\ngleam/bit_array to_string","url":"gleam/bit_array.html#to_string"},{"doc":"gleam/bit_array","title":"gleam/bit_array","content":" BitArrays are a sequence of binary data of any length.","url":"gleam/bit_array.html"},{"doc":"gleam/bit_string","title":"append","content":"pub fn append(\n  to first: BitArray,\n  suffix second: BitArray,\n) -&gt; BitArray\n\nSynonyms:\ngleam/bit_string.append\ngleam/bit_string append","url":"gleam/bit_string.html#append"},{"doc":"gleam/bit_string","title":"byte_size","content":"pub fn byte_size(x: BitArray) -&gt; Int\n\nSynonyms:\ngleam/bit_string.byte_size\ngleam/bit_string byte_size","url":"gleam/bit_string.html#byte_size"},{"doc":"gleam/bit_string","title":"concat","content":"pub fn concat(bit_strings: List(BitArray)) -&gt; BitArray\n\nSynonyms:\ngleam/bit_string.concat\ngleam/bit_string concat","url":"gleam/bit_string.html#concat"},{"doc":"gleam/bit_string","title":"from_string","content":"pub fn from_string(x: String) -&gt; BitArray\n\nSynonyms:\ngleam/bit_string.from_string\ngleam/bit_string from_string","url":"gleam/bit_string.html#from_string"},{"doc":"gleam/bit_string","title":"is_utf8","content":"pub fn is_utf8(bits: BitArray) -&gt; Bool\n\nSynonyms:\ngleam/bit_string.is_utf8\ngleam/bit_string is_utf8","url":"gleam/bit_string.html#is_utf8"},{"doc":"gleam/bit_string","title":"slice","content":"pub fn slice(\n  from string: BitArray,\n  at position: Int,\n  take length: Int,\n) -&gt; Result(BitArray, Nil)\n\nSynonyms:\ngleam/bit_string.slice\ngleam/bit_string slice","url":"gleam/bit_string.html#slice"},{"doc":"gleam/bit_string","title":"to_string","content":"pub fn to_string(bits: BitArray) -&gt; Result(String, Nil)\n\nSynonyms:\ngleam/bit_string.to_string\ngleam/bit_string to_string","url":"gleam/bit_string.html#to_string"},{"doc":"gleam/bit_string","title":"gleam/bit_string","content":" This module has been deprecated. Please use the `gleam/bit_array` module\n instead.","url":"gleam/bit_string.html"},{"doc":"gleam/bytes_builder","title":"BytesBuilder","content":"pub opaque type BytesBuilder\n\n\nSynonyms:\ngleam/bytes_builder.BytesBuilder\ngleam/bytes_builder BytesBuilder","url":"gleam/bytes_builder.html#BytesBuilder"},{"doc":"gleam/bytes_builder","title":"append","content":"pub fn append(\n  to first: BytesBuilder,\n  suffix second: BitArray,\n) -&gt; BytesBuilder\n Appends a bit array to the end of a builder.\n\n Runs in constant time.\n\nSynonyms:\ngleam/bytes_builder.append\ngleam/bytes_builder append","url":"gleam/bytes_builder.html#append"},{"doc":"gleam/bytes_builder","title":"append_builder","content":"pub fn append_builder(\n  to first: BytesBuilder,\n  suffix second: BytesBuilder,\n) -&gt; BytesBuilder\n Appends a builder onto the end of another.\n\n Runs in constant time.\n\nSynonyms:\ngleam/bytes_builder.append_builder\ngleam/bytes_builder append_builder","url":"gleam/bytes_builder.html#append_builder"},{"doc":"gleam/bytes_builder","title":"append_string","content":"pub fn append_string(\n  to first: BytesBuilder,\n  suffix second: String,\n) -&gt; BytesBuilder\n Appends a string onto the end of a builder.\n\n Runs in constant time when running on Erlang.\n Runs in linear time with the length of the string otherwise.\n\nSynonyms:\ngleam/bytes_builder.append_string\ngleam/bytes_builder append_string","url":"gleam/bytes_builder.html#append_string"},{"doc":"gleam/bytes_builder","title":"byte_size","content":"pub fn byte_size(builder: BytesBuilder) -&gt; Int\n Returns the size of the builder&#39;s content in bytes.\n\n Runs in linear time.\n\nSynonyms:\ngleam/bytes_builder.byte_size\ngleam/bytes_builder byte_size","url":"gleam/bytes_builder.html#byte_size"},{"doc":"gleam/bytes_builder","title":"concat","content":"pub fn concat(builders: List(BytesBuilder)) -&gt; BytesBuilder\n Joins a list of builders into a single builder.\n\n Runs in constant time.\n\nSynonyms:\ngleam/bytes_builder.concat\ngleam/bytes_builder concat","url":"gleam/bytes_builder.html#concat"},{"doc":"gleam/bytes_builder","title":"concat_bit_arrays","content":"pub fn concat_bit_arrays(bits: List(BitArray)) -&gt; BytesBuilder\n Joins a list of bit arrays into a single builder.\n\n Runs in constant time.\n\nSynonyms:\ngleam/bytes_builder.concat_bit_arrays\ngleam/bytes_builder concat_bit_arrays","url":"gleam/bytes_builder.html#concat_bit_arrays"},{"doc":"gleam/bytes_builder","title":"from_bit_array","content":"pub fn from_bit_array(bits: BitArray) -&gt; BytesBuilder\n Creates a new builder from a bit array.\n\n Runs in constant time.\n\nSynonyms:\ngleam/bytes_builder.from_bit_array\ngleam/bytes_builder from_bit_array","url":"gleam/bytes_builder.html#from_bit_array"},{"doc":"gleam/bytes_builder","title":"from_string","content":"pub fn from_string(string: String) -&gt; BytesBuilder\n Creates a new builder from a string.\n\n Runs in constant time when running on Erlang.\n Runs in linear time otherwise.\n\nSynonyms:\ngleam/bytes_builder.from_string\ngleam/bytes_builder from_string","url":"gleam/bytes_builder.html#from_string"},{"doc":"gleam/bytes_builder","title":"from_string_builder","content":"pub fn from_string_builder(\n  builder: StringBuilder,\n) -&gt; BytesBuilder\n Creates a new builder from a string builder.\n\n Runs in constant time when running on Erlang.\n Runs in linear time otherwise.\n\nSynonyms:\ngleam/bytes_builder.from_string_builder\ngleam/bytes_builder from_string_builder","url":"gleam/bytes_builder.html#from_string_builder"},{"doc":"gleam/bytes_builder","title":"new","content":"pub fn new() -&gt; BytesBuilder\n Create an empty `BytesBuilder`. Useful as the start of a pipe chaining many\n builders together.\n\nSynonyms:\ngleam/bytes_builder.new\ngleam/bytes_builder new","url":"gleam/bytes_builder.html#new"},{"doc":"gleam/bytes_builder","title":"prepend","content":"pub fn prepend(\n  to second: BytesBuilder,\n  prefix first: BitArray,\n) -&gt; BytesBuilder\n Prepends a bit array to the start of a builder.\n\n Runs in constant time.\n\nSynonyms:\ngleam/bytes_builder.prepend\ngleam/bytes_builder prepend","url":"gleam/bytes_builder.html#prepend"},{"doc":"gleam/bytes_builder","title":"prepend_builder","content":"pub fn prepend_builder(\n  to second: BytesBuilder,\n  prefix first: BytesBuilder,\n) -&gt; BytesBuilder\n Prepends a builder onto the start of another.\n\n Runs in constant time.\n\nSynonyms:\ngleam/bytes_builder.prepend_builder\ngleam/bytes_builder prepend_builder","url":"gleam/bytes_builder.html#prepend_builder"},{"doc":"gleam/bytes_builder","title":"prepend_string","content":"pub fn prepend_string(\n  to second: BytesBuilder,\n  prefix first: String,\n) -&gt; BytesBuilder\n Prepends a string onto the start of a builder.\n\n Runs in constant time when running on Erlang.\n Runs in linear time with the length of the string otherwise.\n\nSynonyms:\ngleam/bytes_builder.prepend_string\ngleam/bytes_builder prepend_string","url":"gleam/bytes_builder.html#prepend_string"},{"doc":"gleam/bytes_builder","title":"to_bit_array","content":"pub fn to_bit_array(builder: BytesBuilder) -&gt; BitArray\n Turns an builder into a bit array.\n\n Runs in linear time.\n\n When running on Erlang this function is implemented natively by the\n virtual machine and is highly optimised.\n\nSynonyms:\ngleam/bytes_builder.to_bit_array\ngleam/bytes_builder to_bit_array","url":"gleam/bytes_builder.html#to_bit_array"},{"doc":"gleam/bytes_builder","title":"gleam/bytes_builder","content":" BytesBuilder is a type used for efficiently concatenating bytes together\n without copying.\n\n If we append one bit array to another the bit arrays must be copied to a\n new location in memory so that they can sit together. This behaviour\n enables efficient reading of the string but copying can be expensive,\n especially if we want to join many bit arrays together.\n\n BytesBuilder is different in that it can be joined together in constant\n time using minimal memory, and then can be efficiently converted to a\n bit array using the `to_bit_array` function.\n\n Byte builders are always byte aligned, so that a number of bits that is not\n divisible by 8 will be padded with 0s.\n\n On Erlang this type is compatible with Erlang&#39;s iolists.","url":"gleam/bytes_builder.html"},{"doc":"gleam/bit_builder","title":"BitBuilder","content":"pub type BitBuilder =\n  bytes_builder.BytesBuilder\n\n\nSynonyms:\ngleam/bit_builder.BitBuilder\ngleam/bit_builder BitBuilder","url":"gleam/bit_builder.html#BitBuilder"},{"doc":"gleam/bit_builder","title":"append","content":"pub fn append(to: BytesBuilder, suffix: BitArray) -&gt; BytesBuilder\n\nSynonyms:\ngleam/bit_builder.append\ngleam/bit_builder append","url":"gleam/bit_builder.html#append"},{"doc":"gleam/bit_builder","title":"append_builder","content":"pub fn append_builder(\n  to first: BytesBuilder,\n  suffix second: BytesBuilder,\n) -&gt; BytesBuilder\n\nSynonyms:\ngleam/bit_builder.append_builder\ngleam/bit_builder append_builder","url":"gleam/bit_builder.html#append_builder"},{"doc":"gleam/bit_builder","title":"append_string","content":"pub fn append_string(\n  to: BytesBuilder,\n  suffix: String,\n) -&gt; BytesBuilder\n\nSynonyms:\ngleam/bit_builder.append_string\ngleam/bit_builder append_string","url":"gleam/bit_builder.html#append_string"},{"doc":"gleam/bit_builder","title":"byte_size","content":"pub fn byte_size(builder: BytesBuilder) -&gt; Int\n\nSynonyms:\ngleam/bit_builder.byte_size\ngleam/bit_builder byte_size","url":"gleam/bit_builder.html#byte_size"},{"doc":"gleam/bit_builder","title":"concat","content":"pub fn concat(builders: List(BytesBuilder)) -&gt; BytesBuilder\n\nSynonyms:\ngleam/bit_builder.concat\ngleam/bit_builder concat","url":"gleam/bit_builder.html#concat"},{"doc":"gleam/bit_builder","title":"concat_bit_strings","content":"pub fn concat_bit_strings(bits: List(BitArray)) -&gt; BytesBuilder\n\nSynonyms:\ngleam/bit_builder.concat_bit_strings\ngleam/bit_builder concat_bit_strings","url":"gleam/bit_builder.html#concat_bit_strings"},{"doc":"gleam/bit_builder","title":"from_bit_string","content":"pub fn from_bit_string(bits: BitArray) -&gt; BytesBuilder\n\nSynonyms:\ngleam/bit_builder.from_bit_string\ngleam/bit_builder from_bit_string","url":"gleam/bit_builder.html#from_bit_string"},{"doc":"gleam/bit_builder","title":"from_string","content":"pub fn from_string(string: String) -&gt; BytesBuilder\n\nSynonyms:\ngleam/bit_builder.from_string\ngleam/bit_builder from_string","url":"gleam/bit_builder.html#from_string"},{"doc":"gleam/bit_builder","title":"from_string_builder","content":"pub fn from_string_builder(\n  builder: StringBuilder,\n) -&gt; BytesBuilder\n\nSynonyms:\ngleam/bit_builder.from_string_builder\ngleam/bit_builder from_string_builder","url":"gleam/bit_builder.html#from_string_builder"},{"doc":"gleam/bit_builder","title":"new","content":"pub fn new() -&gt; BytesBuilder\n\nSynonyms:\ngleam/bit_builder.new\ngleam/bit_builder new","url":"gleam/bit_builder.html#new"},{"doc":"gleam/bit_builder","title":"prepend","content":"pub fn prepend(\n  to: BytesBuilder,\n  prefix: BitArray,\n) -&gt; BytesBuilder\n\nSynonyms:\ngleam/bit_builder.prepend\ngleam/bit_builder prepend","url":"gleam/bit_builder.html#prepend"},{"doc":"gleam/bit_builder","title":"prepend_builder","content":"pub fn prepend_builder(\n  to: BytesBuilder,\n  prefix: BytesBuilder,\n) -&gt; BytesBuilder\n\nSynonyms:\ngleam/bit_builder.prepend_builder\ngleam/bit_builder prepend_builder","url":"gleam/bit_builder.html#prepend_builder"},{"doc":"gleam/bit_builder","title":"prepend_string","content":"pub fn prepend_string(\n  to: BytesBuilder,\n  prefix: String,\n) -&gt; BytesBuilder\n\nSynonyms:\ngleam/bit_builder.prepend_string\ngleam/bit_builder prepend_string","url":"gleam/bit_builder.html#prepend_string"},{"doc":"gleam/bit_builder","title":"to_bit_string","content":"pub fn to_bit_string(builder: BytesBuilder) -&gt; BitArray\n\nSynonyms:\ngleam/bit_builder.to_bit_string\ngleam/bit_builder to_bit_string","url":"gleam/bit_builder.html#to_bit_string"},{"doc":"gleam/bit_builder","title":"gleam/bit_builder","content":" This module has been deprecated in favour of `gleam/bytes_builder`.","url":"gleam/bit_builder.html"},{"doc":"gleam/set","title":"Set","content":"pub opaque type Set(member)\n A set is a collection of unique members of the same type.\n\n It is implemented using the `gleam/map` module, so inserts and lookups have\n logarithmic time complexity.\n\n\nSynonyms:\ngleam/set.Set\ngleam/set Set","url":"gleam/set.html#Set"},{"doc":"gleam/set","title":"contains","content":"pub fn contains(in set: Set(a), this member: a) -&gt; Bool\n Checks whether a set contains a given member.\n\n This function runs in logarithmic time.\n\n ## Examples\n\n \n &gt; new()\n &gt; |&gt; insert(2)\n &gt; |&gt; contains(2)\n True\n \n\n \n &gt; new()\n &gt; |&gt; insert(2)\n &gt; |&gt; contains(1)\n False\n \n\nSynonyms:\ngleam/set.contains\ngleam/set contains","url":"gleam/set.html#contains"},{"doc":"gleam/set","title":"delete","content":"pub fn delete(from set: Set(a), this member: a) -&gt; Set(a)\n Removes a member from a set. If the set does not contain the member then\n the set is returned unchanged.\n\n This function runs in logarithmic time.\n\n ## Examples\n\n \n &gt; new()\n &gt; |&gt; insert(2)\n &gt; |&gt; delete(2)\n &gt; |&gt; contains(1)\n False\n \n\nSynonyms:\ngleam/set.delete\ngleam/set delete","url":"gleam/set.html#delete"},{"doc":"gleam/set","title":"drop","content":"pub fn drop(from set: Set(a), drop disallowed: List(a)) -&gt; Set(a)\n\nSynonyms:\ngleam/set.drop\ngleam/set drop","url":"gleam/set.html#drop"},{"doc":"gleam/set","title":"filter","content":"pub fn filter(\n  in set: Set(a),\n  keeping predicate: fn(a) -&gt; Bool,\n) -&gt; Set(a)\n Creates a new set from an existing set, minus any members that a given\n function returns `False` for.\n\n This function runs in loglinear time.\n\n ## Examples\n\n \n &gt; import gleam/int\n &gt; from_list([1, 4, 6, 3, 675, 44, 67])\n &gt; |&gt; filter(for: int.is_even)\n &gt; |&gt; to_list\n [4, 6, 44]\n \n\nSynonyms:\ngleam/set.filter\ngleam/set filter","url":"gleam/set.html#filter"},{"doc":"gleam/set","title":"fold","content":"pub fn fold(\n  over set: Set(a),\n  from initial: b,\n  with reducer: fn(b, a) -&gt; b,\n) -&gt; b\n Combines all entries into a single value by calling a given function on each\n one.\n\n Sets are not ordered so the values are not returned in any specific order.\n Do not write code that relies on the order entries are used by this\n function as it may change in later versions of Gleam or Erlang.\n\n # Examples\n\n \n &gt; from_list([1, 3, 9])\n &gt; |&gt; fold(0, fn(member, accumulator) { accumulator + member })\n 13\n \n\nSynonyms:\ngleam/set.fold\ngleam/set fold","url":"gleam/set.html#fold"},{"doc":"gleam/set","title":"from_list","content":"pub fn from_list(members: List(a)) -&gt; Set(a)\n Creates a new set of the members in a given list.\n\n This function runs in loglinear time.\n\n ## Examples\n\n \n &gt; import gleam/list\n &gt; [1, 1, 2, 4, 3, 2] |&gt; from_list |&gt; to_list |&gt; list.sort\n [1, 3, 3, 4]\n \n\nSynonyms:\ngleam/set.from_list\ngleam/set from_list","url":"gleam/set.html#from_list"},{"doc":"gleam/set","title":"insert","content":"pub fn insert(into set: Set(a), this member: a) -&gt; Set(a)\n Inserts an member into the set.\n\n This function runs in logarithmic time.\n\n ## Examples\n\n \n &gt; new()\n &gt; |&gt; insert(1)\n &gt; |&gt; insert(2)\n &gt; |&gt; size\n 2\n \n\nSynonyms:\ngleam/set.insert\ngleam/set insert","url":"gleam/set.html#insert"},{"doc":"gleam/set","title":"intersection","content":"pub fn intersection(\n  of first: Set(a),\n  and second: Set(a),\n) -&gt; Set(a)\n Creates a new set that contains members that are present in both given sets.\n\n This function runs in loglinear time.\n\n ## Examples\n\n \n &gt; intersection(from_list([1, 2]), from_list([2, 3])) |&gt; to_list\n [2]\n \n\nSynonyms:\ngleam/set.intersection\ngleam/set intersection","url":"gleam/set.html#intersection"},{"doc":"gleam/set","title":"new","content":"pub fn new() -&gt; Set(a)\n Creates a new empty set.\n\nSynonyms:\ngleam/set.new\ngleam/set new","url":"gleam/set.html#new"},{"doc":"gleam/set","title":"size","content":"pub fn size(set: Set(a)) -&gt; Int\n Gets the number of members in a set.\n\n This function runs in constant time.\n\n ## Examples\n\n \n &gt; new()\n &gt; |&gt; insert(1)\n &gt; |&gt; insert(2)\n &gt; |&gt; size\n 2\n \n\nSynonyms:\ngleam/set.size\ngleam/set size","url":"gleam/set.html#size"},{"doc":"gleam/set","title":"take","content":"pub fn take(from set: Set(a), keeping desired: List(a)) -&gt; Set(a)\n Creates a new map from a given map, only including any members which are in\n a given list.\n\n This function runs in loglinear time.\n\n ## Examples\n\n \n &gt; from_list([1, 2, 3])\n &gt; |&gt; take([1, 3, 5])\n &gt; |&gt; to_list\n [1, 3]\n \n\nSynonyms:\ngleam/set.take\ngleam/set take","url":"gleam/set.html#take"},{"doc":"gleam/set","title":"to_list","content":"pub fn to_list(set: Set(a)) -&gt; List(a)\n Converts the set into a list of the contained members.\n\n The list has no specific ordering, any unintentional ordering may change in\n future versions of Gleam or Erlang.\n\n This function runs in linear time.\n\n ## Examples\n\n \n &gt; new() |&gt; insert(2) |&gt; to_list\n [2]\n \n\nSynonyms:\ngleam/set.to_list\ngleam/set to_list","url":"gleam/set.html#to_list"},{"doc":"gleam/set","title":"union","content":"pub fn union(of first: Set(a), and second: Set(a)) -&gt; Set(a)\n Creates a new set that contains all members of both given sets.\n\n This function runs in loglinear time.\n\n ## Examples\n\n \n &gt; union(from_list([1, 2]), from_list([2, 3])) |&gt; to_list\n [1, 2, 3]\n \n\nSynonyms:\ngleam/set.union\ngleam/set union","url":"gleam/set.html#union"},{"doc":"gleam/set","title":"gleam/set","content":"","url":"gleam/set.html"},{"doc":"gleam/dynamic","title":"DecodeError","content":"pub type DecodeError {\n  DecodeError(\n    expected: String,\n    found: String,\n    path: List(String),\n  )\n}\n Error returned when unexpected data is encountered\n\nDecodeError(expected: String, found: String, path: List(String))\n\n\nSynonyms:\ngleam/dynamic.DecodeError\ngleam/dynamic DecodeError","url":"gleam/dynamic.html#DecodeError"},{"doc":"gleam/dynamic","title":"DecodeErrors","content":"pub type DecodeErrors =\n  List(DecodeError)\n\n\nSynonyms:\ngleam/dynamic.DecodeErrors\ngleam/dynamic DecodeErrors","url":"gleam/dynamic.html#DecodeErrors"},{"doc":"gleam/dynamic","title":"Decoder","content":"pub type Decoder(t) =\n  fn(Dynamic) -&gt; Result(t, DecodeErrors)\n\n\nSynonyms:\ngleam/dynamic.Decoder\ngleam/dynamic Decoder","url":"gleam/dynamic.html#Decoder"},{"doc":"gleam/dynamic","title":"Dynamic","content":"pub type Dynamic\n `Dynamic` data is data that we don&#39;t know the type of yet.\n We likely get data like this from interop with Erlang, or from\n IO with the outside world.\n\n\nSynonyms:\ngleam/dynamic.Dynamic\ngleam/dynamic Dynamic","url":"gleam/dynamic.html#Dynamic"},{"doc":"gleam/dynamic","title":"any","content":"pub fn any(\n  of decoders: List(fn(Dynamic) -&gt; Result(a, List(DecodeError))),\n) -&gt; fn(Dynamic) -&gt; Result(a, List(DecodeError))\n Joins multiple decoders into one. When run they will each be tried in turn\n until one succeeds, or they all fail.\n\n ## Examples\n\n \n &gt; import gleam/result\n &gt; let bool_or_string = any(of: [\n &gt;   string,\n &gt;   fn(x) { result.map(bool(x), fn(_) { &quot;a bool&quot; }) }\n &gt; ])\n &gt; bool_or_string(from(&quot;ok&quot;))\n Ok(&quot;ok&quot;)\n \n\n \n &gt; bool_or_string(from(True))\n Ok(&quot;a bool&quot;)\n \n\n \n &gt; bool_or_string(from(1))\n Error(DecodeError(expected: &quot;another type&quot;, found: &quot;Int&quot;, path: []))\n \n\nSynonyms:\ngleam/dynamic.any\ngleam/dynamic any","url":"gleam/dynamic.html#any"},{"doc":"gleam/dynamic","title":"bit_array","content":"pub fn bit_array(\n  from data: Dynamic,\n) -&gt; Result(BitArray, List(DecodeError))\n Checks to see whether a `Dynamic` value is a bit array, and returns that bit\n array if it is.\n\n ## Examples\n\n \n &gt; bit_array(from(&quot;Hello&quot;)) == bit_array.from_string(&quot;Hello&quot;)\n True\n \n\n \n &gt; bit_array(from(123))\n Error([DecodeError(expected: &quot;BitArray&quot;, found: &quot;Int&quot;, path: [])])\n \n\nSynonyms:\ngleam/dynamic.bit_array\ngleam/dynamic bit_array","url":"gleam/dynamic.html#bit_array"},{"doc":"gleam/dynamic","title":"bit_string","content":"pub fn bit_string(\n  from data: Dynamic,\n) -&gt; Result(BitArray, List(DecodeError))\n\nSynonyms:\ngleam/dynamic.bit_string\ngleam/dynamic bit_string","url":"gleam/dynamic.html#bit_string"},{"doc":"gleam/dynamic","title":"bool","content":"pub fn bool(\n  from data: Dynamic,\n) -&gt; Result(Bool, List(DecodeError))\n Checks to see whether a `Dynamic` value is a bool, and returns that bool if\n it is.\n\n ## Examples\n\n \n &gt; bool(from(True))\n Ok(True)\n \n\n \n &gt; bool(from(123))\n Error([DecodeError(expected: &quot;Bool&quot;, found: &quot;Int&quot;, path: [])])\n \n\nSynonyms:\ngleam/dynamic.bool\ngleam/dynamic bool","url":"gleam/dynamic.html#bool"},{"doc":"gleam/dynamic","title":"classify","content":"pub fn classify(data: Dynamic) -&gt; String\n Return a string indicating the type of the dynamic value.\n\n \n &gt; classify(from(&quot;Hello&quot;))\n &quot;String&quot;\n \n\nSynonyms:\ngleam/dynamic.classify\ngleam/dynamic classify","url":"gleam/dynamic.html#classify"},{"doc":"gleam/dynamic","title":"decode1","content":"pub fn decode1(\n  constructor: fn(a) -&gt; b,\n  t1: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n) -&gt; fn(Dynamic) -&gt; Result(b, List(DecodeError))\n Decode 1 values from a `Dynamic` value.\n\n ## Examples\n\n \n &gt; from(#(1, 2.0, &quot;3&quot;))\n &gt; |&gt; decode1(MyRecord, element(0, int))\n Ok(MyRecord(1))\n \n\n \n &gt; from(#(&quot;&quot;, &quot;&quot;, &quot;&quot;))\n &gt; |&gt; decode1(MyRecord, element(0, int))\n Error([\n   DecodeError(expected: &quot;Int&quot;, found: &quot;String&quot;, path: [&quot;0&quot;]),\n ])\n \n\nSynonyms:\ngleam/dynamic.decode1\ngleam/dynamic decode1","url":"gleam/dynamic.html#decode1"},{"doc":"gleam/dynamic","title":"decode2","content":"pub fn decode2(\n  constructor: fn(a, b) -&gt; c,\n  t1: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  t2: fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n) -&gt; fn(Dynamic) -&gt; Result(c, List(DecodeError))\n Decode 2 values from a `Dynamic` value.\n\n ## Examples\n\n \n &gt; from(#(1, 2.0, &quot;3&quot;))\n &gt; |&gt; decode2(MyRecord, element(0, int), element(1, float))\n Ok(MyRecord(1, 2.0))\n \n\n \n &gt; from(#(&quot;&quot;, &quot;&quot;, &quot;&quot;))\n &gt; |&gt; decode2(MyRecord, element(0, int), element(1, float))\n Error([\n   DecodeError(expected: &quot;Int&quot;, found: &quot;String&quot;, path: [&quot;0&quot;]),\n   DecodeError(expected: &quot;Float&quot;, found: &quot;String&quot;, path: [&quot;1&quot;]),\n ])\n \n\nSynonyms:\ngleam/dynamic.decode2\ngleam/dynamic decode2","url":"gleam/dynamic.html#decode2"},{"doc":"gleam/dynamic","title":"decode3","content":"pub fn decode3(\n  constructor: fn(a, b, c) -&gt; d,\n  t1: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  t2: fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n  t3: fn(Dynamic) -&gt; Result(c, List(DecodeError)),\n) -&gt; fn(Dynamic) -&gt; Result(d, List(DecodeError))\n Decode 3 values from a `Dynamic` value.\n\n ## Examples\n\n \n &gt; from(#(1, 2.0, &quot;3&quot;))\n &gt; |&gt; decode3(MyRecord, element(0, int), element(1, float), element(2, string))\n Ok(MyRecord(1, 2.0, &quot;3&quot;))\n \n\n \n &gt; from(#(&quot;&quot;, &quot;&quot;, &quot;&quot;))\n &gt; |&gt; decode3(MyRecord, element(0, int), element(1, float), element(2, string))\n Error([\n   DecodeError(expected: &quot;Int&quot;, found: &quot;String&quot;, path: [&quot;0&quot;]),\n   DecodeError(expected: &quot;Float&quot;, found: &quot;String&quot;, path: [&quot;1&quot;]),\n ])\n \n\nSynonyms:\ngleam/dynamic.decode3\ngleam/dynamic decode3","url":"gleam/dynamic.html#decode3"},{"doc":"gleam/dynamic","title":"decode4","content":"pub fn decode4(\n  constructor: fn(a, b, c, d) -&gt; e,\n  t1: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  t2: fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n  t3: fn(Dynamic) -&gt; Result(c, List(DecodeError)),\n  t4: fn(Dynamic) -&gt; Result(d, List(DecodeError)),\n) -&gt; fn(Dynamic) -&gt; Result(e, List(DecodeError))\n Decode 4 values from a `Dynamic` value.\n\n ## Examples\n\n \n &gt; from(#(1, 2.1, &quot;3&quot;, &quot;4&quot;))\n &gt; |&gt; decode4(\n &gt;   MyRecord,\n &gt;   element(0, int),\n &gt;   element(1, float),\n &gt;   element(2, string),\n &gt;   element(3, string),\n &gt; )\n Ok(MyRecord(1, 2.1, &quot;3&quot;, &quot;4&quot;))\n \n\n \n &gt; from(#(&quot;&quot;, &quot;&quot;, &quot;&quot;, &quot;&quot;))\n &gt; |&gt; decode4(\n &gt;   MyRecord,\n &gt;   element(0, int),\n &gt;   element(1, float),\n &gt;   element(2, string),\n &gt;   element(3, string),\n &gt; )\n Error([\n   DecodeError(expected: &quot;Int&quot;, found: &quot;String&quot;, path: [&quot;0&quot;]),\n   DecodeError(expected: &quot;Float&quot;, found: &quot;String&quot;, path: [&quot;1&quot;]),\n ])\n \n\nSynonyms:\ngleam/dynamic.decode4\ngleam/dynamic decode4","url":"gleam/dynamic.html#decode4"},{"doc":"gleam/dynamic","title":"decode5","content":"pub fn decode5(\n  constructor: fn(a, b, c, d, e) -&gt; f,\n  t1: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  t2: fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n  t3: fn(Dynamic) -&gt; Result(c, List(DecodeError)),\n  t4: fn(Dynamic) -&gt; Result(d, List(DecodeError)),\n  t5: fn(Dynamic) -&gt; Result(e, List(DecodeError)),\n) -&gt; fn(Dynamic) -&gt; Result(f, List(DecodeError))\n Decode 5 values from a `Dynamic` value.\n\n ## Examples\n\n \n &gt; from(#(1, 2.1, &quot;3&quot;, &quot;4&quot;, &quot;5&quot;))\n &gt; |&gt; decode5(\n &gt;   MyRecord,\n &gt;   element(0, int),\n &gt;   element(1, float),\n &gt;   element(2, string),\n &gt;   element(3, string),\n &gt;   element(4, string),\n &gt; )\n Ok(MyRecord(1, 2.1, &quot;3&quot;, &quot;4&quot;, &quot;5&quot;))\n \n\n \n &gt; from(#(&quot;&quot;, &quot;&quot;, &quot;&quot;, &quot;&quot;, &quot;&quot;))\n &gt; |&gt; decode5(\n &gt;   MyRecord,\n &gt;   element(0, int),\n &gt;   element(1, float),\n &gt;   element(2, string),\n &gt;   element(3, string),\n &gt;   element(4, string),\n &gt; )\n Error([\n   DecodeError(expected: &quot;Int&quot;, found: &quot;String&quot;, path: [&quot;0&quot;]),\n   DecodeError(expected: &quot;Float&quot;, found: &quot;String&quot;, path: [&quot;1&quot;]),\n ])\n \n\nSynonyms:\ngleam/dynamic.decode5\ngleam/dynamic decode5","url":"gleam/dynamic.html#decode5"},{"doc":"gleam/dynamic","title":"decode6","content":"pub fn decode6(\n  constructor: fn(a, b, c, d, e, f) -&gt; g,\n  t1: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  t2: fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n  t3: fn(Dynamic) -&gt; Result(c, List(DecodeError)),\n  t4: fn(Dynamic) -&gt; Result(d, List(DecodeError)),\n  t5: fn(Dynamic) -&gt; Result(e, List(DecodeError)),\n  t6: fn(Dynamic) -&gt; Result(f, List(DecodeError)),\n) -&gt; fn(Dynamic) -&gt; Result(g, List(DecodeError))\n Decode 6 values from a `Dynamic` value.\n\n ## Examples\n\n \n &gt; from(#(1, 2.1, &quot;3&quot;, &quot;4&quot;, &quot;5&quot;, &quot;6&quot;))\n &gt; |&gt; decode6(\n &gt;   MyRecord,\n &gt;   element(0, int),\n &gt;   element(1, float),\n &gt;   element(2, string),\n &gt;   element(3, string),\n &gt;   element(4, string),\n &gt;   element(5, string),\n &gt; )\n Ok(MyRecord(1, 2.1, &quot;3&quot;, &quot;4&quot;, &quot;5&quot;, &quot;6&quot;))\n \n\n \n &gt; from(#(&quot;&quot;, &quot;&quot;, &quot;&quot;, &quot;&quot;, &quot;&quot;, &quot;&quot;))\n &gt; |&gt; decode6(\n &gt;   MyRecord,\n &gt;   element(0, int),\n &gt;   element(1, float),\n &gt;   element(2, string),\n &gt;   element(3, string),\n &gt;   element(4, string),\n &gt;   element(5, string),\n &gt; )\n Error([\n   DecodeError(expected: &quot;Int&quot;, found: &quot;String&quot;, path: [&quot;0&quot;]),\n   DecodeError(expected: &quot;Float&quot;, found: &quot;String&quot;, path: [&quot;1&quot;]),\n ])\n \n\nSynonyms:\ngleam/dynamic.decode6\ngleam/dynamic decode6","url":"gleam/dynamic.html#decode6"},{"doc":"gleam/dynamic","title":"decode7","content":"pub fn decode7(\n  constructor: fn(a, b, c, d, e, f, g) -&gt; h,\n  t1: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  t2: fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n  t3: fn(Dynamic) -&gt; Result(c, List(DecodeError)),\n  t4: fn(Dynamic) -&gt; Result(d, List(DecodeError)),\n  t5: fn(Dynamic) -&gt; Result(e, List(DecodeError)),\n  t6: fn(Dynamic) -&gt; Result(f, List(DecodeError)),\n  t7: fn(Dynamic) -&gt; Result(g, List(DecodeError)),\n) -&gt; fn(Dynamic) -&gt; Result(h, List(DecodeError))\n Decode 7 values from a `Dynamic` value.\n\n ## Examples\n\n \n &gt; from(#(1, 2.1, &quot;3&quot;, &quot;4&quot;, &quot;5&quot;, &quot;6&quot;))\n &gt; |&gt; decode7(\n &gt;   MyRecord,\n &gt;   element(0, int),\n &gt;   element(1, float),\n &gt;   element(2, string),\n &gt;   element(3, string),\n &gt;   element(4, string),\n &gt;   element(5, string),\n &gt;   element(6, string),\n &gt; )\n Ok(MyRecord(1, 2.1, &quot;3&quot;, &quot;4&quot;, &quot;5&quot;, &quot;6&quot;, &quot;7&quot;))\n \n\n \n &gt; from(#(&quot;&quot;, &quot;&quot;, &quot;&quot;, &quot;&quot;, &quot;&quot;, &quot;&quot;, &quot;&quot;))\n &gt; |&gt; decode7(\n &gt;   MyRecord,\n &gt;   element(0, int),\n &gt;   element(1, float),\n &gt;   element(2, string),\n &gt;   element(3, string),\n &gt;   element(4, string),\n &gt;   element(5, string),\n &gt;   element(6, string),\n &gt; )\n Error([\n   DecodeError(expected: &quot;Int&quot;, found: &quot;String&quot;, path: [&quot;0&quot;]),\n   DecodeError(expected: &quot;Float&quot;, found: &quot;String&quot;, path: [&quot;1&quot;]),\n ])\n \n\nSynonyms:\ngleam/dynamic.decode7\ngleam/dynamic decode7","url":"gleam/dynamic.html#decode7"},{"doc":"gleam/dynamic","title":"decode8","content":"pub fn decode8(\n  constructor: fn(a, b, c, d, e, f, g, h) -&gt; i,\n  t1: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  t2: fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n  t3: fn(Dynamic) -&gt; Result(c, List(DecodeError)),\n  t4: fn(Dynamic) -&gt; Result(d, List(DecodeError)),\n  t5: fn(Dynamic) -&gt; Result(e, List(DecodeError)),\n  t6: fn(Dynamic) -&gt; Result(f, List(DecodeError)),\n  t7: fn(Dynamic) -&gt; Result(g, List(DecodeError)),\n  t8: fn(Dynamic) -&gt; Result(h, List(DecodeError)),\n) -&gt; fn(Dynamic) -&gt; Result(i, List(DecodeError))\n Decode 8 values from a `Dynamic` value.\n\n ## Examples\n\n \n &gt; from(#(1, 2.1, &quot;3&quot;, &quot;4&quot;, &quot;5&quot;, &quot;6&quot;, &quot;7&quot;, &quot;8&quot;))\n &gt; |&gt; decode8(\n &gt;   MyRecord,\n &gt;   element(0, int),\n &gt;   element(1, float),\n &gt;   element(2, string),\n &gt;   element(3, string),\n &gt;   element(4, string),\n &gt;   element(5, string),\n &gt;   element(6, string),\n &gt;   element(7, string),\n &gt; )\n Ok(MyRecord(1, 2.1, &quot;3&quot;, &quot;4&quot;, &quot;5&quot;, &quot;6&quot;, &quot;7&quot;, &quot;8&quot;))\n \n\n \n &gt; from(#(&quot;&quot;, &quot;&quot;, &quot;&quot;, &quot;&quot;, &quot;&quot;, &quot;&quot;, &quot;&quot;, &quot;&quot;))\n &gt; |&gt; decode8(\n &gt;   MyRecord,\n &gt;   element(0, int),\n &gt;   element(1, float),\n &gt;   element(2, string),\n &gt;   element(3, string),\n &gt;   element(4, string),\n &gt;   element(5, string),\n &gt;   element(6, string),\n &gt;   element(7, string),\n &gt; )\n Error([\n   DecodeError(expected: &quot;Int&quot;, found: &quot;String&quot;, path: [&quot;0&quot;]),\n   DecodeError(expected: &quot;Float&quot;, found: &quot;String&quot;, path: [&quot;1&quot;]),\n ])\n \n\nSynonyms:\ngleam/dynamic.decode8\ngleam/dynamic decode8","url":"gleam/dynamic.html#decode8"},{"doc":"gleam/dynamic","title":"decode9","content":"pub fn decode9(\n  constructor: fn(a, b, c, d, e, f, g, h, i) -&gt; j,\n  t1: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  t2: fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n  t3: fn(Dynamic) -&gt; Result(c, List(DecodeError)),\n  t4: fn(Dynamic) -&gt; Result(d, List(DecodeError)),\n  t5: fn(Dynamic) -&gt; Result(e, List(DecodeError)),\n  t6: fn(Dynamic) -&gt; Result(f, List(DecodeError)),\n  t7: fn(Dynamic) -&gt; Result(g, List(DecodeError)),\n  t8: fn(Dynamic) -&gt; Result(h, List(DecodeError)),\n  t9: fn(Dynamic) -&gt; Result(i, List(DecodeError)),\n) -&gt; fn(Dynamic) -&gt; Result(j, List(DecodeError))\n Decode 9 values from a `Dynamic` value.\n\n ## Examples\n\n \n &gt; from(#(1, 2.1, &quot;3&quot;, &quot;4&quot;, &quot;5&quot;, &quot;6&quot;, &quot;7&quot;, &quot;8&quot;, &quot;9&quot;))\n &gt; |&gt; decode9(\n &gt;   MyRecord,\n &gt;   element(0, int),\n &gt;   element(1, float),\n &gt;   element(2, string),\n &gt;   element(3, string),\n &gt;   element(4, string),\n &gt;   element(5, string),\n &gt;   element(6, string),\n &gt;   element(7, string),\n &gt;   element(8, string),\n &gt; )\n Ok(MyRecord(1, 2.1, &quot;3&quot;, &quot;4&quot;, &quot;5&quot;, &quot;6&quot;, &quot;7&quot;, &quot;8&quot;, &quot;9&quot;))\n \n\n \n &gt; from(#(&quot;&quot;, &quot;&quot;, &quot;&quot;, &quot;&quot;, &quot;&quot;, &quot;&quot;, &quot;&quot;, &quot;&quot;, &quot;&quot;))\n &gt; |&gt; decode9(\n &gt;   MyRecord,\n &gt;   element(0, int),\n &gt;   element(1, float),\n &gt;   element(2, string),\n &gt;   element(3, string),\n &gt;   element(4, string),\n &gt;   element(5, string),\n &gt;   element(6, string),\n &gt;   element(7, string),\n &gt;   element(8, string),\n &gt; )\n Error([\n   DecodeError(expected: &quot;Int&quot;, found: &quot;String&quot;, path: [&quot;0&quot;]),\n   DecodeError(expected: &quot;Float&quot;, found: &quot;String&quot;, path: [&quot;1&quot;]),\n ])\n \n\nSynonyms:\ngleam/dynamic.decode9\ngleam/dynamic decode9","url":"gleam/dynamic.html#decode9"},{"doc":"gleam/dynamic","title":"dynamic","content":"pub fn dynamic(\n  value: Dynamic,\n) -&gt; Result(Dynamic, List(DecodeError))\n Decodes a `Dynamic` value from a `Dynamic` value.\n\n This function doesn&#39;t seem very useful at first, but it can be convenient\n when you need to give a decoder function but you don&#39;t actually care what\n the to-decode value is.\n\nSynonyms:\ngleam/dynamic.dynamic\ngleam/dynamic dynamic","url":"gleam/dynamic.html#dynamic"},{"doc":"gleam/dynamic","title":"element","content":"pub fn element(\n  at index: Int,\n  of inner_type: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n) -&gt; fn(Dynamic) -&gt; Result(a, List(DecodeError))\n Checks to see if a `Dynamic` value is a tuple large enough to have a certain\n index, and returns the value of that index if it is.\n\n ## Examples\n\n \n &gt; from(#(1, 2))\n &gt; |&gt; element(0, int)\n Ok(from(1))\n \n\n \n &gt; from(#(1, 2))\n &gt; |&gt; element(2, int)\n Error([\n   DecodeError(\n     expected: &quot;Tuple of at least 3 elements&quot;,\n     found: &quot;Tuple of 2 elements&quot;,\n     path: [],\n   ),\n ])\n \n\nSynonyms:\ngleam/dynamic.element\ngleam/dynamic element","url":"gleam/dynamic.html#element"},{"doc":"gleam/dynamic","title":"field","content":"pub fn field(\n  named name: a,\n  of inner_type: fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n) -&gt; fn(Dynamic) -&gt; Result(b, List(DecodeError))\n Checks to see if a `Dynamic` value is a map with a specific field, and returns\n the value of that field if it is.\n\n This will not succeed on a record.\n\n ## Examples\n\n \n &gt; import gleam/map\n &gt; map.new()\n &gt; |&gt; map.insert(&quot;Hello&quot;, &quot;World&quot;)\n &gt; |&gt; from\n &gt; |&gt; field(named: &quot;Hello&quot;, of: string)\n Ok(&quot;World&quot;)\n \n\n \n &gt; from(123)\n &gt; |&gt; field(&quot;Hello&quot;, string)\n Error([DecodeError(expected: &quot;Map&quot;, found: &quot;Int&quot;, path: [])])\n \n\nSynonyms:\ngleam/dynamic.field\ngleam/dynamic field","url":"gleam/dynamic.html#field"},{"doc":"gleam/dynamic","title":"float","content":"pub fn float(\n  from data: Dynamic,\n) -&gt; Result(Float, List(DecodeError))\n Checks to see whether a `Dynamic` value is a float, and returns that float if\n it is.\n\n ## Examples\n\n \n &gt; float(from(2.0))\n Ok(2.0)\n \n\n \n &gt; float(from(123))\n Error([DecodeError(expected: &quot;Float&quot;, found: &quot;Int&quot;, path: [])])\n \n\nSynonyms:\ngleam/dynamic.float\ngleam/dynamic float","url":"gleam/dynamic.html#float"},{"doc":"gleam/dynamic","title":"from","content":"pub fn from(a: a) -&gt; Dynamic\n Converts any Gleam data into `Dynamic` data.\n\nSynonyms:\ngleam/dynamic.from\ngleam/dynamic from","url":"gleam/dynamic.html#from"},{"doc":"gleam/dynamic","title":"int","content":"pub fn int(from data: Dynamic) -&gt; Result(Int, List(DecodeError))\n Checks to see whether a `Dynamic` value is an int, and returns that int if it\n is.\n\n ## Examples\n\n \n &gt; int(from(123))\n Ok(123)\n \n\n \n &gt; int(from(&quot;Hello&quot;))\n Error([DecodeError(expected: &quot;Int&quot;, found: &quot;String&quot;, path: [])])\n \n\nSynonyms:\ngleam/dynamic.int\ngleam/dynamic int","url":"gleam/dynamic.html#int"},{"doc":"gleam/dynamic","title":"list","content":"pub fn list(\n  of decoder_type: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n) -&gt; fn(Dynamic) -&gt; Result(List(a), List(DecodeError))\n Checks to see whether a `Dynamic` value is a list of a particular type, and\n returns that list if it is.\n\n The second argument is a decoder function used to decode the elements of\n the list. The list is only decoded if all elements in the list can be\n successfully decoded using this function.\n\n If you do not wish to decode all the elements in the list use the `shallow_list`\n function instead.\n\n ## Examples\n\n \n &gt; from([&quot;a&quot;, &quot;b&quot;, &quot;c&quot;])\n &gt; |&gt; list(of: string)\n Ok([&quot;a&quot;, &quot;b&quot;, &quot;c&quot;])\n \n\n \n &gt; from([1, 2, 3])\n &gt; |&gt; list(of: string)\n Error([DecodeError(expected: &quot;String&quot;, found: &quot;Int&quot;, path: [&quot;*&quot;])])\n \n\n \n &gt; from(&quot;ok&quot;)\n &gt; |&gt; list(of: string)\n Error([DecodeError(expected: &quot;List&quot;, found: &quot;String&quot;, path: [])])\n \n\nSynonyms:\ngleam/dynamic.list\ngleam/dynamic list","url":"gleam/dynamic.html#list"},{"doc":"gleam/dynamic","title":"map","content":"pub fn map(\n  of key_type: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  to value_type: fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n) -&gt; fn(Dynamic) -&gt; Result(Map(a, b), List(DecodeError))\n Checks to see if a `Dynamic` value is a map.\n\n ## Examples\n\n \n &gt; import gleam/map\n &gt; map.new() |&gt; from |&gt; map(string, int)\n Ok(map.new())\n \n\n \n &gt; from(1) |&gt; map(string, int)\n Error(DecodeError(expected: &quot;Map&quot;, found: &quot;Int&quot;, path: []))\n \n\n \n &gt; from(&quot;&quot;) |&gt; map(string, int)\n Error(DecodeError(expected: &quot;Map&quot;, found: &quot;String&quot;, path: []))\n \n\nSynonyms:\ngleam/dynamic.map\ngleam/dynamic map","url":"gleam/dynamic.html#map"},{"doc":"gleam/dynamic","title":"optional","content":"pub fn optional(\n  of decode: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n) -&gt; fn(Dynamic) -&gt; Result(Option(a), List(DecodeError))\n Checks to see if a `Dynamic` value is a nullable version of a particular\n type, and returns a corresponding `Option` if it is.\n\n ## Examples\n\n \n &gt; from(&quot;Hello&quot;)\n &gt; |&gt; optional(string)\n Ok(Some(&quot;Hello&quot;))\n \n\n \n &gt; from(&quot;Hello&quot;)\n &gt; |&gt; optional(string)\n Ok(Some(&quot;Hello&quot;))\n \n\n \n &gt; from(atom.from_string(&quot;null&quot;))\n &gt; |&gt; optional(string)\n Ok(None)\n \n\n \n &gt; from(atom.from_string(&quot;nil&quot;))\n &gt; |&gt; optional(string)\n Ok(None)\n \n\n \n &gt; from(atom.from_string(&quot;undefined&quot;))\n &gt; |&gt; optional(string)\n Ok(None)\n \n\n \n &gt; from(123)\n &gt; |&gt; optional(string)\n Error([DecodeError(expected: &quot;String&quot;, found: &quot;Int&quot;, path: [])])\n \n\nSynonyms:\ngleam/dynamic.optional\ngleam/dynamic optional","url":"gleam/dynamic.html#optional"},{"doc":"gleam/dynamic","title":"optional_field","content":"pub fn optional_field(\n  named name: a,\n  of inner_type: fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n) -&gt; fn(Dynamic) -&gt; Result(Option(b), List(DecodeError))\n Checks to see if a `Dynamic` value is a map with a specific field.\n If the map does not have the specified field, returns an `Ok(None)` instead of failing; otherwise,\n returns the decoded field wrapped in `Some(_)`.\n\n ## Examples\n\n \n &gt; import gleam/map\n &gt; map.new()\n &gt; |&gt; map.insert(&quot;Hello&quot;, &quot;World&quot;)\n &gt; |&gt; from\n &gt; |&gt; field(named: &quot;Hello&quot;, of: string)\n Ok(Some(&quot;World&quot;))\n \n\n \n &gt; import gleam/map\n &gt; map.new()\n &gt; |&gt; from\n &gt; |&gt; field(named: &quot;Hello&quot;, of: string)\n Ok(None)\n \n\n \n &gt; from(123)\n &gt; |&gt; field(&quot;Hello&quot;, string)\n Error([DecodeError(expected: &quot;Map&quot;, found: &quot;Int&quot;, path: [])])\n \n\nSynonyms:\ngleam/dynamic.optional_field\ngleam/dynamic optional_field","url":"gleam/dynamic.html#optional_field"},{"doc":"gleam/dynamic","title":"result","content":"pub fn result(\n  ok decode_ok: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  error decode_error: fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n) -&gt; fn(Dynamic) -&gt; Result(Result(a, b), List(DecodeError))\n Checks to see whether a `Dynamic` value is a result of a particular type, and\n returns that result if it is.\n\n The `ok` and `error` arguments are decoders for decoding the `Ok` and\n `Error` values of the result.\n\n ## Examples\n\n \n &gt; from(Ok(1))\n &gt; |&gt; result(ok: int, error: string)\n Ok(Ok(1))\n \n\n \n &gt; from(Error(&quot;boom&quot;))\n &gt; |&gt; result(ok: int, error: string)\n Ok(Error(&quot;boom&quot;))\n \n\n \n &gt; from(123)\n &gt; |&gt; result(ok: int, error: string)\n Error([DecodeError(expected: &quot;Result&quot;, found: &quot;Int&quot;, path: [])])\n \n\nSynonyms:\ngleam/dynamic.result\ngleam/dynamic result","url":"gleam/dynamic.html#result"},{"doc":"gleam/dynamic","title":"shallow_list","content":"pub fn shallow_list(\n  from value: Dynamic,\n) -&gt; Result(List(Dynamic), List(DecodeError))\n Checks to see whether a `Dynamic` value is a list, and returns that list if it\n is. The types of the elements are not checked.\n\n If you wish to decode all the elements in the list use the `list` function\n instead.\n\n ## Examples\n\n \n &gt; shallow_list(from([&quot;a&quot;, &quot;b&quot;, &quot;c&quot;]))\n Ok([from(&quot;a&quot;), from(&quot;b&quot;), from(&quot;c&quot;)])\n \n\n \n &gt; shallow_list(1)\n Error([DecodeError(expected: &quot;List&quot;, found: &quot;Int&quot;, path: [])])\n \n\nSynonyms:\ngleam/dynamic.shallow_list\ngleam/dynamic shallow_list","url":"gleam/dynamic.html#shallow_list"},{"doc":"gleam/dynamic","title":"string","content":"pub fn string(\n  from data: Dynamic,\n) -&gt; Result(String, List(DecodeError))\n Checks to see whether a `Dynamic` value is a string, and returns that string if\n it is.\n\n ## Examples\n\n \n &gt; string(from(&quot;Hello&quot;))\n Ok(&quot;Hello&quot;)\n \n\n \n &gt; string(from(123))\n Error([DecodeError(expected: &quot;String&quot;, found: &quot;Int&quot;, path: [])])\n \n\nSynonyms:\ngleam/dynamic.string\ngleam/dynamic string","url":"gleam/dynamic.html#string"},{"doc":"gleam/dynamic","title":"tuple2","content":"pub fn tuple2(\n  first decode1: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  second decode2: fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n) -&gt; fn(Dynamic) -&gt; Result(#(a, b), List(DecodeError))\n Checks to see if a `Dynamic` value is a 2-element tuple, list or array containing\n specifically typed elements.\n\n ## Examples\n\n \n &gt; from(#(1, 2))\n &gt; |&gt; tuple2(int, int)\n Ok(#(1, 2))\n \n\n \n &gt; from(#(1, 2.0))\n &gt; |&gt; tuple2(int, float)\n Ok(#(1, 2.0))\n \n\n \n &gt; from([1, 2])\n &gt; |&gt; tuple2(int, int)\n Ok(#(1, 2))\n \n\n \n &gt; from([from(1), from(2.0)])\n &gt; |&gt; tuple2(int, float)\n Ok(#(1, 2.0))\n \n\n \n &gt; from(#(1, 2, 3))\n &gt; |&gt; tuple2(int, float)\n Error([\n   DecodeError(expected: &quot;Tuple of 2 elements&quot;, found: &quot;Tuple of 3 elements&quot;, path: []),\n ])\n \n\n \n &gt; from(&quot;&quot;)\n &gt; |&gt; tuple2(int, float)\n Error([DecodeError(expected: &quot;Tuple of 2 elements&quot;, found: &quot;String&quot;, path: [])])\n \n\nSynonyms:\ngleam/dynamic.tuple2\ngleam/dynamic tuple2","url":"gleam/dynamic.html#tuple2"},{"doc":"gleam/dynamic","title":"tuple3","content":"pub fn tuple3(\n  first decode1: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  second decode2: fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n  third decode3: fn(Dynamic) -&gt; Result(c, List(DecodeError)),\n) -&gt; fn(Dynamic) -&gt; Result(#(a, b, c), List(DecodeError))\n Checks to see if a `Dynamic` value is a 3-element tuple, list or array containing\n specifically typed elements.\n\n ## Examples\n\n \n &gt; from(#(1, 2, 3))\n &gt; |&gt; tuple3(int, int, int)\n Ok(#(1, 2, 3))\n \n\n \n &gt; from(#(1, 2.0, &quot;3&quot;))\n &gt; |&gt; tuple3(int, float, string)\n Ok(#(1, 2.0, &quot;3&quot;))\n \n\n \n &gt; from([1, 2, 3])\n &gt; |&gt; tuple3(int, int, int)\n Ok(#(1, 2, 3))\n \n\n \n &gt; from([from(1), from(2.0), from(&quot;3&quot;)])\n &gt; |&gt; tuple3(int, float, string)\n Ok(#(1, 2.0, &quot;3&quot;))\n \n\n \n &gt; from(#(1, 2))\n &gt; |&gt; tuple3(int, float, string)\n Error([\n   DecodeError(expected: &quot;Tuple of 3 elements&quot;, found: &quot;Tuple of 2 elements&quot;, path: [])),\n ])\n \n\n \n &gt; from(&quot;&quot;)\n &gt; |&gt; tuple3(int, float, string)\n Error([\n   DecodeError(expected: &quot;Tuple of 3 elements&quot;, found: &quot;String&quot;, path: []),\n ])\n \n\nSynonyms:\ngleam/dynamic.tuple3\ngleam/dynamic tuple3","url":"gleam/dynamic.html#tuple3"},{"doc":"gleam/dynamic","title":"tuple4","content":"pub fn tuple4(\n  first decode1: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  second decode2: fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n  third decode3: fn(Dynamic) -&gt; Result(c, List(DecodeError)),\n  fourth decode4: fn(Dynamic) -&gt; Result(d, List(DecodeError)),\n) -&gt; fn(Dynamic) -&gt; Result(#(a, b, c, d), List(DecodeError))\n Checks to see if a `Dynamic` value is a 4-element tuple, list or array containing\n specifically typed elements.\n\n ## Examples\n\n \n &gt; from(#(1, 2, 3, 4))\n &gt; |&gt; tuple4(int, int, int, int)\n Ok(#(1, 2, 3, 4))\n \n\n \n &gt; from(#(1, 2.0, &quot;3&quot;, 4))\n &gt; |&gt; tuple4(int, float, string, int)\n Ok(#(1, 2.0, &quot;3&quot;, 4))\n\n \n &gt; from([1, 2, 3, 4])\n &gt; |&gt; tuple4(int, int, int, int)\n Ok(#(1, 2, 3, 4))\n \n\n \n &gt; from([from(1), from(2.0), from(&quot;3&quot;), from(4)])\n &gt; |&gt; tuple4(int, float, string, int)\n Ok(#(1, 2.0, &quot;3&quot;, 4))\n \n\n &gt; from(#(1, 2))\n &gt; |&gt; tuple4(int, float, string, int)\n Error([\n   DecodeError(expected: &quot;Tuple of 4 elements&quot;, found: &quot;Tuple of 2 elements&quot;, path: []),\n ])\n \n\n \n &gt; from(&quot;&quot;)\n &gt; |&gt; tuple4(int, float, string, int)\n Error([\n   DecodeError(expected: &quot;Tuple of 4 elements&quot;, found: &quot;String&quot;, path: []),\n ])\n \n\nSynonyms:\ngleam/dynamic.tuple4\ngleam/dynamic tuple4","url":"gleam/dynamic.html#tuple4"},{"doc":"gleam/dynamic","title":"tuple5","content":"pub fn tuple5(\n  first decode1: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  second decode2: fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n  third decode3: fn(Dynamic) -&gt; Result(c, List(DecodeError)),\n  fourth decode4: fn(Dynamic) -&gt; Result(d, List(DecodeError)),\n  fifth decode5: fn(Dynamic) -&gt; Result(e, List(DecodeError)),\n) -&gt; fn(Dynamic) -&gt; Result(#(a, b, c, d, e), List(DecodeError))\n Checks to see if a `Dynamic` value is a 5-element tuple, list or array containing\n specifically typed elements.\n\n ## Examples\n\n \n &gt; from(#(1, 2, 3, 4, 5))\n &gt; |&gt; tuple5(int, int, int, int, int)\n Ok(#(1, 2, 3, 4, 5))\n \n\n \n &gt; from(#(1, 2.0, &quot;3&quot;, 4, 5))\n &gt; |&gt; tuple5(int, float, string, int, int)\n Ok(#(1, 2.0, &quot;3&quot;, 4, 5))\n \n\n \n &gt; from([1, 2, 3, 4, 5])\n &gt; |&gt; tuple5(int, int, int, int, int)\n Ok(#(1, 2, 3, 4, 5))\n \n\n \n &gt; from([from(1), from(2.0), from(&quot;3&quot;), from(4), from(True)])\n &gt; |&gt; tuple5(int, float, string, int, bool)\n Ok(#(1, 2.0, &quot;3&quot;, 4, True))\n \n\n \n &gt; from(#(1, 2))\n &gt; |&gt; tuple5(int, float, string, int, int)\n Error([\n   DecodeError(expected: &quot;Tuple of 5 elements&quot;, found: &quot;Tuple of 2 elements&quot;, path: [])),\n ])\n\n &gt; from(&quot;&quot;)\n &gt; |&gt; tuple5(int, float, string, int, int)\n Error([DecodeError(expected: &quot;Tuple of 5 elements&quot;, found: &quot;String&quot;, path: [])])\n \n\nSynonyms:\ngleam/dynamic.tuple5\ngleam/dynamic tuple5","url":"gleam/dynamic.html#tuple5"},{"doc":"gleam/dynamic","title":"tuple6","content":"pub fn tuple6(\n  first decode1: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  second decode2: fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n  third decode3: fn(Dynamic) -&gt; Result(c, List(DecodeError)),\n  fourth decode4: fn(Dynamic) -&gt; Result(d, List(DecodeError)),\n  fifth decode5: fn(Dynamic) -&gt; Result(e, List(DecodeError)),\n  sixth decode6: fn(Dynamic) -&gt; Result(f, List(DecodeError)),\n) -&gt; fn(Dynamic) -&gt;\n  Result(#(a, b, c, d, e, f), List(DecodeError))\n Checks to see if a `Dynamic` value is a 6-element tuple, list or array containing\n specifically typed elements.\n\n ## Examples\n\n \n &gt; from(#(1, 2, 3, 4, 5, 6))\n &gt; |&gt; tuple6(int, int, int, int, int, int)\n Ok(#(1, 2, 3, 4, 5, 6))\n \n\n \n &gt; from(#(1, 2.0, &quot;3&quot;, 4, 5, 6))\n &gt; |&gt; tuple6(int, float, string, int, int, int)\n Ok(#(1, 2.0, &quot;3&quot;, 4, 5, 6))\n \n\n \n &gt; from([1, 2, 3, 4, 5, 6])\n &gt; |&gt; tuple6(int, int, int, int, int, int)\n Ok(#(1, 2, 3, 4, 5, 6))\n \n\n \n &gt; from([from(1), from(2.0), from(&quot;3&quot;), from(4), from(True), from(False)])\n &gt; |&gt; tuple6(int, float, string, int, bool, bool)\n Ok(#(1, 2.0, &quot;3&quot;, 4, True, False))\n \n\n \n &gt; from(#(1, 2))\n &gt; |&gt; tuple6(int, float, string, int, int, int)\n Error([\n   DecodeError(expected: &quot;Tuple of 6 elements&quot;, found: &quot;Tuple of 2 elements&quot;, path: []),\n ])\n \n\n \n &gt; from(&quot;&quot;)\n &gt; |&gt; tuple6(int, float, string, int, int, int)\n Error([DecodeError(expected: &quot;Tuple of 6 elements&quot;, found: &quot;String&quot;, path: [])])\n \n\nSynonyms:\ngleam/dynamic.tuple6\ngleam/dynamic tuple6","url":"gleam/dynamic.html#tuple6"},{"doc":"gleam/dynamic","title":"unsafe_coerce","content":"pub fn unsafe_coerce(a: Dynamic) -&gt; a\n Unsafely casts a Dynamic value into any other type.\n\n This is an escape hatch for the type system that may be useful when wrapping\n native Erlang APIs. It is to be used as a last measure only!\n\n If you can avoid using this function, do!\n\nSynonyms:\ngleam/dynamic.unsafe_coerce\ngleam/dynamic unsafe_coerce","url":"gleam/dynamic.html#unsafe_coerce"},{"doc":"gleam/dynamic","title":"gleam/dynamic","content":"","url":"gleam/dynamic.html"},{"doc":"gleam/function","title":"apply1","content":"pub fn apply1(fun: fn(a) -&gt; b, arg1: a) -&gt; b\n Takes a function with arity one and an argument,\n calls that function with the argument and returns the function return value.\n\n Useful for concisely calling functions returned as a part of a pipeline.\n\n ## Example\n\n \n &gt; let doubler = fn() {\n &gt;  fn(x: Int) { x * 2 }\n &gt; }\n &gt;\n &gt; doubler()\n &gt; |&gt; apply1(2)\n 4\n \n\nSynonyms:\ngleam/function.apply1\ngleam/function apply1","url":"gleam/function.html#apply1"},{"doc":"gleam/function","title":"apply2","content":"pub fn apply2(fun: fn(a, b) -&gt; c, arg1: a, arg2: b) -&gt; c\n Takes a function with arity two and two arguments,\n calls that function with the arguments\n and returns the function return value.\n\n See [`apply1`](#apply1) for more details.\n\nSynonyms:\ngleam/function.apply2\ngleam/function apply2","url":"gleam/function.html#apply2"},{"doc":"gleam/function","title":"apply3","content":"pub fn apply3(\n  fun: fn(a, b, c) -&gt; d,\n  arg1: a,\n  arg2: b,\n  arg3: c,\n) -&gt; d\n Takes a function with arity three and three arguments,\n calls that function with the arguments\n and returns the function return value.\n\n See [`apply1`](#apply1) for more details.\n\nSynonyms:\ngleam/function.apply3\ngleam/function apply3","url":"gleam/function.html#apply3"},{"doc":"gleam/function","title":"compose","content":"pub fn compose(fun1: fn(a) -&gt; b, fun2: fn(b) -&gt; c) -&gt; fn(a) -&gt; c\n Takes two functions and chains them together to form one function that\n takes the input from the first and returns the output of the second.\n\nSynonyms:\ngleam/function.compose\ngleam/function compose","url":"gleam/function.html#compose"},{"doc":"gleam/function","title":"constant","content":"pub fn constant(value: a) -&gt; fn(b) -&gt; a\n Takes a single argument and returns a new function that\n ignores its argument and always returns the input value.\n\nSynonyms:\ngleam/function.constant\ngleam/function constant","url":"gleam/function.html#constant"},{"doc":"gleam/function","title":"curry2","content":"pub fn curry2(fun: fn(a, b) -&gt; c) -&gt; fn(a) -&gt; fn(b) -&gt; c\n Takes a function with `2` arguments (an arity of `2`), and returns the\n curried equivalent.\n\n `fn(a, b) -&gt; c` becomes `fn(a) -&gt; fn(b) -&gt; c`.\n\n ## Examples\n\n *Currying* creates a new function that is identical to the given function\n except that arguments must now be supplied one by one over several function\n calls. It thus is the process of taking a function with `n` arguments\n and producing a sequence of `n` single-argument functions. Given:\n\n \n &gt; fn my_fun(i: Int, s: String) -&gt; String { ... }\n \n\n …calling `curry2(my_fun)` would return the curried equivalent, like so:\n\n \n &gt; curry2(my_fun)\n fn(Int) -&gt; fn(String) -&gt; String\n \n\n Currying is useful when you want to partially apply a function with\n some arguments and then pass it somewhere else, for example:\n\n \n &gt; import gleam/list\n &gt; let multiply = curry2(fn(x, y) { x * y })\n &gt; let doubles = list.map([1, 2, 3], multiply(2))\n [2, 4, 6]\n \n\nSynonyms:\ngleam/function.curry2\ngleam/function curry2","url":"gleam/function.html#curry2"},{"doc":"gleam/function","title":"curry3","content":"pub fn curry3(\n  fun: fn(a, b, c) -&gt; d,\n) -&gt; fn(a) -&gt; fn(b) -&gt; fn(c) -&gt; d\n Takes a function with `3` arguments (an arity of `3`), and returns the\n curried equivalent.\n\n `fn(a, b, c) -&gt; d` becomes `fn(a) -&gt; fn(b) -&gt; fn(c) -&gt; d`.\n\n See [`curry2`](#curry2) for a detailed explanation.\n\nSynonyms:\ngleam/function.curry3\ngleam/function curry3","url":"gleam/function.html#curry3"},{"doc":"gleam/function","title":"curry4","content":"pub fn curry4(\n  fun: fn(a, b, c, d) -&gt; e,\n) -&gt; fn(a) -&gt; fn(b) -&gt; fn(c) -&gt; fn(d) -&gt; e\n Takes a function with `4` arguments (an arity of `4`), and returns the\n curried equivalent.\n\n `fn(a, b, c, d) -&gt; e` becomes `fn(a) -&gt; fn(b) -&gt; fn(c) -&gt; fn(d) -&gt; e`.\n\n See [`curry2`](#curry2) for a detailed explanation.\n\nSynonyms:\ngleam/function.curry4\ngleam/function curry4","url":"gleam/function.html#curry4"},{"doc":"gleam/function","title":"curry5","content":"pub fn curry5(\n  fun: fn(a, b, c, d, e) -&gt; f,\n) -&gt; fn(a) -&gt; fn(b) -&gt; fn(c) -&gt; fn(d) -&gt; fn(e) -&gt; f\n Takes a function with `5` arguments (an arity of `5`), and returns the\n curried equivalent.\n\n `fn(a, b, c, d, e) -&gt; f` becomes\n `fn(a) -&gt; fn(b) -&gt; fn(c) -&gt; fn(d) -&gt; fn(e) -&gt; f`.\n\n See [`curry2`](#curry2) for a detailed explanation.\n\nSynonyms:\ngleam/function.curry5\ngleam/function curry5","url":"gleam/function.html#curry5"},{"doc":"gleam/function","title":"curry6","content":"pub fn curry6(\n  fun: fn(a, b, c, d, e, f) -&gt; g,\n) -&gt; fn(a) -&gt; fn(b) -&gt; fn(c) -&gt; fn(d) -&gt; fn(e) -&gt; fn(f) -&gt; g\n Takes a function with `6` arguments (an arity of `6`), and returns the\n curried equivalent.\n\n `fn(a, b, c, d, e, f) -&gt; g` becomes\n `fn(a) -&gt; fn(b) -&gt; fn(c) -&gt; fn(d) -&gt; fn(e) -&gt; fn(f) -&gt; g`.\n\n See [`curry2`](#curry2) for a detailed explanation.\n\nSynonyms:\ngleam/function.curry6\ngleam/function curry6","url":"gleam/function.html#curry6"},{"doc":"gleam/function","title":"flip","content":"pub fn flip(fun: fn(a, b) -&gt; c) -&gt; fn(b, a) -&gt; c\n Takes a function that takes two arguments and returns a new function that\n takes the same two arguments, but in reverse order.\n\nSynonyms:\ngleam/function.flip\ngleam/function flip","url":"gleam/function.html#flip"},{"doc":"gleam/function","title":"identity","content":"pub fn identity(x: a) -&gt; a\n Takes a single argument and always returns its input value.\n\nSynonyms:\ngleam/function.identity\ngleam/function identity","url":"gleam/function.html#identity"},{"doc":"gleam/function","title":"tap","content":"pub fn tap(arg: a, effect: fn(a) -&gt; b) -&gt; a\n Takes an argument and a single function,\n calls that function with that argument\n and returns that argument instead of the function return value.\n Useful for running synchronous side effects in a pipeline.\n\nSynonyms:\ngleam/function.tap\ngleam/function tap","url":"gleam/function.html#tap"},{"doc":"gleam/function","title":"gleam/function","content":"","url":"gleam/function.html"},{"doc":"gleam/regex","title":"CompileError","content":"pub type CompileError {\n  CompileError(error: String, byte_index: Int)\n}\n When a regular expression fails to compile:\n\nCompileError(error: String, byte_index: Int)\n\nerror\n&lt;p&gt;The problem encountered that caused the compilation to fail&lt;/p&gt;\n\nbyte_index\n&lt;p&gt;The byte index into the string to where the problem was found\nThis value may not be correct in JavaScript environments.&lt;/p&gt;\n\nSynonyms:\ngleam/regex.CompileError\ngleam/regex CompileError","url":"gleam/regex.html#CompileError"},{"doc":"gleam/regex","title":"Match","content":"pub type Match {\n  Match(content: String, submatches: List(Option(String)))\n}\n The details about a particular match:\n\nMatch(content: String, submatches: List(Option(String)))\n\ncontent\n&lt;p&gt;The full string of the match.&lt;/p&gt;\n\nsubmatches\n&lt;p&gt;A &lt;code&gt;Regex&lt;/code&gt; can have subpatterns, sup-parts that are in parentheses.&lt;/p&gt;\n\nSynonyms:\ngleam/regex.Match\ngleam/regex Match","url":"gleam/regex.html#Match"},{"doc":"gleam/regex","title":"Options","content":"pub type Options {\n  Options(case_insensitive: Bool, multi_line: Bool)\n}\n The problem encountered that caused the compilation to fail\n The byte index into the string to where the problem was found\n This value may not be correct in JavaScript environments.\n\nOptions(case_insensitive: Bool, multi_line: Bool)\n\n\nSynonyms:\ngleam/regex.Options\ngleam/regex Options","url":"gleam/regex.html#Options"},{"doc":"gleam/regex","title":"Regex","content":"pub type Regex\n\n\nSynonyms:\ngleam/regex.Regex\ngleam/regex Regex","url":"gleam/regex.html#Regex"},{"doc":"gleam/regex","title":"check","content":"pub fn check(with regex: Regex, content content: String) -&gt; Bool\n Returns a boolean indicating whether there was a match or not.\n\n ## Examples\n\n \n &gt; let assert Ok(re) = from_string(&quot;^f.o.?&quot;)\n &gt; check(with: re, content: &quot;foo&quot;)\n True\n \n\n \n &gt; check(with: re, content: &quot;boo&quot;)\n False\n \n\nSynonyms:\ngleam/regex.check\ngleam/regex check","url":"gleam/regex.html#check"},{"doc":"gleam/regex","title":"compile","content":"pub fn compile(\n  pattern: String,\n  with options: Options,\n) -&gt; Result(Regex, CompileError)\n Creates a `Regex` with some additional options.\n\n ## Examples\n\n \n &gt; let options = Options(case_insensitive: False, multi_line: True)\n &gt; let assert Ok(re) = compile(&quot;^[0-9]&quot;, with: options)\n &gt; check(re, &quot;abc\\n123&quot;)\n True\n \n\n \n &gt; let options = Options(case_insensitive: True, multi_line: False)\n &gt; let assert Ok(re) = compile(&quot;[A-Z]&quot;, with: options)\n &gt; check(re, &quot;abc123&quot;)\n True\n \n\nSynonyms:\ngleam/regex.compile\ngleam/regex compile","url":"gleam/regex.html#compile"},{"doc":"gleam/regex","title":"from_string","content":"pub fn from_string(\n  pattern: String,\n) -&gt; Result(Regex, CompileError)\n Creates a new `Regex`.\n\n ## Examples\n\n \n &gt; let assert Ok(re) = from_string(&quot;[0-9]&quot;)\n &gt; check(re, &quot;abc123&quot;)\n True\n \n\n \n &gt; check(re, &quot;abcxyz&quot;)\n False\n \n\n \n &gt; from_string(&quot;[0-9&quot;)\n Error(\n   CompileError(\n     error: &quot;missing terminating ] for character class&quot;,\n     byte_index: 4\n   )\n )\n \n\nSynonyms:\ngleam/regex.from_string\ngleam/regex from_string","url":"gleam/regex.html#from_string"},{"doc":"gleam/regex","title":"scan","content":"pub fn scan(\n  with regex: Regex,\n  content string: String,\n) -&gt; List(Match)\n Collects all matches of the regular expression.\n\n ## Examples\n\n \n &gt; let assert Ok(re) = from_string(&quot;[oi]n a (\\\\w+)&quot;)\n &gt; scan(with: re, content: &quot;I am on a boat in a lake.&quot;)\n [\n   Match(\n     content: &quot;on a boat&quot;,\n     submatches: [Some(&quot;boat&quot;)]\n   ),\n   Match(\n     content: &quot;in a lake&quot;,\n     submatches: [Some(&quot;lake&quot;)]\n   )\n ]\n \n\n \n &gt; let assert Ok(re) = regex.from_string(&quot;([+|\\\\-])?(\\\\d+)(\\\\w+)?&quot;)\n &gt; scan(with: re, content: &quot;-36&quot;)\n [\n   Match(\n     content: &quot;-36&quot;,\n     submatches: [Some(&quot;-&quot;), Some(&quot;36&quot;)]\n   )\n ]\n\n &gt; scan(with: re, content: &quot;36&quot;)\n [\n   Match(\n     content: &quot;36&quot;,\n     submatches: [None, Some(&quot;36&quot;)]\n   )\n ]\n \n\n \n &gt; let assert Ok(re) = regex.from_string(&quot;var\\\\s*(\\\\w+)\\\\s*(int|string)?\\\\s*=\\\\s*(.*)&quot;)\n &gt; scan(with: re, content: &quot;var age = 32&quot;)\n [\n   Match(\n     content: &quot;var age = 32&quot;,\n     submatches: [Some(&quot;age&quot;), None, Some(&quot;32&quot;)]\n   )\n ]\n \n\n \n &gt; let assert Ok(re) = regex.from_string(&quot;let (\\\\w+) = (\\\\w+)&quot;)\n &gt; scan(with: re, content: &quot;let age = 32&quot;)\n [\n   Match(\n     content: &quot;let age = 32&quot;,\n     submatches: [Some(&quot;age&quot;), Some(&quot;32&quot;)]\n   )\n ]\n\n &gt; scan(with: re, content: &quot;const age = 32&quot;)\n []\n \n\nSynonyms:\ngleam/regex.scan\ngleam/regex scan","url":"gleam/regex.html#scan"},{"doc":"gleam/regex","title":"split","content":"pub fn split(\n  with regex: Regex,\n  content string: String,\n) -&gt; List(String)\n Splits a string.\n\n ## Examples\n\n \n &gt; let assert Ok(re) = from_string(&quot; *, *&quot;)\n &gt; split(with: re, content: &quot;foo,32, 4, 9  ,0&quot;)\n [&quot;foo&quot;, &quot;32&quot;, &quot;4&quot;, &quot;9&quot;, &quot;0&quot;]\n \n\nSynonyms:\ngleam/regex.split\ngleam/regex split","url":"gleam/regex.html#split"},{"doc":"gleam/regex","title":"gleam/regex","content":" This module contains regular expression matching functions for strings.\n The matching algorithms of the library are based on the PCRE library, but not\n all of the PCRE library is interfaced and some parts of the library go beyond\n what PCRE offers. Currently PCRE version 8.40 (release date 2017-01-11) is used.","url":"gleam/regex.html"},{"doc":"gleam/bool","title":"and","content":"pub fn and(a: Bool, b: Bool) -&gt; Bool\n Returns the and of two bools, but it evaluates both arguments.\n\n It&#39;s the function equivalent of the `&amp;&amp;` operator.\n This function is useful in higher order functions or pipes.\n\n ## Examples\n\n \n &gt; and(True, True)\n True\n \n\n \n &gt; and(False, True)\n False\n \n\n \n &gt; False |&gt; and(True)\n False\n \n\nSynonyms:\ngleam/bool.and\ngleam/bool and","url":"gleam/bool.html#and"},{"doc":"gleam/bool","title":"compare","content":"pub fn compare(a: Bool, with b: Bool) -&gt; Order\n Compares two bools and returns the first value&#39;s `Order` to the second.\n\n ## Examples\n\n \n &gt; import gleam/order\n &gt; compare(True, False)\n order.Gt\n \n\nSynonyms:\ngleam/bool.compare\ngleam/bool compare","url":"gleam/bool.html#compare"},{"doc":"gleam/bool","title":"exclusive_nor","content":"pub fn exclusive_nor(a: Bool, b: Bool) -&gt; Bool\n Returns the exclusive nor of two bools.\n\n ## Examples\n\n \n &gt; exclusive_nor(False, False)\n True\n \n\n \n &gt; exclusive_nor(False, True)\n False\n \n\n \n &gt; exclusive_nor(True, False)\n False\n \n\n \n &gt; exclusive_nor(True, True)\n True\n \n\nSynonyms:\ngleam/bool.exclusive_nor\ngleam/bool exclusive_nor","url":"gleam/bool.html#exclusive_nor"},{"doc":"gleam/bool","title":"exclusive_or","content":"pub fn exclusive_or(a: Bool, b: Bool) -&gt; Bool\n Returns the exclusive or of two bools.\n\n ## Examples\n\n \n &gt; exclusive_or(False, False)\n False\n \n\n \n &gt; exclusive_or(False, True)\n True\n \n\n \n &gt; exclusive_or(True, False)\n True\n \n\n \n &gt; exclusive_or(True, True)\n False\n \n\nSynonyms:\ngleam/bool.exclusive_or\ngleam/bool exclusive_or","url":"gleam/bool.html#exclusive_or"},{"doc":"gleam/bool","title":"guard","content":"pub fn guard(\n  when requirement: Bool,\n  return consequence: a,\n  otherwise alternative: fn() -&gt; a,\n) -&gt; a\n Run a callback function if the given bool is `False`, otherwise return a\n default value.\n\n With a `use` expression this function can simulate the early-return pattern\n found in some other programming languages.\n\n In a procedural language:\n\n js\n if (predicate) return value;\n // ...\n \n\n In Gleam with a `use` expression:\n\n \n use &lt;- guard(when: predicate, return: value)\n // ...\n \n\n Like everything in Gleam `use` is an expression, so it short circuits the\n current block, not the entire function. As a result you can assign the value\n to a variable:\n\n \n let x = {\n   use &lt;- guard(when: predicate, return: value)\n   // ...\n }\n \n\n Note that unlike in procedural languages the `return` value is evaluated\n even when the predicate is `False`, so it is advisable not to perform\n expensive computation there.\n\n\n ## Examples\n\n \n &gt; let name = &quot;&quot;\n &gt; use &lt;- guard(when: name == &quot;&quot;, return: &quot;Welcome!&quot;)\n &gt; &quot;Hello, &quot; &lt;&gt; name\n &quot;Welcome!&quot;\n \n\n \n &gt; let name = &quot;Kamaka&quot;\n &gt; use &lt;- guard(when: name == &quot;&quot;, return: &quot;Welcome!&quot;)\n &gt; &quot;Hello, &quot; &lt;&gt; name\n &quot;Hello, Kamaka&quot;\n \n\nSynonyms:\ngleam/bool.guard\ngleam/bool guard","url":"gleam/bool.html#guard"},{"doc":"gleam/bool","title":"max","content":"pub fn max(a: Bool, b: Bool) -&gt; Bool\n Returns `True` if either argument&#39;s value is `True`.\n\n ## Examples\n\n \n &gt; max(True, False)\n True\n \n\n \n &gt; max(False, True)\n True\n \n\n \n &gt; max(False, False)\n False\n \n\nSynonyms:\ngleam/bool.max\ngleam/bool max","url":"gleam/bool.html#max"},{"doc":"gleam/bool","title":"min","content":"pub fn min(a: Bool, b: Bool) -&gt; Bool\n Returns `False` if either bool value is `False`.\n\n ## Examples\n\n \n &gt; min(True, False)\n False\n \n\n \n &gt; min(False, True)\n False\n\n &gt; min(False, False)\n False\n \n\nSynonyms:\ngleam/bool.min\ngleam/bool min","url":"gleam/bool.html#min"},{"doc":"gleam/bool","title":"nand","content":"pub fn nand(a: Bool, b: Bool) -&gt; Bool\n Returns the nand of two bools.\n\n ## Examples\n\n \n &gt; nand(False, False)\n True\n \n\n \n &gt; nand(False, True)\n True\n \n\n \n &gt; nand(True, False)\n True\n \n\n \n &gt; nand(True, True)\n False\n \n\nSynonyms:\ngleam/bool.nand\ngleam/bool nand","url":"gleam/bool.html#nand"},{"doc":"gleam/bool","title":"negate","content":"pub fn negate(bool: Bool) -&gt; Bool\n Returns the opposite bool value.\n\n This is the same as the `!` or `not` operators in some other languages.\n\n ## Examples\n\n \n &gt; negate(True)\n False\n \n\n \n &gt; negate(False)\n True\n \n\nSynonyms:\ngleam/bool.negate\ngleam/bool negate","url":"gleam/bool.html#negate"},{"doc":"gleam/bool","title":"nor","content":"pub fn nor(a: Bool, b: Bool) -&gt; Bool\n Returns the nor of two bools.\n\n ## Examples\n\n \n &gt; nor(False, False)\n True\n \n\n \n &gt; nor(False, True)\n False\n \n\n \n &gt; nor(True, False)\n False\n \n\n \n &gt; nor(True, True)\n False\n \n\nSynonyms:\ngleam/bool.nor\ngleam/bool nor","url":"gleam/bool.html#nor"},{"doc":"gleam/bool","title":"or","content":"pub fn or(a: Bool, b: Bool) -&gt; Bool\n Returns the or of two bools, but it evaluates both arguments.\n\n It&#39;s the function equivalent of the `||` operator.\n This function is useful in higher order functions or pipes.\n\n ## Examples\n\n \n &gt; or(True, True)\n True\n \n\n \n &gt; or(False, True)\n True\n \n\n \n &gt; False |&gt; or(True)\n True\n \n\nSynonyms:\ngleam/bool.or\ngleam/bool or","url":"gleam/bool.html#or"},{"doc":"gleam/bool","title":"to_int","content":"pub fn to_int(bool: Bool) -&gt; Int\n Returns a numeric representation of the given bool.\n\n ## Examples\n\n \n &gt; to_int(True)\n 1\n\n &gt; to_int(False)\n 0\n \n\nSynonyms:\ngleam/bool.to_int\ngleam/bool to_int","url":"gleam/bool.html#to_int"},{"doc":"gleam/bool","title":"to_string","content":"pub fn to_string(bool: Bool) -&gt; String\n Returns a string representation of the given bool.\n\n ## Examples\n\n \n &gt; to_string(True)\n &quot;True&quot;\n \n\n \n &gt; to_string(False)\n &quot;False&quot;\n \n\nSynonyms:\ngleam/bool.to_string\ngleam/bool to_string","url":"gleam/bool.html#to_string"},{"doc":"gleam/bool","title":"gleam/bool","content":" A type with two possible values, `True` and `False`. Used to indicate whether\n things are... true or false!\n\n Often is it clearer and offers more type safety to define a custom type\n than to use `Bool`. For example, rather than having a `is_teacher: Bool`\n field consider having a `role: SchoolRole` field where `SchoolRole` is a custom\n type that can be either `Student` or `Teacher`.","url":"gleam/bool.html"},{"doc":"gleam/uri","title":"Uri","content":"pub type Uri {\n  Uri(\n    scheme: Option(String),\n    userinfo: Option(String),\n    host: Option(String),\n    port: Option(Int),\n    path: String,\n    query: Option(String),\n    fragment: Option(String),\n  )\n}\n Type representing holding the parsed components of an URI.\n All components of a URI are optional, except the path.\n\nUri(\n  scheme: Option(String),\n  userinfo: Option(String),\n  host: Option(String),\n  port: Option(Int),\n  path: String,\n  query: Option(String),\n  fragment: Option(String),\n)\n\n\nSynonyms:\ngleam/uri.Uri\ngleam/uri Uri","url":"gleam/uri.html#Uri"},{"doc":"gleam/uri","title":"merge","content":"pub fn merge(base: Uri, relative: Uri) -&gt; Result(Uri, Nil)\n Resolves a URI with respect to the given base URI.\n\n The base URI must be an absolute URI or this function will return an error.\n The algorithm for merging uris is described in\n [RFC 3986](https://tools.ietf.org/html/rfc3986#section-5.2).\n\nSynonyms:\ngleam/uri.merge\ngleam/uri merge","url":"gleam/uri.html#merge"},{"doc":"gleam/uri","title":"origin","content":"pub fn origin(uri: Uri) -&gt; Result(String, Nil)\n Fetches the origin of a URI.\n\n Returns the origin of a uri as defined in\n [RFC 6454](https://tools.ietf.org/html/rfc6454)\n\n The supported URI schemes are `http` and `https`.\n URLs without a scheme will return `Error`.\n\n ## Examples\n\n \n &gt; let assert Ok(uri) = parse(&quot;http://example.com/path?foo#bar&quot;)\n &gt; origin(uri)\n Ok(&quot;http://example.com&quot;)\n \n\nSynonyms:\ngleam/uri.origin\ngleam/uri origin","url":"gleam/uri.html#origin"},{"doc":"gleam/uri","title":"parse","content":"pub fn parse(uri_string: String) -&gt; Result(Uri, Nil)\n Parses a compliant URI string into the `Uri` Type.\n If the string is not a valid URI string then an error is returned.\n\n The opposite operation is `uri.to_string`.\n\n ## Examples\n\n \n &gt; parse(&quot;https://example.com:1234/a/b?query=true#fragment&quot;)\n Ok(\n   Uri(\n     scheme: Some(&quot;https&quot;),\n     userinfo: None,\n     host: Some(&quot;example.com&quot;),\n     port: Some(1234),\n     path: &quot;/a/b&quot;,\n     query: Some(&quot;query=true&quot;),\n     fragment: Some(&quot;fragment&quot;)\n   )\n )\n \n\nSynonyms:\ngleam/uri.parse\ngleam/uri parse","url":"gleam/uri.html#parse"},{"doc":"gleam/uri","title":"parse_query","content":"pub fn parse_query(\n  query: String,\n) -&gt; Result(List(#(String, String)), Nil)\n Parses an urlencoded query string into a list of key value pairs.\n Returns an error for invalid encoding.\n\n The opposite operation is `uri.query_to_string`.\n\n ## Examples\n\n \n &gt; parse_query(&quot;a=1&amp;b=2&quot;)\n Ok([#(&quot;a&quot;, &quot;1&quot;), #(&quot;b&quot;, &quot;2&quot;)])\n \n\nSynonyms:\ngleam/uri.parse_query\ngleam/uri parse_query","url":"gleam/uri.html#parse_query"},{"doc":"gleam/uri","title":"path_segments","content":"pub fn path_segments(path: String) -&gt; List(String)\n Splits the path section of a URI into it&#39;s constituent segments.\n\n Removes empty segments and resolves dot-segments as specified in\n [section 5.2](https://www.ietf.org/rfc/rfc3986.html#section-5.2) of the RFC.\n\n ## Examples\n\n \n &gt; path_segments(&quot;/users/1&quot;)\n [&quot;users&quot; ,&quot;1&quot;]\n \n\nSynonyms:\ngleam/uri.path_segments\ngleam/uri path_segments","url":"gleam/uri.html#path_segments"},{"doc":"gleam/uri","title":"percent_decode","content":"pub fn percent_decode(value: String) -&gt; Result(String, Nil)\n Decodes a percent encoded string.\n\n ## Examples\n\n \n &gt; percent_decode(&quot;100%25+great&quot;)\n Ok(&quot;100% great&quot;)\n \n\nSynonyms:\ngleam/uri.percent_decode\ngleam/uri percent_decode","url":"gleam/uri.html#percent_decode"},{"doc":"gleam/uri","title":"percent_encode","content":"pub fn percent_encode(value: String) -&gt; String\n Encodes a string into a percent encoded representation.\n\n ## Examples\n\n \n &gt; percent_encode(&quot;100% great&quot;)\n &quot;100%25%20great&quot;\n \n\nSynonyms:\ngleam/uri.percent_encode\ngleam/uri percent_encode","url":"gleam/uri.html#percent_encode"},{"doc":"gleam/uri","title":"query_to_string","content":"pub fn query_to_string(query: List(#(String, String))) -&gt; String\n Encodes a list of key value pairs as a URI query string.\n\n The opposite operation is `uri.parse_query`.\n\n ## Examples\n\n \n &gt; query_to_string([#(&quot;a&quot;, &quot;1&quot;), #(&quot;b&quot;, &quot;2&quot;)])\n &quot;a=1&amp;b=2&quot;\n \n\nSynonyms:\ngleam/uri.query_to_string\ngleam/uri query_to_string","url":"gleam/uri.html#query_to_string"},{"doc":"gleam/uri","title":"to_string","content":"pub fn to_string(uri: Uri) -&gt; String\n Encodes a `Uri` value as a URI string.\n\n The opposite operation is `uri.parse`.\n\n ## Examples\n\n \n &gt; let uri = Uri(Some(&quot;http&quot;), None, Some(&quot;example.com&quot;), ...)\n &gt; to_string(uri)\n &quot;http://example.com&quot;\n \n\nSynonyms:\ngleam/uri.to_string\ngleam/uri to_string","url":"gleam/uri.html#to_string"},{"doc":"gleam/uri","title":"gleam/uri","content":" Utilities for working with URIs\n\n This module provides functions for working with URIs (for example, parsing\n URIs or encoding query strings). The functions in this module are implemented\n according to [RFC 3986](https://tools.ietf.org/html/rfc3986).\n\n Query encoding (Form encoding) is defined in the\n [W3C specification](https://www.w3.org/TR/html52/sec-forms.html#urlencoded-form-data).","url":"gleam/uri.html"},{"doc":"gleam/io","title":"debug","content":"pub fn debug(term: a) -&gt; a\n Prints a value to standard error (stderr) yielding Gleam syntax.\n\n The value is returned after being printed so it can be used in pipelines.\n\n ## Example\n\n \n &gt; debug(&quot;Hi mum&quot;)\n // -&gt; &lt;&lt;&quot;Hi mum&quot;&gt;&gt;\n &quot;Hi mum&quot;\n \n\n \n &gt; debug(Ok(1))\n // -&gt; {ok, 1}\n Ok(1)\n \n\n \n &gt; import list\n &gt; [1, 2]\n &gt; |&gt; list.map(fn(x) { x + 1 })\n &gt; |&gt; debug\n &gt; |&gt; list.map(fn(x) { x * 2 })\n // -&gt; [2, 3]\n [4, 6]\n \n\nSynonyms:\ngleam/io.debug\ngleam/io debug","url":"gleam/io.html#debug"},{"doc":"gleam/io","title":"print","content":"pub fn print(string: String) -&gt; Nil\n Writes a string to standard output.\n\n If you want your output to be printed on its own line see `println`.\n\n ## Example\n\n \n &gt; io.print(&quot;Hi mum&quot;)\n // -&gt; Hi mum\n Nil\n \n\nSynonyms:\ngleam/io.print\ngleam/io print","url":"gleam/io.html#print"},{"doc":"gleam/io","title":"print_error","content":"pub fn print_error(string: String) -&gt; Nil\n Writes a string to standard error.\n\n If you want your output to be printed on its own line see `println_error`.\n\n ## Example\n\n \n &gt; io.print_error(&quot;Hi pop&quot;)\n // -&gt; Hi pop\n Nil\n \n\nSynonyms:\ngleam/io.print_error\ngleam/io print_error","url":"gleam/io.html#print_error"},{"doc":"gleam/io","title":"println","content":"pub fn println(string: String) -&gt; Nil\n Writes a string to standard output, appending a newline to the end.\n\n ## Example\n\n \n &gt; io.println(&quot;Hi mum&quot;)\n // -&gt; Hi mum\n Nil\n \n\nSynonyms:\ngleam/io.println\ngleam/io println","url":"gleam/io.html#println"},{"doc":"gleam/io","title":"println_error","content":"pub fn println_error(string: String) -&gt; Nil\n Writes a string to standard error, appending a newline to the end.\n\n ## Example\n\n \n &gt; io.println_error(&quot;Hi pop&quot;)\n // -&gt; Hi mum\n Nil\n \n\nSynonyms:\ngleam/io.println_error\ngleam/io println_error","url":"gleam/io.html#println_error"},{"doc":"gleam/io","title":"gleam/io","content":"","url":"gleam/io.html"},{"doc":"gleam/base","title":"decode64","content":"pub fn decode64(encoded: String) -&gt; Result(BitArray, Nil)\n\nSynonyms:\ngleam/base.decode64\ngleam/base decode64","url":"gleam/base.html#decode64"},{"doc":"gleam/base","title":"encode64","content":"pub fn encode64(input: BitArray, padding: Bool) -&gt; String\n\nSynonyms:\ngleam/base.encode64\ngleam/base encode64","url":"gleam/base.html#encode64"},{"doc":"gleam/base","title":"url_decode64","content":"pub fn url_decode64(encoded: String) -&gt; Result(BitArray, Nil)\n\nSynonyms:\ngleam/base.url_decode64\ngleam/base url_decode64","url":"gleam/base.html#url_decode64"},{"doc":"gleam/base","title":"url_encode64","content":"pub fn url_encode64(input: BitArray, padding: Bool) -&gt; String\n\nSynonyms:\ngleam/base.url_encode64\ngleam/base url_encode64","url":"gleam/base.html#url_encode64"},{"doc":"gleam/base","title":"gleam/base","content":"","url":"gleam/base.html"}]);